import { Component, OnInit } from '@angular/core';
import { LoaderService } from '../../providers/loader.service';
import { VendedoresLojasService } from '../../providers/vendedores-lojas.service';
import * as HighCharts from 'highcharts';
import { AuthServiceService } from '../../providers/auth-service.service';
import { ModalController } from '@ionic/angular';
import { AvaliacaoDetalheComponent } from '../../modal/avaliacao-detalhe/avaliacao-detalhe.component';

@Component({
  selector: 'app-avaliacao-vendedores',
  templateUrl: './avaliacao-vendedores.page.html',
  styleUrls: ['./avaliacao-vendedores.page.scss'],
})
export class AvaliacaoVendedoresPage implements OnInit {
  parametro = {
    idConexao : '1',
    data_inicial : '',
    data_final : ''
  }
  dadosGrafico: any = [];
  totalPesoas: number = 0;
  otimo: number = 0;
  bom: number = 0;
  regular: number = 0;
  ruim: number = 0;

  vendas: any = [];
  constructor(public loader: LoaderService, public vendedores: VendedoresLojasService, 
    public auth: AuthServiceService, public modalController: ModalController) { }

  ngOnInit() {
    this.parametro.idConexao = this.auth.Id;
    this.buscarCampanhas(this.parametro);
  }

  avaliar(avaliacao, vendedor){
    this.abrirTelaGenerica(avaliacao, vendedor);
  }

  async abrirTelaGenerica(avaliacao, vendedor) {
    const modal = await this.modalController.create({
      component: AvaliacaoDetalheComponent,
      componentProps: {
        avaliacao: avaliacao, vendedor: vendedor
      },
      backdropDismiss: false,      
    });

    modal.onDidDismiss().then((res) => {      
      let data = res.data;
      if(data != null){
        
      }
    });
    return await modal.present();
  }

  buscarCampanhas(parametro){
    this.vendas = [];   
    this.otimo = 0;
    this.bom = 0;
    this.regular = 0;
    this.ruim = 0;
    this.loader.showLoader("Buscando informações no servidor..."); 
    this.vendedores.avaliacaoAtendimento(parametro)
    .then((result: any) => {
      
      for (let i = 0; i < result.length; i++) {
        const element = result[i].DADOS;
        for (let a = 0; a < element.length; a++) {
          const k = element[a];
          let ab = k.VALOR.split('|');
          k.RETORNO = ab[1];
          k.VALOR = k.VALOR.split('|')[0];
          if(k.VALOR == 'OTIMO'){
            this.otimo = this.otimo + k.TOTAL;
          }
          if(k.VALOR == 'BOM'){
            this.bom = this.bom + k.TOTAL;
          }
          if(k.VALOR == 'REGULAR'){
            this.regular = this.regular + k.TOTAL;
          }
          if(k.VALOR == 'RUIM'){
            this.ruim = this.ruim + k.TOTAL;
          }
        }
      }
      // console.log(result);
      this.dadosGrafico = [];
      this.dadosGrafico.push(
        {name: "Otimo", y: this.otimo, color: '#0fc908'},
        {name: "Bom", y: this.bom, color: '#34540e'},
        {name: "Regular", y: this.regular, color: '#fff768'},
        {name: "Ruim", y: this.ruim, color: '#c90808'}
      );      
      this.vendas = result;
      this.totalPesoas = this.otimo + this.bom + this.regular + this.ruim;
      this.graf(this.dadosGrafico);
      this.loader.hideLoader();
      if(result.length == 0){        
        this.loader.presentToast("Não encontrei nada!");        
      }      
      }).catch((error: any) => {
        this.loader.hideLoader();      
        this.loader.showError("Ops!", error);          
      });
  }

  graf(dadosGrafico){    
    // this.status = true;
    HighCharts.chart('pieChart', {
      chart: {
        plotBackgroundColor: null,
        plotBorderWidth: null,
        plotShadow: false,
        type: 'pie'
      },
      title: {
        text: '%',
        align: 'center',
        verticalAlign: 'middle'
    },
      tooltip: {
        pointFormat: '<b>{point.y:.2f}</b> Pessoas'
      },
      plotOptions: {
        pie: {
          dataLabels: {
              enabled: true,
              distance: -30,
              format: '<b>{point.name}</b><br>{point.percentage:.2f} %',
              style: {
                  fontWeight: 'bold',
                  color: 'white'
              }
          },
          /*startAngle: -90,
          endAngle: 90,
          center: ['50%', '75%'],*/
          size: '90%'
        }
      },      
      
      series: [{
        type: undefined, 
        innerSize: '50%',      
        // keys: ['name', 'y', 'color.pattern.color'],
        data: dadosGrafico
    }]
    });    
  }
  //avaliacaoAtendimento

}
