import { Component, OnInit } from '@angular/core';
import { AlertController, ModalController } from '@ionic/angular';
import { LerBarrasComponent } from '../../modal/ler-barras/ler-barras.component';
import { UserData } from '../../providers/user-data';
import validateAccessKey from 'br-validate-dfe-access-key';
import { LoaderService } from '../../providers/loader.service';
import { EstoqueLojasService } from '../../providers/estoque-lojas.service';
import { TelaGenericaComponent } from '../../modal/tela-generica/tela-generica.component';


@Component({
  selector: 'app-cadastrar-produtos-amc',
  templateUrl: './cadastrar-produtos-amc.page.html',
  styleUrls: ['./cadastrar-produtos-amc.page.scss'],
})
export class CadastrarProdutosAmcPage implements OnInit {
  codigoProcurar: any = "";
  loading: boolean = true;
  cabecalho: any = [];
  itens: any = [];
  items: any[] = [1,2,3,4,5,6,7];
  desabilitarBotao: boolean = false;
  totalItens = 0;
  totalItensCadastrados = 0;
  artigo: any = "";  
  cod_artigo : ""  
  consultouArtigo: boolean = true;    
  constructor(public modalController: ModalController, public user: UserData, public loader: LoaderService,
    public estoque : EstoqueLojasService, public alertController: AlertController) { }

  ngOnInit() {
    this.loader.presentToast('Escolha a coleção e depois coloque a chave ou referência.');
  }

  async abrirTelaGenerica(tela) {
    const modal = await this.modalController.create({
      component: TelaGenericaComponent,
      componentProps: {
        tela: tela, parametro: 'cadastrarProduto'
      },
      backdropDismiss: false,      
    });

    modal.onDidDismiss().then((res) => {      
      let data = res.data;
      console.log(data);
      if(data != null){
        this.consultouArtigo = false;
        if(data.TELA == "artigo"){
          this.artigo = data.DESCRICAO;
          this.cod_artigo = data.CODIGO;
          return;
        }
      }
    });
    return await modal.present();
  }

  async lerEtiqueta() {
    const modal = await this.modalController.create({
      component: LerBarrasComponent,
      componentProps: {        
      },
      backdropDismiss: false,      
    });

    modal.onDidDismiss().then((res) => {
      this.pesquisarChave(res.data, 'camera');
    });

    return await modal.present();
  }

  valuechange(newValue) {
    if(newValue.key == 'Enter' || newValue.keyCode == 13 || newValue.keyIdentifier == 'Enter'){
      this.pesquisarChave(this.codigoProcurar, 'tela');
    }    
  }

  pesquisarChave(codbarra, origem){
    if(codbarra.length < 13){
      this.loading = false;
      this.estoque.consultarItemReferenciaAMC(codbarra)      
        .then((result: any) => {
          this.totalItens = 0;
          this.totalItensCadastrados = 0;
          this.loading = true;       
          this.cabecalho = [];
          this.itens = [];
          this.codigoProcurar = "";
          this.desabilitarBotao = false; 
          if(result == ''){
            this.loader.showError("Ops!", "Não encontrei essa referência.");
          } else {          
            this.cabecalho = [];
            for (let i = 0; i < result.length; i++) {
              const element = result[i];
              let dados = [];
              for (let a = 0; a < element.dados.length; a++) {
                const elemento = element.dados[a];                
                dados.push({
                  "codColecao": elemento.codColecao,
                  "codCor": elemento.codCor,
                  "codGrupo": elemento.codGrupo,
                  "codReduzido": elemento.codReduzido,
                  "codSku": elemento.codSku,
                  "codSkuDiferente": elemento.codSkuDiferente,
                  "desCor": elemento.desCor,
                  "desGrupo": elemento.desGrupo,
                  "desSortimento": elemento.desSortimento,
                  "descricao": elemento.descricao,
                  "ean": elemento.ean,
                  "existe": elemento.existe,
                  "idPrincipalPai": elemento.idPrincipalPai,
                  "idVariacao": elemento.idVariacao,
                  "ncm": elemento.ncm,
                  "valorCusto": (elemento.precoCusto == 0) ? elemento.precoVenda/2.75 : elemento.precoCusto,
                  "valorRoyaltie": (elemento.precoRoyaltie),
                  "precoVenda": elemento.precoVenda,
                  "referencia": elemento.referencia,
                  "tamanho": elemento.tamanho,
                  "unidade": elemento.unidade
                });
              }
              this.itens.push({
                "codReferencia" : codbarra,
                "dados": dados
              });  
            }                        
            this.totalItens = this.itens.length;                   
            this.presentAlert();
          }
        }).catch((error: any) => {          
          //console.log('error: '+error);        
          this.loading = true;
          this.desabilitarBotao = false; 
          this.loader.showError('Ops', 'O seu servidor pode esta sem internet no momento, tente novamente mais tarde.');
        });
    } else {
      let validar: boolean = validateAccessKey(codbarra);
      if(validar == false){
        let texto = (origem == 'camera') ? 'Ao usar a câmera confirma se a chave de acesso bate com a que esta na folha, porque ela esta errada!' : 'Você digitou a chave de acesso errada!'
        this.loader.showError("Ops.", texto);
      } else {
        this.loading = false;
        this.desabilitarBotao = true;
        this.estoque.consultarNFeAMC(codbarra)      
        .then((result: any) => {
          this.totalItens = 0;
          this.totalItensCadastrados = 0;
          this.loading = true;       
          this.cabecalho = [];
          this.itens = [];
          this.codigoProcurar = "";
          this.desabilitarBotao = false; 
          if(result == ''){
            this.loader.showError("Ops!", "Essa nota fiscal não foi emitda pela AMC. <br>Então você deve consultar os produtos usando a referência da etiqueta.");
          } else {          
            this.cabecalho.push(result.cabecalhoNF);
            this.itens = result.itens;
            this.totalItens = this.itens.length;                   
            this.presentAlert();
          }
        }).catch((error: any) => {          
          //console.log('error: '+error);        
          this.loading = true;
          this.desabilitarBotao = false; 
          this.loader.showError('Ops', 'O seu servidor pode esta sem internet no momento, tente novamente mais tarde.');
        });
      }
    }
    
  }

  async presentAlert() {
    const alert = await this.alertController.create({      
      header: 'Atenção!',
      subHeader: 'Encontrei '+this.totalItens+' referências',
      message: 'Agora vou cadastrar os produtos...',
      backdropDismiss: false,
      buttons: [
        {
          text: 'OK',
          handler: () => {
            this.add();
          }
        }
      ]
    });
    await alert.present();
    const { role } = await alert.onDidDismiss();    
  }

  addItem(item){
    this.loader.showLoader("Cadastrando produto..."+this.totalItensCadastrados+"/"+this.totalItens);
    // console.log(item);    
    return this.estoque.cadastrarItemAMC(item, this.cod_artigo)      
    .then((result: any) => {
      this.loader.hideLoader();
      this.totalItensCadastrados = this.totalItensCadastrados +1;
      for (let i = 0; i < result.length; i++) {        
        const element = result[i];          
        for (let a = 0; a < element.variacoes.length; a++) {
          const elemento = element.variacoes[a];
          let referencia = elemento.referencia.replaceAll(".","");
          let codprod = elemento.codprod;          
          for (let b = 0; b < this.itens.length; b++) {
            const elementx = this.itens[b];            
            if(elementx.codReferencia == referencia){
              elementx.codprod = codprod;                
              //console.log(this.itens);
            }
          }
        }
      }
      return result;
    }).catch((error: any) => {
      console.log(error);        
      console.log(item);
      this.loader.hideLoader();
      this.loader.showError('Ops', 'O seu servidor pode esta sem internet no momento, tente novamente mais tarde.');
    });      
    
  }

  async add(){          
    for (const [idx, item] of this.itens.entries()) {
      const todo = await this.addItem(item);
      // console.log(`Received Todo ${idx+1}:`, todo);
    }
  }

}
