import { format, parseISO } from 'date-fns';
import { Component, OnInit } from '@angular/core';
import { ModalController } from '@ionic/angular';
import { ParametrosComponent } from '../../modal/parametros/parametros.component';
import { AuthServiceService } from '../../providers/auth-service.service';
import { EstoqueLojasService } from '../../providers/estoque-lojas.service';
import { LoaderService } from '../../providers/loader.service';

@Component({
  selector: 'app-cadastro-alteracao-promocao-planilha',
  templateUrl: './cadastro-alteracao-promocao-planilha.page.html',
  styleUrls: ['./cadastro-alteracao-promocao-planilha.page.scss'],
})
export class CadastroAlteracaoPromocaoPlanilhaPage implements OnInit {
  parametro: any = {
    "dataInicial": "",
    "dataFinal": "",
    "percentual": 0,
    "artigos" : [],
    "marcas": [],
    "fornecedores": [],
    "colecao": [],
    "grupos": [],
    "promocao": [],
  };
  totalProd: number = 0;
  dataMin: any;
  contrast: number = 0;

  constructor(public estoque: EstoqueLojasService, public modalController: ModalController, 
    public loader: LoaderService, public auth: AuthServiceService) {
    let diaAtual = new Date();
    let mes : any = diaAtual.getMonth()+1;
    let dia : any =    diaAtual.getDate(); 
    this.dataMin = diaAtual.getFullYear()+'-'+this.padLeft(mes, '0', 2)+'-'+ this.padLeft(dia, '0', 2) ;  
    this.parametro.codigo = this.auth.Usuario.codigo;

  }

  ngOnInit() {
  }

  async openModal() {
    const modal = await this.modalController.create({
      component: ParametrosComponent,
      componentProps: {
        "lojas": false,
        "artigo": true,
        "grupo": true,
        "marca": true,
        "fornecedor": false,
        "dataInicial": false,
        "dataFinal": false,
        "colecao": false,
        "data": false,
        "genero": false
      },
      backdropDismiss: false,      
    });

    modal.onDidDismiss().then((res) => {      
      // console.log(res);
      if (res !== null) {
        // this.parametro = res.data;
        this.parametro.dataInicial = "";
        this.parametro.dataFinal = "";
        this.parametro.colecao = [];
        this.parametro.fornecedores = [];
        this.parametro.promocao = [];
        this.parametro.artigos = [];
        this.parametro.grupos = [];
        this.parametro.marcas = [];
        let arrayArtigo = [];
        let arrayGrupos = [];
        let arrayMarcas = [];
        for (let i = 0; i < res.data.filtroArtigos.length; i++) {
          const element = res.data.filtroArtigos[i];
          arrayArtigo.push({
            "CODIGO" : element
          });          
        }
        this.parametro.artigos = arrayArtigo;        
        for (let i = 0; i < res.data.filtroGrupos.length; i++) {
          const element = res.data.filtroGrupos[i];
          arrayGrupos.push({
            "CODIGO" : element
          });          
        }
        this.parametro.grupos = arrayGrupos;
        for (let i = 0; i < res.data.filtroMarcas.length; i++) {
          const element = res.data.filtroMarcas[i];
          arrayMarcas.push({
            "CODIGO" : element
          });          
        } 
        this.parametro.marcas = arrayMarcas;       
        
        this.consultarProdutos(this.parametro);
      }
    });

    return await modal.present();
  }

  padLeft(text:string, padChar:string, size:number): string {
    return (String(padChar).repeat(size) + text).substr( (size * -1), size) ;
  }

  escolherDataInicial(e){
    this.parametro.dataInicial = this.formatDate(e, 'yyyy-MM-dd');
  }

  escolherDataFinal(e){
    this.parametro.dataFinal = this.formatDate(e, 'yyyy-MM-dd');
  }

  formatDate(value: string, formato: string) {
    return format(parseISO(value), formato/*'yyyy-MM-dd'*/);
  }

  consultarProdutos(param){    
    this.estoque.consultarProduto(param)
    .then((result: any) => {
      for (let i = 0; i < result.length; i++) {
        const element = result[i];
        this.totalProd = element.COUNT;
      }     
    })
    .catch((error: any) => {
      console.log('error: '+error);
    });
  }

  aplicarPromocao(){    
    this.loader.showLoader("Atualizando o cadastro.");
    this.estoque.inserirPromocaoProduto(this.parametro)
    .then((result: any) => {
      this.loader.hideLoader();
      this.parametro.dataInicial = "";
      this.parametro.dataFinal = "";
      this.parametro.percentual = 0;    
      this.loader.presentToast(result);
    })
    .catch((error: any) => {
      this.loader.hideLoader();
      this.loader.showError("Ops", error);
    });
  }

}
