import { ChangeDetectorRef, Component, OnInit } from '@angular/core';
import { ActivatedRoute } from '@angular/router';
import { BarcodeScanner } from '@ionic-native/barcode-scanner/ngx';
import { AlertController, ModalController } from '@ionic/angular';
import { LerBarrasComponent } from '../../modal/ler-barras/ler-barras.component';
import { AuthServiceService } from '../../providers/auth-service.service';
import { EstoqueLojasService } from '../../providers/estoque-lojas.service';
import { LoaderService } from '../../providers/loader.service';
import { ModuloService } from '../../providers/modulo.service';

@Component({
  selector: 'app-cadastro-alteracao-promocao',
  templateUrl: './cadastro-alteracao-promocao.page.html',
  styleUrls: ['./cadastro-alteracao-promocao.page.scss'],
})
export class CadastroAlteracaoPromocaoPage implements OnInit {
  web : boolean = true;
  public Parametro = {
    id: '',
    codigo: '',
    parametro: ''
  }
  arr: any = [];
  items: any;
  // hoje: any = '2021-06-16';
  mes: any;
  hoje: any;
  dia: any;
  cadastro = {
    codprod: '',
    descr: '',
    refe: '',
    custo: '',
    venda: '',
    iniprom: '',
    fimprom: '',
    promocao: '',
    nova_iniprom: '',
    nova_fimprom: '',
    nova_promocao: '',
    id: '',
    end_mac: '',
    usuario: ''
  }

  filtroPesquisa: any = 'referencia';
  codigoProcurar: any = '';
  loading: any;
  products: any[] = [];
  selectedProduct: any;
  productFound:boolean = false;

  private scannerEnabled: boolean = true;
  private transports: Transport[] = [];
  private information: string = "No se ha detectado información de ningún código. Acerque un código QR para escane";
  
  public obj: any;
  constructor(public auth: AuthServiceService, public modulo: ModuloService, public loader: LoaderService,
    public estoque: EstoqueLojasService, public alertController: AlertController,
    private barcodeScanner: BarcodeScanner, private cd: ChangeDetectorRef,
    private route: ActivatedRoute, public modalController: ModalController) { 
    this.web = this.auth.celular;
    
  }

  async lerBarras() {
    const modal = await this.modalController.create({
      component: LerBarrasComponent,
      componentProps: {        
      },
      backdropDismiss: false,      
    });

    modal.onDidDismiss().then((res) => {
      if(res.data != ''){
        if(res.data.length == 8){
          this.filtroPesquisa = 'codigo_winsae';
        } else {
          this.filtroPesquisa = 'ean';
        }
        this.codigoProcurar = res.data;
        this.pesquisarProduto();
      }
    });

    return await modal.present();
  }

  abrirCamera(){

  }
  
  uploadPWA(){

  }

  lerEtiqueta(){
    this.selectedProduct = {};
    this.barcodeScanner.scan().then((barcodeData) => {
      this.codigoProcurar = barcodeData.text;
      this.Parametro.codigo = this.codigoProcurar; 
      this.Parametro.parametro = this.filtroPesquisa;  
      if(barcodeData.text.length == 8){
        this.filtroPesquisa = 'codigo_winsae';
      } else {
        this.filtroPesquisa = 'ean';
      }      
      this.pesquisarProduto();
    }, (err) => {
      this.lerBarras();
    });
  }

  ngOnInit() {
    let diaAtual = new Date();
    this.mes = diaAtual.getMonth()+1;
    this.dia = diaAtual.getDate();
    this.hoje = diaAtual.getFullYear()+'-'+this.padLeft(this.mes, '0', 2)+'-'+this.padLeft(this.dia, '0', 2);
    const data = this.route.snapshot.paramMap.get('codigo');
    console.log(data);
  }

  padLeft(text:string, padChar:string, size:number): string {
    return (String(padChar).repeat(size) + text).substr( (size * -1), size) ;
  }

  ionViewCanEnter() {
    this.modulo.consultarModulo('frmCadastroDeProdutos').then((result: any) => {
      if(result == true){            
        return true;            
      } else {
        this.loader.showError("Ops", "Seu usuário não tem permissão para entrar no módulo.");            
        return false;
      }
    }).catch((error: any) => {          
      //console.log('error: '+error);          
    });    
  }

  valuechange(newValue) {
    if(newValue.key == 'Enter' || newValue.keyCode == 13 || newValue.keyIdentifier == 'Enter'){
      this.pesquisarProduto();
    }    
  }

  public pesquisarProduto(){
    this.arr = [];
    this.obj = [];
    this.items = [];    
    this.loading = false;
    if(this.codigoProcurar == ''){
      this.loader.showError('Ops', 'Deve preencher com algum valor.');
      this.loading = true;
    } else {
      this.Parametro.codigo = this.filtroPesquisa == 'codigo_winsae' ? this.padLeft(this.codigoProcurar, '0', 5) : this.codigoProcurar;
      this.Parametro.parametro = this.filtroPesquisa;    
      {
        this.estoque.buscarEstoquep(this.Parametro)
        .then((result: any) => {          
          this.loading = true;
          // console.log(result);
          let mapProdutos = result.map( function( elem ) {
            return {
              "CODPROD" : elem.CODPROD, 
              "CUSTO" : elem.CUSTO,
              "DESCRICAO" : elem.DESCRICAO,
              "FIMPROM" : elem.FIMPROM,
              "INIPROM" : elem.INIPROM,
              "PROMOCAO" : elem.PROMOCAO,
              "REFERENCIA" : elem.REFERENCIA,
              "VENDA" : elem.VENDA,
              "FOTO": elem.FOTO,
              "DESCRICAO_MARCA": elem.DESCRICAO_MARCA,
              "DESCRICAO_COR": elem.DESCRICAO_COR              
              };
          });
          
          mapProdutos.reduce((previous, current)=> {
            if(!previous[current['CODPROD']]) {
                previous[current['CODPROD']] = [current];
                this.arr.push(current);
            } else {                  
                console.log("Já existe");
            }  
            return previous;
          }, {});          
          this.obj = this.arr;             
          this.codigoProcurar = '';
          if(this.obj == ''){
            this.loader.showError('Ops', 'Não encontrei nada.');
          }
        })
        .catch((error: any) => {          
          //console.log('error: '+error);
          this.loading = true;
          this.loader.showError('Ops', 'O seu servidor pode esta sem internet no momento, tente novamente mais tarde.');
        });
      }
    }
  }

  async presentAlertPrompt(produto) {        
    this.cadastro.codprod = produto.CODPROD;
    this.cadastro.descr = produto.DESCRICAO;
    this.cadastro.refe = produto.REFERENCIA;
    this.cadastro.custo = produto.CUSTO;
    this.cadastro.venda = produto.VENDA;
    this.cadastro.promocao = produto.PROMOCAO;
    this.cadastro.iniprom = (produto.INIPROM == '' || produto.INIPROM == null) ? null : produto.INIPROM.replace(' 00:00:00','');
    this.cadastro.fimprom = (produto.FIMPROM == '' || produto.FIMPROM == null) ? null : produto.FIMPROM.replace(' 00:00:00','');
    this.cadastro.usuario = this.auth.Usuario.codigo;
    const alert = await this.alertController.create({
      cssClass: 'my-custom-class',
      header: 'Alteração de preços',
      inputs: [
        {
          label: 'Venda',
          name: 'preco',
          type: 'number',
          value: produto.VENDA,
          placeholder: 'Preço de Venda'
        },
        {
          label: 'Promoção',
          name: 'promocao',
          type: 'number',
          // id: 'name2-id',
          value: (produto.PROMOCAO == 0 ? null : produto.PROMOCAO),
          placeholder: 'Valor da promoção'
        },
        // multiline input.
        {
          label: 'Início da promoção',
          name: 'inicioPromocao',
          // id: 'paragraph',
          type: 'date',
          value: this.cadastro.iniprom,//produto.INIPROM,
          min: this.hoje,          
        },                
        {
          label: 'Final da promoção',
          name: 'finalPromocao',
          type: 'date',
          value: this.cadastro.fimprom,//produto.FIMPROM,
          min: this.hoje          
        }        
      ],
      buttons: [
        {
          text: 'Cancelar',
          role: 'cancel',
          cssClass: 'secondary',
          handler: () => {
            console.log('Confirm Cancel');
          }
        }, {
          text: 'Alterar',
          cssClass: 'danger',
          handler: (data) => {
            this.cadastro.nova_iniprom = data.inicioPromocao;
            this.cadastro.nova_fimprom = data.finalPromocao;
            this.cadastro.nova_promocao = data.promocao;
            this.cadastro.venda = data.preco;                        
            this.salvarCadastro();
          }
        }
      ]
    });

    await alert.present();
  }

  salvarCadastro(){
    this.loading = false;
    this.obj = [];
    this.arr = [];
    this.estoque.atualizarCadastroPromocao(this.cadastro).then((result: any) => {      
      if(result == true){
        this.loading = true;
        this.loader.presentToast("Produto alterado com sucesso!");
        this.codigoProcurar = this.cadastro.codprod;
        this.pesquisarProduto();
      }
    }).catch((error: any) => {
      console.log('error: '+error);
    });
  }

}
interface Transport {
  plates: string;
  slot: Slot;
}

interface Slot {
  name: string;
  description: string;
}