import { Component, OnInit } from '@angular/core';
import { AlertController } from '@ionic/angular';
import { FinanceiroLojasService } from '../../providers/financeiro-lojas.service';
import { LoaderService } from '../../providers/loader.service';

@Component({
  selector: 'app-cadastro-condicao-pagamento',
  templateUrl: './cadastro-condicao-pagamento.page.html',
  styleUrls: ['./cadastro-condicao-pagamento.page.scss'],
})
export class CadastroCondicaoPagamentoPage implements OnInit {
  obj: any;
  constructor(public loader: LoaderService, public financeiro: FinanceiroLojasService, public alertCtrl: AlertController) { }

  ngOnInit() {
    this.consultarCondicaoPagto();
  }

  consultarCondicaoPagto(){
    this.obj = [];
    this.loader.showLoader("Buscando as condições...");
    this.financeiro.consultarCondicaoPagto()
    .then((result: any) => {
      this.loader.hideLoader();      
      this.obj = result;            
    }).catch((error: any) =>{      
      this.loader.hideLoader();      
      this.loader.showError("Ops!", error);
    });          
  } 
  
  async alterarCondicao(cond) {    
    const alert = await this.alertCtrl.create({
      // cssClass: 'my-custom-class',
      header: 'Alteração',
      inputs: [
        {
          name: 'descricao',
          type: 'text',
          placeholder: 'Descrição',
          value: cond.DESCR
        },
        {
          name: 'desconto',
          type: 'number',          
          placeholder: '% de desconto',
          value: cond.PERCENTUAL
        },                
      ],
      buttons: [
        {
          text: 'Cancelar',
          role: 'cancel',
          cssClass: 'secondary',
          handler: () => {            
          }
        }, {
          text: 'Confirmar',
          handler: (data) => {
            cond.DESCR = data.descricao;
            cond.PERCENTUAL = data.desconto;            
            this.salvarCondicao(cond);
            // this.fecharAlterarCondicao(data);
          }
        }
      ]
    });

    await alert.present();
  }

  salvarCondicao(cond){
    this.financeiro.salvarCondicaoPagto(cond)
    .then((result: any) => {       
      if(result == true){
        this.loader.presentToast('Avise as lojas p/ fecharem e abrirem o programa de vendas para obter o resultado esperado!');        
        setTimeout(() => {  
          this.consultarCondicaoPagto() 
        }, 4000);        
      }
    }).catch((error: any) =>{
      console.log(error);
    });
  }


}
