import { format, parseISO } from 'date-fns';
import { Component, OnInit } from '@angular/core';
import { BarcodeScanner } from '@ionic-native/barcode-scanner/ngx';
import { AlertController, ModalController, PopoverController } from '@ionic/angular';
import { AuthServiceService } from '../../providers/auth-service.service';
import { FinanceiroLojasService } from '../../providers/financeiro-lojas.service';
import { LoaderService } from '../../providers/loader.service';

import { boleto, boletoBancario, boletoArrecadacao } from 'boleto-brasileiro-validator';
import { ParametrosComponent } from '../../modal/parametros/parametros.component';
import { TelaGenericaComponent } from '../../modal/tela-generica/tela-generica.component';

@Component({
  selector: 'app-cadastro-contas-pagar',
  templateUrl: './cadastro-contas-pagar.page.html',
  styleUrls: ['./cadastro-contas-pagar.page.scss'],
})
export class CadastroContasPagarPage implements OnInit {
  param: any = {
    barras: "",
    vencimento: '',
    valorDocumento: "",
    banco: "",
    agencia: "",
    beneficiario: "",
    nossoNumero: "",
    numeroDocumento: "",
    pedido: "",
    parcela: 1,
    fornecedor: "",
    filtroFornecedor: "",
    filtroLoja: "",
    loja: "",
    id:"",
    usuario: "",
    tipo: ""
  }

  celular: boolean = this.auth.celular;
  modeloCelular: string = this.auth.modeloCelular;

  tipoBoleto = "Boleto bancário";
  constructor(public auth: AuthServiceService, public alertCtrl: AlertController, 
    public financeiro: FinanceiroLojasService, public loader: LoaderService, 
    public barcodeScanner: BarcodeScanner, public modalController: ModalController,
    public popoverController: PopoverController) { }

  ngOnInit() {
  }

  formatDate(value: string, formato: string) {
    return format(parseISO(value), formato/*'yyyy-MM-dd'*/);
  }

  vencimento(e){
    console.log(e);
    this.param.vencimento = this.formatDate(e, 'yyyy-MM-dd');
    this.popoverController.dismiss();
  }

  async alertConfirm() {
    let alert = await this.alertCtrl.create({
      header: 'Criar mais uma parcela',
      message: 'Deseja criar mais uma parcela para esta conta?',      
      // enableBackdropDismiss: false,
      buttons: [
        {
          text: 'Não',
          role: 'cancel',
          handler: () => {
            this.param.barras = "";
            this.param.vencimento = new Date();
            this.param.valorDocumento = "";
            this.param.banco = "";
            this.param.agencia = "";
            this.param.beneficiario = "";
            this.param.nossoNumero = "";
            this.param.numeroDocumento = "";
            this.param.pedido = "";
            this.param.parcela = 1;
            this.param.fornecedor = "";
            this.param.filtroFornecedor = "";
            this.param.filtroLoja = "";
            this.param.loja = "";
            this.param.id = "";
            this.param.usuario = "";
            this.param.tipo = "";
          }
        },
        {
          text: 'Sim',
          handler: () => {
            this.param.barras = "";
            this.param.parcela = this.param.parcela + 1;            
          }
        }
      ]
    });
    await alert.present();
  }

  valuechange(newValue) {    
    if(newValue.key == 'Enter' || newValue.keyCode == 13 || newValue.keyIdentifier == 'Enter'){
      this.vencimentoBarrasDigitavel();
    }
    if(this.validarBoleto(this.param.barras)){
      this.vencimentoBarrasDigitavel();
    }
  }

  lerCodigoBarras(){
    /*if(this.modeloCelular == 'ios'){
      let popover = this.modalCtrl.create('CameraWebPage');
      popover.onDidDismiss(
          data => {
            alert(data);
          }
      );
      popover.present();         
    } else*/ {
      this.barcodeScanner.scan({
        orientation: 'landscape',
        resultDisplayDuration: 0
      }).then(barcodeData => {
        if(this.validarBoleto(barcodeData.text)){
          this.param.barras = barcodeData.text;
          this.vencimentoBarrasDigitavel();
        } else {
          alert("Código de barras inválido");
        }
       }).catch(err => {
           console.log('Error', err);
           this.loader.showError("Ops", "Seu aparelho não esta habilitado para ler código de barras de bancos");
       });
    }
  }

  validarBoletoBanco(bol){
    return (boletoBancario(bol.toString()));
  }

  padLeft(text:string, padChar:string, size:number): string {
    return (String(padChar).repeat(size) + text).substr( (size * -1), size) ;
  }

  validarBoleto(bol){
    return (boleto(bol.toString()));
  }

  validarBoletoArrecadacao(bol){
    return (boletoArrecadacao(bol.toString()));
  }

  vencimentoBarrasDigitavel(){
    if(this.validarBoleto(this.param.barras)){
      if(this.validarBoletoArrecadacao(this.param.barras)){
        let tam = this.param.barras.length;
        let identificacaoSegmento = this.param.barras.substr(1, 1);
        
        let valor = tam == 44 ? this.param.barras.substr(4, 11) : this.param.barras.substr(4, 7) + this.param.barras.substr(12, 4);
        let tamanhoValor = parseInt(valor).toString().length;
        let valorFinal = parseInt(valor).toString();        
        this.param.valorDocumento = valorFinal.substr(0, tamanhoValor-2)+"."+valorFinal.substr(tamanhoValor-2, tamanhoValor);
        this.tipoBoleto = this.padraoArrecadacao(parseInt(identificacaoSegmento));
      } else {
        this.tipoBoleto = "Boleto bancário";
        var linhaDigitavel = this.param.barras;
        if(linhaDigitavel.length == 44){
          this.param.banco = linhaDigitavel.substr(0, 3);
          this.param.agencia = linhaDigitavel.substr(20, 4);
          this.param.beneficiario = linhaDigitavel.substr(26, 7);
          this.param.nossoNumero =  linhaDigitavel.substr(34, 7);
          
          var dias = parseInt(linhaDigitavel.substr(5, 4)); // captura 6075 
      
          // Meses são indexados em zero em JavaScript, logo é necessário subtrair 1 do mês desejado.
          var dataInicialFebraban = new Date(1997, 10 - 1, 7);    
          var outraData = new Date(dataInicialFebraban.getTime());
          outraData.setDate(dataInicialFebraban.getDate() + dias);    
          let dia: any = outraData.getDate();
          let mes: any = outraData.getMonth()+1;
          
          let a: any;
          a = outraData.getFullYear() + "-" + this.padLeft(mes,'0', 2) + "-" + this.padLeft(dia,'0', 2) ;
          this.param.vencimento = a;
          
          var tamanhoPreco = linhaDigitavel.substr(9, 10).toString().length;    
          
          this.param.valorDocumento = parseFloat(linhaDigitavel.substr(9, 10)
          .substr(0, tamanhoPreco-2))+'.'+parseFloat(linhaDigitavel.substr(9, 10)
          .substr(tamanhoPreco-2, tamanhoPreco));
          this.consultarContas();
        } else {
          this.param.banco = linhaDigitavel.substr(0, 3);
          this.param.agencia = linhaDigitavel.substr(5, 4);
          this.param.beneficiario = linhaDigitavel.substr(12, 7);
          this.param.nossoNumero =  linhaDigitavel.substr(21, 7);
          
          var dias = parseInt(linhaDigitavel.substr(33, 4)); // captura 6075 
    
          // Meses são indexados em zero em JavaScript, logo é necessário subtrair 1 do mês desejado.
          var dataInicialFebraban = new Date(1997, 10 - 1, 7);    
          var outraData = new Date(dataInicialFebraban.getTime());
          outraData.setDate(dataInicialFebraban.getDate() + dias);    
          let a: any;
          let dia: any = outraData.getDate();
          let mes: any = outraData.getMonth()+1;
          
          
          a = outraData.getFullYear() + "-" + this.padLeft(mes,'0', 2) + "-" + this.padLeft(dia,'0', 2) ;
          this.param.vencimento = a;
          
          var tamanhoPreco = linhaDigitavel.substr(37, 10).toString().length;    
          
          this.param.valorDocumento = parseFloat(linhaDigitavel.substr(37, 10)
          .substr(0, tamanhoPreco-2))+'.'+parseFloat(linhaDigitavel.substr(37, 10)
          .substr(tamanhoPreco-2, tamanhoPreco));
          this.consultarContas();
        }
        
      }

    } else {
      alert("Código de barras inválido");
    }
    
  }

  /*filtroMasterFornecedorPage(){
    this.param.fornecedor = "";
    let profileModal = this.modalCtrl.create('FiltroMaterFornecedorPage', { params: "contasPagar" }, {enableBackdropDismiss: false});
    profileModal.onDidDismiss(data => {      
      if(data.length > 0 ){        
        this.param.fornecedor = data[0]['CODFORN'];
        this.param.filtroFornecedor = data[0]['NOME'];
        this.param.tipo = data[0]['SIGLA'];
      }
    });    
    profileModal.present();
    // this.navCtrl.push('FiltroMaterFornecedorPage', {});
  }

  filtroMasterLojaPage(){
    this.param.loja = "";    
    let profileModal = this.modalCtrl.create('FiltroMasterLojaPage', {}, {enableBackdropDismiss: false});
    profileModal.onDidDismiss(data => {
      if (data.length >0){
        this.param.loja = data[0]['CODIGO'];
        this.param.filtroLoja = data[0]['NOME'];
      }
    });    
    profileModal.present();
    // this.navCtrl.push('FiltroMaterFornecedorPage', {});
  }*/

  salvarConta(){
    if(this.param.loja == "" || this.param.fornecedor == "" || this.param.valorDocumento == ""){      
      this.loader.showError("Atenção", "Preencha os campos corretamente");
    } else {
      this.param.valorDocumento = this.param.valorDocumento.replace(",",".");
      
      this.loader.showLoader("Aguarde, salvando a informação...");
      this.financeiro.criarContasPagar(this.param)
      .then((result: any) => {
        this.param.pedido = result;
        this.loader.hideLoader();        
        this.alertConfirm();        
      })
      .catch((error: any) => {
        this.loader.hideLoader();
        this.loader.showError("Ops", error);
      });
    }
  }

  async abrirTelaLoja() {
    const modal = await this.modalController.create({
      component: ParametrosComponent,
      componentProps: {
        "lojas": true,
        "artigo": false,
        "grupo": false,
        "marca": false,
        "fornecedor": false,
        "dataInicial": false,
        "dataFinal": false,
        "colecao": false,
        "data": false,
        "genero": false,
        "documento": false
      },
      backdropDismiss: false,      
    });

    modal.onDidDismiss().then((res) => {
      if (res !== null) {              
        this.param.filtroLoja = res.data.lj;
        this.param.loja = res.data.lj;
        // this.parametro = res.data;
      }
    });
    return await modal.present();        
  }

  async abrirTelaGenerica(tela) {
    const modal = await this.modalController.create({
      component: TelaGenericaComponent,
      componentProps: {
        tela: 'fornecedores', parametro: 'contasPagar'
      },
      backdropDismiss: false,      
    });

    modal.onDidDismiss().then((res) => {
      if (res !== null) {      
        // console.log(res);
        this.param.fornecedor = res.data.CODIGO;
        this.param.filtroFornecedor = res.data.DESCRICAO;
        this.param.tipo = res.data.TIPO;                 
        // this.parametro = res.data;
      }
    });
    return await modal.present();        
  }

  consultarContas(){
    this.financeiro.consultarContasForn(this.param)
      .then((result: any) => {
        for (let i = 0; i < result.length; i++) {
          const element = result[i];
          this.param.fornecedor = element.CODFORN;
          this.param.filtroFornecedor = element.NOME;
          this.param.tipo = element.SIGLA;          
        }
      })
      .catch((error: any) => {
        console.log('error: '+error);
      });
  }

  padraoArrecadacao(codigo){    
    switch (codigo) {
      case 1:
        return ("Prefeituras");        
      case 2:
        return ("Saneamento");
      case 3:
        return ("Energia Elétrica e Gás");
      case 4:
        return ("Telecomunicações");
      case 5:
        return ("Órgãos Governamentais");
      case 6:
        return ("Carnes e Assemelhados ou demais Empresas / Órgãos que serão identificadas através do CNPJ");
      case 7:
        return ("Multas de trânsito");
      case 9:
        return ("Uso exclusivo do banco");
      default:
        return ("Sem valor");
    }
  } 

}
