import { Component, ElementRef, OnInit, ViewChild } from '@angular/core';
import { BarcodeScanner } from '@ionic-native/barcode-scanner/ngx';
import { Camera, CameraOptions } from '@ionic-native/camera/ngx';
import { ActionSheetController } from '@ionic/angular';
import { AuthServiceService } from '../../providers/auth-service.service';
import { EstoqueLojasService } from '../../providers/estoque-lojas.service';
import { LoaderService } from '../../providers/loader.service';

@Component({
  selector: 'app-cadastro-grupos',
  templateUrl: './cadastro-grupos.page.html',
  styleUrls: ['./cadastro-grupos.page.scss'],
})
export class CadastroGruposPage implements OnInit {
  @ViewChild('pwaphoto', { static: true }) pwaphoto: ElementRef;
  public Parametro: any = {
    id: "",
    artigos: [],
    marcas: [],
    foto: '',
    nomeTabela: 'GRUP01',
    valorChave: ''
  }

  cameraEAN: boolean = true;
  
  filtroPesquisa: any = 'referencia';
  codigoProcurar: any = '';

  clickedImagePath:any;
  products: any[] = [];
  selectedProduct: any;
  productFound:boolean = false;
  codprod = "";

  options: CameraOptions = {
    quality: 80,
    destinationType: this.camera.DestinationType.DATA_URL,
    encodingType: this.camera.EncodingType.JPEG,
    mediaType: this.camera.MediaType.PICTURE,
    cameraDirection:0,  
    allowEdit: false,
    correctOrientation: true,
    saveToPhotoAlbum: false,
    targetWidth: 800,
    targetHeight: 800
  }

  gelleryOptions: CameraOptions = {
    quality: 80,
    sourceType: this.camera.PictureSourceType.PHOTOLIBRARY,
    destinationType: this.camera.DestinationType.DATA_URL,
    encodingType: this.camera.EncodingType.JPEG,
    allowEdit: false,
    correctOrientation: true,
    saveToPhotoAlbum: false,
    targetWidth: 800,
    targetHeight: 800
  }
  valores: any;
  public grupos: any = [];
  constructor(public rel_estoque: EstoqueLojasService, public auth: AuthServiceService, 
    public load: LoaderService, public actionSheetCtrl: ActionSheetController,
    private barcodeScanner: BarcodeScanner, public camera: Camera, public loader: LoaderService ) { 
    this.Parametro.id = this.auth.Id;
    this.pesquisarGrupos();
  }

  ngOnInit() {
  }

  public pesquisarGrupos(){
    this.load.showLoader("Aguarde, consultando o produto...");    
    this.rel_estoque.buscarGrupoCatalogo(this.Parametro).then((result: any) => {
        this.load.hideLoader();        
        this.grupos = result;        
      }).catch((error: any) => {
        this.load.hideLoader();       
        this.load.showError('Ops', 'O seu servidor pode esta sem internet no momento, tente novamente mais tarde.');
      });          
  }

  uploadPWA() {

    if (this.pwaphoto == null) {
      return;
    }

    const fileList: FileList = this.pwaphoto.nativeElement.files;

    if (fileList && fileList.length > 0) {
      this.resizeImage(fileList[0], 400, 400).then((resultado) => {        
        this.Parametro.foto = resultado;
        this.Parametro.id = this.auth.Id;
        // this.Parametro.valorChave = this.codprod;
        this.enviarImgServer();        
      });
    }
  }

  resizeImage(file:File, maxWidth:number, maxHeight:number):Promise<any> {
    return new Promise((resolve, reject) => {
        let image = new Image();
        image.src = URL.createObjectURL(file);
        image.onload = () => {
            let width = image.width;
            let height = image.height;

            let newWidth;
            let newHeight;
						let canvas = document.createElement('canvas');
            
            if (width <= maxWidth && height <= maxHeight) {
            		canvas.width = width;
            		canvas.height = height;
                let context2 = canvas.getContext('2d');
            		context2.drawImage(image, 0, 0, width, height);						       		                
                resolve((""+canvas.toDataURL('image/jpeg')));
            } else {
              if (width > height) {
                  newHeight = height * (maxWidth / width);
                  newWidth = maxWidth;
              } else {
                  newWidth = width * (maxHeight / height);
                  newHeight = maxHeight;
              }
              
              canvas.width = newWidth;
              canvas.height = newHeight;
  
              let context = canvas.getContext('2d');
  
              context.drawImage(image, 0, 0, newWidth, newHeight);
  
              // canvas.toBlob(resolve, file.type);
              resolve(""+canvas.toDataURL('image/jpeg'));
            }                       
        };
        image.onerror = reject;
    });
  }

  async presentActionSheet(item) { 
    console.log(item);
    this.Parametro.valorChave = item.GRUPO;
    if(this.auth.modeloCelular == "ios" || this.auth.modeloCelular == ""){
      this.pwaphoto.nativeElement.click();
    } else {
      const actionSheet = await this.actionSheetCtrl.create({        
        header: 'Escolher foto',
        buttons: [
          {
            text: 'Arquivo',
            role: 'destructive',
            handler: () => {            
              this.abrirGeleria(item);
            }
          },{
            text: 'Tirar foto',
            handler: () => {            
              this.addFoto(item);
            }
          },{
            text: 'Cancelar',
            role: 'cancel',
            handler: () => {
              console.log('Cancel clicked');
            }
          }
        ]
      });
      await actionSheet.present();
    }
  }

  abrirGeleria(item) {    
    this.camera.getPicture(this.gelleryOptions).then((imgData) => {      
      let base64Image = 'data:image/jpeg;base64,' + imgData;
      this.Parametro.foto = base64Image;
      this.Parametro.id = this.auth.Id;
      this.Parametro.valorChave = item.GRUPO;
      this.enviarImgServer();
    }, (err) => {
      console.log(err);
    })
  }

  addFoto(item){
    
    this.camera.getPicture(this.options).then((imageData) => {      
    let base64Image = 'data:image/jpeg;base64,' + imageData;
    this.Parametro.foto = base64Image;
    this.Parametro.id = this.auth.Id;
    this.Parametro.valorChave = item.GRUPO;
    // alert(base64Image)
    this.enviarImgServer();
    }, (err) => {
      alert("Erro: "+ err);
    });     
  }

  
  enviarImgServer(){
    // console.log(this.Parametro);
    this.loader.showLoader("Enviando foto para o servidor...");
    this.rel_estoque.inserirFotoAleatoriaNovo(this.Parametro).then((result: any) => {
      this.loader.hideLoader();
      this.loader.presentToast('Foto inserida com sucesso!');      
      this.pesquisarGrupos();
    }).catch((error: any) => {
      this.loader.hideLoader();
        //console.log('error: '+error);
      this.loader.showError('Ops', 'O seu servidor pode esta sem internet no momento, tente novamente mais tarde.');
    });
  }

}
