import { format, parseISO } from 'date-fns';
import { Component, OnInit, ViewChild } from '@angular/core';
import { ActionSheetController, AlertController, IonDatetime, PopoverController } from '@ionic/angular';
import { AuthServiceService } from '../../providers/auth-service.service';

import { LoaderService } from '../../providers/loader.service';
import { VendasLojasService } from '../../providers/vendas-lojas.service';
import { VendedoresLojasService } from '../../providers/vendedores-lojas.service';
import { Router } from '@angular/router';

@Component({
  selector: 'app-cadastro-manutencao-vendas',
  templateUrl: './cadastro-manutencao-vendas.page.html',
  styleUrls: ['./cadastro-manutencao-vendas.page.scss'],
})
export class CadastroManutencaoVendasPage implements OnInit {
  @ViewChild(IonDatetime, { static: true }) datetime: IonDatetime;
  filtroPesquisaVendedor: any = 'pedido';
  codigoProcurar: any = '';
  tipoDocumento: any = [];
  pedi01: any = {
    "id": "",
    "pedido": "",
    "old_vendedor": "",
    "new_vendedor": "",
    "old_usuario": "",
    "new_usuario": "",
    "old_data": "",
    "new_data": "",
    "old_desconto": 0,
    "new_desconto": "",
    "old_bruto": 0,
    "new_bruto": "",
    "nomeVend": "",
    "nomeOperador": "",
    "liquido": 0,
    "codLoja": "",
    "usuarioLogado": ""
  };

  rece01array: any = {
    "id": "",
    "pedido": "",
    "parcela": "",
    "tipodoc": "",
    "tipodoc_old": "",    
    "usuarioLogado": ""
  };
  rece01: any = "";
  movi01: any = "";
  vendedores: any = [];
  Parametro = {
    id: '',
    codigo: '',
    parametro: '',
    usuario: '',
    foto: '',
    nomeTabela: '',
    valorChave: ''
  }
  encontrou: boolean = false;
  vendas: any = [];
  maxDate: any;
  minDate: any;
  dataAtual = new Date().toISOString();
  // customPickerOptions: any;
  constructor(public alertController: AlertController,
    public vendasLojas: VendasLojasService, public loader: LoaderService, public vend: VendedoresLojasService,
    public auth: AuthServiceService, public popoverController: PopoverController, 
    public actionSheetController: ActionSheetController, public router: Router) { 
      
    var d = new Date();
    var year = d.getFullYear();
    var month = d.getMonth();
    var day = d.getDate();
    var c = new Date(year + 1, month, day);
    var d = new Date(year - 1, month, day);    
    this.maxDate = c.getFullYear()+'-'+(c.getMonth()+1).toString().padStart(2,'0')+'-'+c.getDate().toString().padStart(2,'0');
    this.minDate = d.getFullYear()+'-'+(d.getMonth()+1).toString().padStart(2,'0')+'-'+d.getDate().toString().padStart(2,'0');    
  }

  ngOnInit() {
  }

  async presentActionSheet(pedido) {
    const actionSheet = await this.actionSheetController.create({
      header: 'Cancelar a venda',
      cssClass: 'my-custom-class',
      buttons: [{
        text: 'Deletar',
        role: 'destructive',
        icon: 'trash',
        id: 'delete-button',
        data: {
          type: 'delete'
        },
        handler: () => {
          this.cancelarVenda(pedido)
        }
      }, {
        text: 'Cancelar',
        icon: 'close',
        role: 'cancel',
        handler: () => {
          console.log('Cancel clicked');
        }
      }]
    });
    await actionSheet.present();

    const { role, data } = await actionSheet.onDidDismiss();
    console.log('onDidDismiss resolved with role and data', role, data);
  }

  cancelarVenda(pedi01){
    this.loader.showLoader('Enviando o cancelamento...');    
    this.vendasLojas.cancelarVenda(pedi01).then((result: any) => {
      this.loader.hideLoader();            
      this.loader.presentToast("Cancelamento efetuado com sucesso!");                     
      this.router.navigateByUrl('/app/tabs/schedule');
    }).catch((error: any) => {
      this.loader.hideLoader();
    }); 
  }

  formatDate(value: string, formato: string) {
    return format(parseISO(value), formato/*'yyyy-MM-dd'*/);
  }

  escolherData(e){
    this.pedi01.new_data = this.formatDate(e, 'yyyy-MM-dd');
    this.popoverController.dismiss();
    this.atualizarPedido();          
  }

  segmentChanged(ev: any) {}

  atualizarPedido(){
    this.pedi01.id = this.auth.Id;    
    this.pedi01.usuarioLogado = this.auth.Usuario.codigo;
    this.loader.showLoader("Atualizando o pedido...");
    // console.log(this.pedi01);
    this.vendasLojas.manutencaoDeVendasUpdate(this.pedi01)
    .then((result: any) => {
      this.loader.hideLoader();
      // console.log(result);
      if(result.length == 0){
        this.loader.presentToast("Ops! Não encontrei nada!");
      }               
      this.pesquisarVenda();      
    }).catch((error: any) => {
      this.loader.hideLoader();
    }); 
  }

  

  pesquisarVenda(){
    this.Parametro.codigo = this.codigoProcurar; 
    this.Parametro.parametro = this.filtroPesquisaVendedor; 
    this.encontrou = false;   
    if(this.Parametro.codigo == ''){
      return this.loader.showError('Atenção!', 'Digite alguma coisa para fazer a pesquisa');
    } 
    this.vendas = [];
    this.loader.showLoader("Buscando o pedido...");
    this.vendasLojas.manutencaoDeVendas(this.Parametro)
    .then((result: any) => {
      console.log(result);
      this.loader.hideLoader();
      if(result.pedi01 == false){
        this.loader.presentToast("Ops! Não encontrei nada!");
      } else {
        this.encontrou = true;      
        this.vendas = result;      
        this.pedi01.pedido = result['pedi01']['pedido'];
        
        this.pedi01.new_vendedor = '';
        this.pedi01.new_data = '';
        this.pedi01.new_usuario = '';
        this.pedi01.new_desconto = '';

        this.pedi01.old_vendedor = result['pedi01']['vendedor'];
        this.pedi01.old_data = (result['pedi01']['data']);
        this.pedi01.old_usuario = result['pedi01']['operador'];
        this.pedi01.old_desconto = result['pedi01']['desconto'];
        this.pedi01.old_bruto = result['pedi01']['bruto'];
        this.pedi01.nomeVend = result['pedi01']['nomeVend'];
        this.pedi01.nomeOperador = result['pedi01']['nomeOperador'];
        this.pedi01.nomeCliente = result['pedi01']['nomeCliente'];
        this.pedi01.codLoja = result['pedi01']['codloja'];
        this.pedi01.liquido = result['pedi01']['bruto'] - result['pedi01']['desconto'];
        this.pedi01.old_data.substring(5,7)
        
        this.rece01 = result['rece01'];
        this.movi01 = result['movi01'];
        let mes: any = (parseInt(this.pedi01.old_data.substring(5,7))-1).toString().padStart(2,'0');                
        this.dataAtual = this.formatDate(new Date(this.pedi01.old_data.substring(0,4), mes, this.pedi01.old_data.substring(8,10), 0, 0, 0, 0).toISOString(), 'yyyy-MM-dd');
      }
      
    }).catch((error: any) => {
      this.loader.hideLoader();
    });  
  }

  pesquisarVendedor(){
    this.loader.showLoader("Consultando vendedores");
    this.vend.pesquisarVendedoresPorLoja(this.pedi01['codLoja'])
    .then((result: any) => {      
      this.loader.hideLoader();      
      this.vendedores = [];      
      if(result.length == 0){
        this.loader.presentToast("Ops! Não encontrei nada!");
      } else {
        for (let i = 0; i < result.length; i++) {
          const element = result[i];
          this.vendedores.push({
            name: element.VENDEDOR,
            type: 'radio',
            label: element.VENDEDOR +' '+ element.NOMEVEND,
            value: element.VENDEDOR
          })
        }
        this.presentAlertRadio(this.vendedores, 'vendedor', '');
        
      }
    }).catch((error: any) => {
      this.loader.hideLoader();
    }); 
  }

  pesquisarTipoDocumento(pedido){
    console.log(pedido);
    this.loader.showLoader("Consultando documentos");
    this.Parametro.id = this.auth.Id;
    this.vendasLojas.buscarTipoDocumento(this.Parametro)
    .then((result: any) => {      
      this.loader.hideLoader();      
      this.tipoDocumento = [];      
      if(result.length == 0){
        this.loader.presentToast("Ops! Não encontrei nada!");
      } else {
        for (let i = 0; i < result.length; i++) {
          const element = result[i];
          this.tipoDocumento.push({
            name: element.CODIGO,
            type: 'radio',
            label: element.DESCRICAO,
            value: element.CODIGO
          })
        }
        this.presentAlertRadio(this.tipoDocumento, 'documento', pedido);
      }
    }).catch((error: any) => {
      this.loader.hideLoader();
    }); 
  }

  pesquisarOperador(){
    this.loader.showLoader("Consultando operadores");
    this.Parametro.id = this.auth.Id;
    this.auth.consultarTodosUsuarios(this.Parametro)
    .then((result: any) => {      
      this.loader.hideLoader();      
      this.vendedores = [];      
      if(result.length == 0){
        this.loader.presentToast("Ops! Não encontrei nada!");
      } else {
        for (let i = 0; i < result.length; i++) {
          const element = result[i];
          this.vendedores.push({
            name: element.CODIGO,
            type: 'radio',
            label: element.CODIGO +' '+ element.NOME,
            value: element.CODIGO
          })
        }
        this.presentAlertRadio(this.vendedores, 'operador', '');
      }
    }).catch((error: any) => {
      this.loader.hideLoader();
    }); 
  }

  valuechange(newValue) {
    if(newValue.key == 'Enter' || newValue.keyCode == 13 || newValue.keyIdentifier == 'Enter'){
      this.pesquisarVenda();
    }    
  }

  buscar2(v, v2){
    this.pesquisarTipoDocumento(v2);
  }

  buscar(v){
    // console.log(v);
    if(v == 'vendedor'){
      this.pesquisarVendedor();        
    }
    if(v == 'operador'){
      this.pesquisarOperador();        
    }
  }

  add_years(dt,n) {
    return new Date(dt.setFullYear(dt.getFullYear() + n));
  }

  async presentAlertRadio(array, tipo, pedido) {
    //console.log(array);
    const alert = await this.alertController.create({
      cssClass: 'my-custom-class',
      header: tipo,
      inputs: array,
      buttons: [
        {
          text: 'Cancelar',
          role: 'cancel',
          cssClass: 'secondary',
          handler: () => {
            console.log('Confirm Cancel');
          }
        }, {
          text: 'Confirmar',
          handler: (a) => {
            console.log(a);
            if(tipo == 'operador'){
              this.pedi01.new_usuario = a;
              this.atualizarPedido();
            } else if(tipo == 'documento'){
              //console.log(a);
              this.atualizarRece01(a, pedido);
            } else {
              this.pedi01.new_vendedor = a;
              this.atualizarPedido();
            }
          }
        }
      ]
    });
    await alert.present();
  }

  atualizarRece01(tipodoc, pedido){
    this.rece01array.id = this.auth.Id;        
    this.rece01array.usuarioLogado = this.auth.Usuario.codigo;
    this.rece01array.pedido = pedido.PEDIDO;
    this.rece01array.parcela = pedido.PARCELA;
    this.rece01array.tipodoc = tipodoc;
    this.rece01array.tipodoc_old = pedido.TIPODOC;
    console.log(this.rece01array);
    
    this.loader.showLoader("Atualizando o documento...");    
    this.vendasLojas.manutencaoDeReceUpdate(this.rece01array).then((result: any) => {
      this.loader.hideLoader();
      // console.log(result);
      if(result.length == 0){
        this.loader.presentToast("Ops! Não encontrei nada!");
      }               
      this.pesquisarVenda();      
    }).catch((error: any) => {
      this.loader.hideLoader();
    });     
  }
  
}
