import { Component, ElementRef, OnInit, ViewChild } from '@angular/core';
import { ModalController } from '@ionic/angular';
import { ParametrosComponent } from '../../modal/parametros/parametros.component';
import { AuthServiceService } from '../../providers/auth-service.service';
import { EstoqueLojasService } from '../../providers/estoque-lojas.service';
import { LoaderService } from '../../providers/loader.service';
import { VendedoresLojasService } from '../../providers/vendedores-lojas.service';

@Component({
  selector: 'app-cadastro-vendedores',
  templateUrl: './cadastro-vendedores.page.html',
  styleUrls: ['./cadastro-vendedores.page.scss'],
})
export class CadastroVendedoresPage implements OnInit {
  filtroPesquisaVendedor: any = 'codigo';
  codigoProcurar: any = '';
  vendedores = {
    vendedor: '',
    nomevend: '',
    lojavend: '',
    descloja: '',
    id: ''
  }
  temFoto: boolean = false;
    
  @ViewChild('pwaphoto', { static: true }) pwaphoto: ElementRef;
  
  obj: any;
  Parametro = {
    id: '',
    codigo: '',
    parametro: '',
    usuario: '',
    foto: '',
    nomeTabela: 'VEND01',
    valorChave: ''
  }
  constructor(public loader: LoaderService, public vendedoresL: VendedoresLojasService, 
    public auth: AuthServiceService, public modalController: ModalController, public rel_estoque: EstoqueLojasService) {
    this.Parametro.id = auth.Id;
    this.Parametro.usuario = auth.Usuario.codigo;
    this.vendedores.id = auth.Id;
   }

  ngOnInit() {
  }

  ngAfterViewInit() {    
    if (this.pwaphoto) {      
    }
  };

  addFoto(item) {        
      this.pwaphoto.nativeElement.click();
  }

  uploadPWA() {

    if (this.pwaphoto == null) {
      return;
    }

    const fileList: FileList = this.pwaphoto.nativeElement.files;

    if (fileList && fileList.length > 0) {
      this.resizeImage(fileList[0], 400, 400).then((resultado) => {        
        this.Parametro.foto = resultado;
        this.Parametro.id = this.auth.Id;        
        this.enviarImgServer();        
      });
    }
  }

  enviarImgServer(){
    this.rel_estoque.inserirFotoAleatoriaNovo(this.Parametro).then((result: any) => {      
      this.pesquisarVendedores();
    }).catch((error: any) => {
      this.Parametro.valorChave = this.vendedores.vendedor;
      this.codigoProcurar = this.vendedores.vendedor;
      this.filtroPesquisaVendedor = 'codigo';
      this.pesquisarVendedores();      
      // this.showAlertCodigoWinSAE('O seu servidor pode esta sem internet no momento, tente novamente mais tarde.');
    });
  }

  resizeImage(file:File, maxWidth:number, maxHeight:number):Promise<any> {
    return new Promise((resolve, reject) => {
        let image = new Image();
        image.src = URL.createObjectURL(file);
        image.onload = () => {
            let width = image.width;
            let height = image.height;

            let newWidth;
            let newHeight;
						let canvas = document.createElement('canvas');
            
            if (width <= maxWidth && height <= maxHeight) {
            		canvas.width = width;
            		canvas.height = height;
                let context2 = canvas.getContext('2d');
            		context2.drawImage(image, 0, 0, width, height);						       		                
                resolve((""+canvas.toDataURL('image/jpeg')));
            } else {
              if (width > height) {
                  newHeight = height * (maxWidth / width);
                  newWidth = maxWidth;
              } else {
                  newWidth = width * (maxHeight / height);
                  newHeight = maxHeight;
              }
              
              canvas.width = newWidth;
              canvas.height = newHeight;
  
              let context = canvas.getContext('2d');
  
              context.drawImage(image, 0, 0, newWidth, newHeight);
  
              // canvas.toBlob(resolve, file.type);
              resolve(""+canvas.toDataURL('image/jpeg'));
            }                       
        };
        image.onerror = reject;
    });
  }

  async openModal() {
    const modal = await this.modalController.create({
      component: ParametrosComponent,
      componentProps: {
        "lojas": true,
        "artigo": false,
        "grupo": false,
        "marca": false,
        "fornecedor": false,
        "dataInicial": false,
        "dataFinal": false,
        "colecao": false,
        "data": false,
        "genero": false,
        "parametro_retroativo": false,
        "somenteValores": false
      },
      backdropDismiss: false,      
    });

    modal.onDidDismiss().then((d :any) => {
      let data = d.data;
      if(data != undefined){        
        if(data.lj != ''){
          this.vendedores.lojavend = data.lj;
          this.salvarCadastro();
        }
      }      
    });

    return await modal.present();
  }

  alterarVendedor(v){
    this.vendedores.descloja = v.DESCLOJA;
    this.vendedores.lojavend = v.LOJAVEND;
    this.vendedores.nomevend = v.NOMEVEND;
    this.vendedores.vendedor = v.VENDEDOR;
    this.openModal();   
  }

  salvarCadastro(){
    this.loader.showLoader("Atualizando cadastro.");
    this.vendedoresL.atualizarLojaVendedores(this.vendedores)
    .then((result: any) => {

      this.loader.hideLoader();
      this.Parametro.valorChave = this.vendedores.vendedor;
      this.codigoProcurar = this.vendedores.vendedor;
      this.filtroPesquisaVendedor = 'codigo';
      this.pesquisarVendedores();
    })
    .catch((error: any) => {
      console.log('error: '+error);
      this.loader.hideLoader();
      this.loader.showError('Ops', 'O seu servidor pode esta sem internet no momento, tente novamente mais tarde.');
    });
  }

  segmentChanged(ev: any) {
    
  }

  valuechange(newValue) {
    if(newValue.key == 'Enter' || newValue.keyCode == 13 || newValue.keyIdentifier == 'Enter'){
      this.pesquisarVendedores();
    }    
  }

  pesquisarVendedores(){    
    this.Parametro.codigo = this.codigoProcurar; 
    this.Parametro.parametro = this.filtroPesquisaVendedor;
    if(this.codigoProcurar == ''){      
      this.loader.showError('Ops', 'Deve preencher com algum valor.');
    } else {
        this.loader.showLoader('Consultando vendedores');
        this.vendedoresL.pesquisarVendedores(this.Parametro)
        .then((result: any) => {
          this.loader.hideLoader();          
          // this.codigoProcurar = '';
          if(result == false && result != ''){
            this.loader.showError('Ops', 'Seu usuário não tem permissão para realizar essa consulta.');
          }
          else if(result == ''){
            this.loader.showError('Ops', 'Não encontrei nada.');
          } else {          
            for (let i = 0; i < result.length; i++) {
              const element = result[i];              
              this.vendedores.descloja = element.DESCLOJA;
              this.vendedores.lojavend = element.LOJAVEND;
              this.vendedores.nomevend = element.NOMEVEND;
              this.vendedores.vendedor = element.VENDEDOR;
              this.Parametro.valorChave = element.VENDEDOR;              
              this.temFoto = (element.FOTO.length < 30) ? false : true;
              
            }
            // console.log(this.vendedores.vendedor);
            this.obj = result;
          }
        })
        .catch((error: any) => {
          //console.log('error: '+error);
          this.loader.hideLoader();
          this.loader.showError('Ops', 'O seu servidor pode estar sem internet no momento, tente novamente mais tarde.');
        });
    }
  }

}
