import { Component, OnInit } from '@angular/core';
import { ClientesLojasService } from '../../providers/clientes-lojas.service';
import { LoaderService } from '../../providers/loader.service';
import * as HighCharts from 'highcharts';
import { ParametrosComponent } from '../../modal/parametros/parametros.component';
import { ModalController } from '@ionic/angular';


@Component({
  selector: 'app-clientes-fluxo',
  templateUrl: './clientes-fluxo.page.html',
  styleUrls: ['./clientes-fluxo.page.scss'],
})
export class ClientesFluxoPage implements OnInit {
  
  movimentacao: any = [];
  movimentacaoTota: any = [];
  mes: any;
  primeiroMes: any;
  naoCadastrouClientes: boolean = false;
  parametro = {
    id : '',
    data_inicial : '',
    data_final : '',
    loja: '%'
  }
  constructor(public clientes: ClientesLojasService, public loader: LoaderService, public modalController: ModalController) { 
    var date = new Date();
    var primeiroDia = new Date(date.getFullYear(), date.getMonth(), 1);
    this.primeiroMes = date.getMonth() + 1;
    var ultimoDia = new Date(date.getFullYear(), date.getMonth() + 1, 0);
    var a = date.getMonth() + 1;
    this.mes = ultimoDia.getMonth() + 1;        
    
    this.parametro.data_inicial = date.getFullYear()+'-'+this.padLeft(this.primeiroMes, '0', 2)+'-'+'01';
    this.parametro.data_final = ultimoDia.getFullYear()+'-'+this.padLeft(this.primeiroMes, '0', 2)+'-'+ultimoDia.getDate();    
  }

  ngOnInit() {
    this.buscarFluxo(this.parametro);
  }

  padLeft(text:string, padChar:string, size:number): string {
    return (String(padChar).repeat(size) + text).substr( (size * -1), size) ;
  }

  presentPopover(myEvent) {
    /*let popover = this.popoverCtrl.create('PopoverFiltroLojasPage');
    popover.present({
      ev: myEvent
    });
    popover.onDidDismiss(
        data => {            
            if(data != null){
              this.parametro.loja = data['lojavend'];
              if(data['DATA_INICIAL'] == "" || data['DATA_FINAL'] == ""){
                this.buscarFluxo(this.parametro);
              } else {
                this.parametro.data_inicial = data['DATA_INICIAL'];
                this.parametro.data_final = data['DATA_FINAL'];
                this.buscarFluxo(this.parametro);
              }
            }
        }
    );*/
  }

  async abrirParametros() {
    const modal = await this.modalController.create({
      component: ParametrosComponent,
      componentProps: {
        "lojas": true,
        "artigo": false,
        "grupo": false,
        "marca": false,
        "fornecedor": false,
        "dataInicial": true,
        "dataFinal": true,
        "colecao": false,
        "data": false,
        "genero": false,
        "documento": false,
        "minCompras": false,
        "ticketMedio": false

      },
      backdropDismiss: false,      
    });

    modal.onDidDismiss().then((res) => {
      if (res !== null) {        
        this.parametro.loja = res.data['lj'];
        if(res.data['dataInicial'] == "" || res.data['dataFinal'] == ""){
          this.buscarFluxo(this.parametro);
        } else {
          this.parametro.data_inicial = res.data['dataInicial'];
          this.parametro.data_final = res.data['dataFinal'];
          this.buscarFluxo(this.parametro);
        }
      }
    });
    return await modal.present();        
  }

  buscarFluxo(parametro){
    this.naoCadastrouClientes = false;
    this.movimentacaoTota = []; 
    this.movimentacao = [];      
    this.clientes.fluxoDeClientes(parametro)
    .then((result: any) => {      
      let ar = [];
      let categorias = [];
      let atendidos = [];
      let recebidos = [];
      let tx = [];
      for (let i = 0; i < result.length; i++) {
        const element = result[i];        
        categorias.push(element.DATA.substr(8,2));
        atendidos.push(+element.CLIENTES_FISICOS);
        recebidos.push(+element.CLIENTES_FINALIZADOS);
        tx.push( +((element.CLIENTES_FINALIZADOS/element.CLIENTES_FISICOS)*100).toFixed(2) );
        if(+element.CLIENTES_FISICOS == 0) {
          this.naoCadastrouClientes = true;
        }
      }
      ar.push({
        "name": "Atendidos",
        "data": atendidos,
        "color": "red"
      });
      ar.push({
        "name": "Convertidos",
        "data": recebidos,
        "color": "#488aff"
      });

      ar.push({
        type: 'spline',
        name: 'tx conversao',
        data: tx,
        marker: {
            lineWidth: 2,
            lineColor: 'black', // Highcharts.getOptions().colors[3],
            fillColor: '#a0a0a0'
        }
      })
      if(result.length == 0){
        this.loader.presentToast("Não existem informações para esses parâmetros!");
      } else {
        this.graf(ar, categorias);
      }
    })
    .catch((error: any) => {
        // this.loading.dismiss();
    console.log('error: '+error);
    });
  }

  graf(data, ar){
    HighCharts.chart('columnCliente', {        
        chart: {
            type: 'column',            
        },
        title: {
            text: 'Fluxo de Clientes'
        },
        subtitle: {
          text: 'Loja:' + this.parametro.loja + ' Período de ' + this.parametro.data_inicial + ' até ' + this.parametro.data_final
        },
        xAxis: {
          categories: ar,
          title: {
            text: 'Dias'
          },
        },
        yAxis: {
          min: 0,
          title: {
              text: 'Quantidade de Clientes'
          },
          stackLabels: {
              enabled: true,
              style: {
                  fontWeight: 'bold',
                  //color: 'red'// (Highcharts.theme && Highcharts.theme.textColor) || 'gray'
              }
          }
        },        
        tooltip: {
          headerFormat: '<b>Dia: {point.x}</b><br/>',
          pointFormat: '{series.name}: {point.y}<br/>'
        },
        /*plotOptions: {
          column: {
              stacking: 'normal',
              dataLabels: {
                  enabled: true,
                  // color: (Highcharts.theme && Highcharts.theme.dataLabelsColor) || 'white'
              }
          }
        },*/
        plotOptions: {
          column: {
              dataLabels: {
                  enabled: true
              }
          }
        },
        credits: {
            enabled: false
        },        
        series: data,        
      });            
  }

}
