import { Component, OnInit } from '@angular/core';
import { SocialSharing } from '@ionic-native/social-sharing/ngx';
import { ActionSheetController, ModalController } from '@ionic/angular';
import { element } from 'protractor';
import { ParametrosComponent } from '../../modal/parametros/parametros.component';
import { ClientesLojasService } from '../../providers/clientes-lojas.service';
import { LoaderService } from '../../providers/loader.service';

@Component({
  selector: 'app-clientes-melhores',
  templateUrl: './clientes-melhores.page.html',
  styleUrls: ['./clientes-melhores.page.scss'],
})
export class ClientesMelhoresPage implements OnInit {
  clientes: any;
  totalClientes = 0;
  parametro: any = {
    "dataInicial": "",
    "dataFinal": "",
    "percentual": 0
  };
  
  data = {
    "dataInicial": '',
    "dataFinal": '',
    "qtMinima": 2,
    "ticketMedio": 1,
    "qtMinimoItens": 1,
    "parametro": '',
    "codclie": '',
    "fornecedores" : [],
    "artigos" : [],
    "marcas": [],
    "grupos": [],
    "colecao": [],
    "loja": "",
    "DATA_INICIAL": "",
    "DATA_FINAL": "",
    "promocao": [],
    "documento": [],
    "tamanho": []    
  }
  constructor(public modalController: ModalController, public loader: LoaderService, 
    public clie: ClientesLojasService, public actionSheetController: ActionSheetController,
    public socialSharing: SocialSharing) { }

  ngOnInit() {
    let diaAtual = new Date();
    let mes : any = diaAtual.getMonth()+1;
    var ultimoDia = new Date(diaAtual.getFullYear(), diaAtual.getMonth() + 1, 0);
    
    this.data.dataInicial = diaAtual.getFullYear()+'-'+this.padLeft(mes, '0', 2)+'-01';
    this.data.dataFinal = diaAtual.getFullYear()+'-'+this.padLeft(mes, '0', 2)+'-'+ ultimoDia.getDate();    
    this.buscarDesempenhoClientes(this.data);
  }

  async abrirParametros() {
    const modal = await this.modalController.create({
      component: ParametrosComponent,
      componentProps: {
        "lojas": true,
        "artigo": false,
        "grupo": false,
        "marca": false,
        "fornecedor": false,
        "dataInicial": true,
        "dataFinal": true,
        "colecao": false,
        "data": false,
        "genero": false,
        "documento": false,
        "minCompras": true,
        "ticketMedio": true

      },
      backdropDismiss: false,      
    });

    modal.onDidDismiss().then((res) => {
      if (res !== null) {              
        // this.data = res.data;
        this.data.dataInicial = res.data.dataInicial;
        this.data.dataFinal = res.data.dataFinal;
        this.data.loja = res.data.lj;             
        this.buscarDesempenhoClientes(this.data);        
      }
    });
    return await modal.present();        
  }

  padLeft(text:string, padChar:string, size:number): string {
    return (String(padChar).repeat(size) + text).substr( (size * -1), size) ;
  }

  buscarDesempenhoClientes(data){
    this.clientes = []; 
    if(this.data.dataInicial == '' || this.data.dataFinal == ''){
      this.loader.showError("Ops!", "Preencha os campos de data corretamente");      
    } else {      
      this.loader.showLoader("Buscando vendas por cliente...");
      this.clie.vendasPorClientes(data)
      .then((result: any) => {
        if(this.data.loja == ''){
          this.data.loja = 'Todas';
        }
        this.loader.hideLoader();
          if(result.length == 0 ){
            this.loader.presentToast('Não encontrei nada.');
          }
          this.totalClientes = result.length;
          this.clientes = result;        
      })
      .catch((error: any) => {      
        this.loader.hideLoader();
        this.loader.showError("Ops!", error);                
      });
    }
  }

  detalhar(cliente){   
    // this.presentToast("Função em desenvolvimento");
    // this.navCtrl.push('DetalheMelhoresClientesPage', {data: cliente});
    this.presentActionSheet(cliente);
  }

  async presentActionSheet(cliente) {
    const actionSheet = await this.actionSheetController.create({
      header: 'Opções',
      cssClass: 'my-custom-class',
      backdropDismiss: false,
      translucent: true,      
      buttons: [{
        text: 'Enviar WhatsApp',
        role: 'destructive',
        icon: 'logo-whatsapp',
        handler: () => {
          // window.open("https://wa.me/"+cliente.TELE+"?text=Olá, "+cliente.NOME+".", "_blank");
          this.socialSharing.shareViaWhatsAppToPhone('+55'+cliente.TELE, "Olá, "+cliente.NOME+".", null, null).then((e) =>{
            console.log(e)
          }).catch((e) => {
            window.open("https://wa.me/"+cliente.TELE+"?text=Olá, "+cliente.NOME+".", "_blank");
          });
        }
      }, /*{
        text: 'Favorite',
        icon: 'heart',
        handler: () => {
          console.log('Favorite clicked');
        }
      }, */{
        text: 'Cancelar',
        icon: 'close',
        role: 'cancel',
        handler: () => {
          console.log('Cancel clicked');
        }
      }]
    });
    await actionSheet.present();

    const { role } = await actionSheet.onDidDismiss();
    console.log('onDidDismiss resolved with role', role);
  }

}
