import { Component, OnInit } from '@angular/core';
import { ModalController } from '@ionic/angular';
import { ParametrosComponent } from '../../modal/parametros/parametros.component';
import { AuthServiceService } from '../../providers/auth-service.service';
import { ClientesLojasService } from '../../providers/clientes-lojas.service';

import * as HighCharts from 'highcharts';

@Component({
  selector: 'app-clientes-qualidade',
  templateUrl: './clientes-qualidade.page.html',
  styleUrls: ['./clientes-qualidade.page.scss'],
})
export class ClientesQualidadePage implements OnInit {
  
  public data = {
    id : ""
  }
  sem_telefone: any = 0;
  com_telefone: any = 0;
  sem_valor: any = 0;
  ar: any = [];
  parametro: any =[];
  trintaDias: any = [];
  sessentaDias: any = [];
  noventaDias: any = [];
  centoOitentaDias: any = [];
  duzentosCinquentaDias: any = [];
  qtClientesComBonus: any = 0;
  constructor(public modalController: ModalController, public auth: AuthServiceService, public clientes: ClientesLojasService) { }

  ngOnInit() {
    this.trintaDias = [];
    this.sessentaDias = [];
    this.noventaDias = [];
    this.centoOitentaDias = []
    this.duzentosCinquentaDias = [];

    let diaAtual = new Date();
    let mes : any = diaAtual.getMonth()+1;
    var ultimoDia = new Date(diaAtual.getFullYear(), diaAtual.getMonth() + 1, 0);
    
    this.parametro.id = this.auth.Id;
    this.parametro.data_inicial = diaAtual.getFullYear()+'-'+this.padLeft(mes, '0', 2)+'-01';
    this.parametro.data_final = diaAtual.getFullYear()+'-'+this.padLeft(mes, '0', 2)+'-'+ ultimoDia.getDate();    
    this.parametro.loja = '';
    this.consultarQualidadeBase(this.parametro);
    this.clientesEmRisco();
    this.consultarBonusCliente();
  }

  async abrirParametros() {
    const modal = await this.modalController.create({
      component: ParametrosComponent,
      componentProps: {
        "lojas": true,
        "artigo": false,
        "grupo": false,
        "marca": false,
        "fornecedor": false,
        "dataInicial": true,
        "dataFinal": true,
        "colecao": false,
        "data": false,
        "genero": false,
        "documento": false,
        "minCompras": false,
        "ticketMedio": false

      },
      backdropDismiss: false,      
    });

    modal.onDidDismiss().then((res) => {
      if (res !== null) {        
        this.parametro.loja = res.data['lj'];
        this.parametro.id = this.auth.Id;
        this.parametro.data_inicial = res.data['dataInicial'];
        this.parametro.data_final = res.data['dataFinal'];      
        this.consultarQualidadeBase(this.parametro);        
      }
    });
    return await modal.present();        
  }

  padLeft(text:string, padChar:string, size:number): string {
    return (String(padChar).repeat(size) + text).substr( (size * -1), size) ;
  }

  ionViewDidLoad() {
    
  }

  trinta(){
    
  }

  sessenta(){
    
  }
  
  noventa(){
    
  }

  centoOitenta(){
    
  }

  duzentosCinquenta(){
    this.clientesBonus();
    
  }

  clientesEmRisco(){
    this.sem_valor = 0;
    this.clientes.consultarClientesSemComprar()
    .then((result: any) => {
        this.ar = [];        
        if(result.length > 0){
            for (let i = 0; i < result.length; i++) {
                const element = result[i];
                if(element.DIAS_SEM_COMPRAR >= 30 && element.DIAS_SEM_COMPRAR < 60){
                    this.trintaDias.push(element);
                } 
                if(element.DIAS_SEM_COMPRAR >= 60 && element.DIAS_SEM_COMPRAR < 90){
                    this.sessentaDias.push(element);
                }
                if(element.DIAS_SEM_COMPRAR >= 90 && element.DIAS_SEM_COMPRAR < 180){
                    this.noventaDias.push(element);
                }                
                if(element.DIAS_SEM_COMPRAR >= 180 && element.DIAS_SEM_COMPRAR < 250) {
                    this.centoOitentaDias.push(element);
                }
                if(element.DIAS_SEM_COMPRAR >= 250) {
                    this.duzentosCinquentaDias.push(element);
                }                
            }                
        } else {
            console.log("Não tem valor");
        }
    })
    .catch((error: any) => {
        console.log('error: '+error);
    });
  }

  whatsApp(){
    window.open("https://api.whatsapp.com/send?phone=5562981888263&text=Quero%20creditos%20para%20fazer%20marketing%20com%20meus%20clientes", "_system", "location=yes");
  }

  consultarBonusCliente(){
    this.clientes.consultarBonusCliente()
    .then((result: any) => {        
        if(result.length > 0){            
            this.qtClientesComBonus = result;            
        } else {
            console.log("Não tem valor");
        }
    })
    .catch((error: any) => {
        console.log('error: '+error);
    });
  }

  clientesBonus(){
    this.clientes.insertClientesMKT(this.duzentosCinquentaDias/*this.qtClientesComBonus*/)
    .then((result: any) => {        
        
    })
    .catch((error: any) => {
        console.log('error: '+error);
    });      
  }

  consultarQualidadeBase(params){
    this.sem_valor = 0;
    this.clientes.consultarQualidadeBaseClientes(params)
    .then((result: any) => {
        this.ar = [];        
        if(result.length > 0){
            for (let i = 0; i < result.length; i++) {
                const element = result[i];
                if(element.DADOS.trim() == 'sem_dados'){
                    this.sem_telefone = element.COUNT;
                    this.ar.push([element.COUNT+'<br> sem telefone', element.COUNT])
                } else {
                    this.com_telefone = element.COUNT;
                    this.ar.push([element.COUNT+'<br> com telefone', element.COUNT])
                }
            }
            this.sem_valor = 1;
            this.graf(this.ar);
            
        } else {
            console.log("Não tem valor");
        }
    })
    .catch((error: any) => {
        console.log('error: '+error);
    });
  }

  graf(ar){
    HighCharts.chart('columnQualidade', {
      chart: {
        plotBackgroundColor: null,
        plotBorderWidth: 0,
        plotShadow: false,
        type: 'pie',            
      },
    title: {
        text: 'Clientes<br>do<br>perído',
        align: 'center',
        verticalAlign: 'middle',
        y: 40
    },
    
    tooltip: {
        pointFormat: '{series.name}: <b>{point.percentage:.1f}%</b>'
    },
    plotOptions: {
        pie: {
            showInLegend: true,
            allowPointSelect: true,
            cursor: 'pointer',
            dataLabels: {
                enabled: true,
                distance: -50,
                style: {
                    fontWeight: 'bold',
                    color: 'white'
                }
            },
            startAngle: -90,
            endAngle: 90,
            center: ['50%', '75%'],
            size: '110%'
        }
    },
    series: [{
        type: 'pie',
        name: 'Valor: ',
        innerSize: '50%',        
        data: ar
    }]         
    });       
  }

  buscarGrafico(a){
    // this.graf();    
  }

}
