import { Component, OnInit } from '@angular/core';
import { ModalController } from '@ionic/angular';
import { ParametrosComponent } from '../../modal/parametros/parametros.component';
import { AuthServiceService } from '../../providers/auth-service.service';
import { LoaderService } from '../../providers/loader.service';
import { VendasLojasService } from '../../providers/vendas-lojas.service';

@Component({
  selector: 'app-comparativo-hora',
  templateUrl: './comparativo-hora.page.html',
  styleUrls: ['./comparativo-hora.page.scss'],
})
export class ComparativoHoraPage implements OnInit {
  mes: any;
  hoje: any;
  dia: any;
  vendas: any = [];
  v1Acumulado: number = 0;
  v2Acumulado: number = 0;
  array: any = [];
  data1: any = '';
  data2: any = '';
  lojas: any = 'Todas as lojas';
  hide: boolean = false;
  constructor(public loader: LoaderService, public vendasLojas: VendasLojasService, 
    public auth: AuthServiceService, public modalController: ModalController) { 
    let diaAtual = new Date();
    this.mes = diaAtual.getMonth()+1;
    this.hoje = diaAtual.getDate();
    this.dia = diaAtual.getFullYear()+'-'+this.padLeft(this.mes, '0', 2)+'-'+this.padLeft(this.hoje, '0', 2);
    // this.buscarComparativo();
    this.data1 = this.dia;
    this.data2 = (diaAtual.getFullYear()-1)+'-'+this.padLeft(this.mes, '0', 2)+'-'+this.padLeft(this.hoje, '0', 2);
    this.buscarResultado();
  }

  ngOnInit() {
  }

  padLeft(text:string, padChar:string, size:number): string {
    return (String(padChar).repeat(size) + text).substr( (size * -1), size) ;
  }

  data1Escolhida(e){
    let data = e.detail.value;
    // let ano = data.substring(8,10);
    // let date = new Date(ano, data.substring(5,7), data.substring(5,7), data.substring(8,10));
    // date.setFullYear(ano);
    // date.getDate()-365;
    // this.data2 = (date.getFullYear())+'-'+this.padLeft(''+date.getMonth()+1, '0', 2)+'-'+this.padLeft(''+date.getDate(), '0', 2);
  }

  buscarResultado(){
    let loja = '';
    if(this.auth.Usuario.somenteLojaLocal == true){
      loja = this.auth.Usuario.loja;
    }
    this.buscarComparativo(this.data1, this.data2, this.auth.Usuario.loja);
  }

  data2Escolhida(e){
    console.log(e.detail.value);
  }

  async openModal() {
    const modal = await this.modalController.create({
      component: ParametrosComponent,
      componentProps: {
        "lojas": true,
        "artigo": false,
        "grupo": false,
        "marca": false,
        "fornecedor": false,
        "dataInicial": false,
        "dataFinal": false,
        "colecao": false,
        "data": false,
        "genero": false,
        "data1": true,
        "data2": true
      },
      backdropDismiss: false,      
    });

    modal.onDidDismiss().then((res) => {
      if (res !== null) {         
        this.data1 = res.data.data1;
        this.data2 = res.data.data2;
        if(res.data.lj != ''){
          this.lojas = 'Loja selecionada '+res.data.lj
        } else {
          this.lojas = 'Todas as lojas'
        }
        this.buscarComparativo(res.data.data1, res.data.data2, res.data.lj)
      }
    });
    return await modal.present();
  }

  buscarComparativo(data1, data2, loja){
    this.vendas = [];
    let ar = { "data1": data1, "data2": data2 , "id": this.auth.Id, "loja": loja}
    this.v1Acumulado = 0;
    this.v2Acumulado = 0;    
    this.loader.showLoader("Buscando informações de vendas...");
    // console.log(ar);
    this.vendasLojas.comparativoVendasHoraDia(ar).then((result: any) => {      
      this.loader.hideLoader();
      // console.log(result);
      if(result.length == 0) {
        this.loader.presentToast('Não encontrei valores para esse período.');
      }
      this.array = [];
      for (let i = 0; i < result.length; i++) {
        const element = result[i];
        this.v1Acumulado = this.v1Acumulado + element.V1;
        this.v2Acumulado = this.v2Acumulado + element.V2;
        if(element.HORA != null)
        this.array.push({
          "HORA" : element.HORA,
          "D1" : element.D1,
          "D2" : element.D2,
          "Q1" : element.Q1,
          "Q2" : element.Q2,
          "V1" : element.V1,
          "V2" : element.V2,
          "V1ACUMULADO" : this.v1Acumulado,
          "V2ACUMULADO" : this.v2Acumulado,
          "CRESCIMENTO":  ((this.v1Acumulado/this.v2Acumulado)-1)*100
        })
      }
      // console.log(this.array);
    }).catch((error: any) => {
      this.loader.hideLoader();
    });
  }

}
