import { Component, ElementRef, OnInit, ViewChild } from '@angular/core';

import { AlertController } from '@ionic/angular';
import { AuthServiceService } from '../../providers/auth-service.service';
import { EstoqueLojasService } from '../../providers/estoque-lojas.service';
import { FinanceiroLojasService } from '../../providers/financeiro-lojas.service';
import { LoaderService } from '../../providers/loader.service';

import * as XLSX from 'xlsx';

@Component({
  selector: 'app-conferencia-cartao',
  templateUrl: '/conferencia-cartao.page.html',
  styleUrls: ['./conferencia-cartao.page.scss'],
})
export class ConferenciaCartaoPage implements OnInit {
  // @ViewChild('fileUploader', { static: true }) pwaphoto: ElementRef;
  @ViewChild('fileUploader') fileUploader:ElementRef;
  array = [];
  totalBruto = 0;
  totalLiquido = 0;
  totalTaxa = 0;
  valorTitulo = 0;
  valorTarifa = 0;
  valorJuros = 0;
  valorRecebido = 0;
  total = 0;
  baixaAutomatica: any = [];
  dados: boolean = false;
  extensaoArquivo: any = "";

  lojaEscolhida: any = "";
  lojas: boolean = false;
  arrayLojas: any = [];

  adquirente: any = "";

  parametro = {
    lj : "",
    adquirente: "",
    parametro: [],   
    idConexao: this.auth.Id         
  };

  constructor(public auth: AuthServiceService, 
    public financeiro: FinanceiroLojasService, public loader: LoaderService,
    public estoqueLojas: EstoqueLojasService, public alertCtrl: AlertController) { 
    
  }
  ngOnInit() {
    
  }

  async buscarAdquirentes() {
    const alert = await this.alertCtrl.create({
      cssClass: 'my-custom-class',
      header: 'Adquirentes',
      inputs: [
        {
          name: 'Cielo',
          type: 'radio',
          label: 'Cielo',
          value: 'cielo',
          handler: (e) => {
            this.adquirente = e.value;
            this.parametro.adquirente = e.value;
          },
        }
      ],
      buttons: [
        {
          text: 'Ok',
          handler: () => {
            console.log('Confirmar');
          },
        },
      ],
    });

    await alert.present();
  }

  async buscarLojas() {
    this.loader.showLoader('Buscando informações no servidor.');
    this.estoqueLojas.buscarLojas()
    .then((result: any) => {      
      this.loader.hideLoader();
      for (let i = 0; i < result.length; i++) {
        const element = result[i];
        this.arrayLojas.push({
          name: element.CODLOJA,
          type: 'radio',          
          label: element.CODLOJA+" - "+element.DESCLOJA,
          value: element.CODLOJA          
        });                
      }
      if(this.arrayLojas.length > 0){
        this.escolherLojas();
      }
    })
    .catch((error: any) => {
      this.loader.hideLoader();
      console.log('error: '+error);
    });
  }

  async enviarArquivoAdquirente() {
    this.loader.showLoader('Enviando informações para o servidor.');
    this.auth.arquivoAdquirente(this.parametro)
    .then((result: any) => {      
      this.loader.hideLoader();
      
      for (let i = 0; i < result.length; i++) {
        const element = result[i];
        this.totalBruto = this.totalBruto + element['valorParcela'];
        this.totalTaxa = this.totalTaxa + element['valorTaxa'];
      }
      this.loader.presentToast('Dados enviados com sucesso!');
    })
    .catch((error: any) => {
      this.loader.hideLoader();
      console.log('error: '+error);
    });
  }

  async escolherLojas(){
    const alert = await this.alertCtrl.create({
      header: 'Lojas',
      inputs: this.arrayLojas,
      buttons: [
        {
          text: 'Cancelar',
          role: 'cancel',
          cssClass: 'secondary',
          handler: () => {
            console.log('Confirm Cancel');
          }
        }, {
          text: 'Escolher',
          handler: (data) => {
            console.log(data);
            this.parametro.lj = data;            
          }
        }
      ]
    });
    await alert.present();
  }

  uploadPWA(e: any) {
    this.extensaoArquivo = e.target.files[0].name.split('.').pop();
    if(e.target.files.length !== 1){
      this.loader.showError("Atenção", "Não use mais de um arquivo");
    } else if(this.extensaoArquivo != "xls"){
      this.loader.showError("Atenção", "A extensão do arquivo tem que ser XLS (Excel)")
    } else {
      const reader: FileReader = new FileReader();
      reader.readAsBinaryString(e.target.files[0]);
      reader.onload = (e:any) => {
        const binarystr: string = e.target.result;
        const wb: XLSX.WorkBook = XLSX.read(binarystr, {type: 'binary'});
  
        const wsname: string = wb.SheetNames[0];
        const ws:XLSX.WorkSheet = wb.Sheets[wsname];
  
        const data = XLSX.utils.sheet_to_json(ws);
        let teste1 = false;
        let teste2 = false;
        let teste3 = false;
        for (let i = 0; i < data.length; i++) {
          const element = data[i];          
          if(element['__EMPTY'] == "Data da venda"){
            teste1 = true;
          }
          else if((teste1 == true)){
            this.array.push({
              "dataVenda" : element['__EMPTY'],
              "bandeira" : element['__EMPTY_1'],
              "formaPagamento" : element['__EMPTY_2'],
              "qtParcelas" : element['__EMPTY_3'],
              "resumoOperacao" : element['__EMPTY_4'],
              "valorVenda" : element['__EMPTY_5'],
              "percentualTaxa" : element['__EMPTY_6'],
              "valorTaxa" : element['__EMPTY_7'],
              "dataPagamento" : element['__EMPTY_8'],
              "valorRecebimento" : element['__EMPTY_9'],
              "canalPagamento" : element['__EMPTY_10'],
              "numeroLogico" : element['__EMPTY_11'],
              "codigoVenda" : element['__EMPTY_12'],
              "codigoAutorizacao" : element['__EMPTY_13'],
              "nsu" : element['__EMPTY_14'],
              "numeroCartao" : element['__EMPTY_15'],
              "recebaRapido" : element['__EMPTY_16'],
              "comissaoMinima" : element['__EMPTY_17'],
              "notaFiscal" : element['__EMPTY_18'],
              "status" : element['__EMPTY_19'],
            });
          } else if(i > 2 && (teste1 == false || teste2 == false || teste3 == false)){
            this.loader.showError("Atenção", "O leiaute do arquivo não esta correto.")
            break;
          }
        }
        
        if(this.array.length == 0){
          this.loader.showError("Atenção", "O leiaute do arquivo não esta correto.")
        } else {
          this.parametro.parametro = this.array;
          this.enviarArquivoAdquirente();
        }
      }
      this.fileUploader.nativeElement.value = null;
    }
  }


}
