import { Component, OnInit } from '@angular/core';
import { Router } from '@angular/router';
import { BarcodeScanner } from '@ionic-native/barcode-scanner/ngx';
import { AlertController, ModalController } from '@ionic/angular';
import { LerBarrasComponent } from '../../modal/ler-barras/ler-barras.component';
import { AuthServiceService } from '../../providers/auth-service.service';
import { LoaderService } from '../../providers/loader.service';
import { VendasLojasService } from '../../providers/vendas-lojas.service';

@Component({
  selector: 'app-shopee',
  templateUrl: './correios.page.html',
  styleUrls: ['./correios.page.scss'],
})
export class CorreiosPage implements OnInit {
  selectedProduct: any;
  codigoProcurar: any = "";
  public Parametro = {
    idPedi01CPL: '',
    codigo: '',
    pedido: '',
    idPedido: '',
    idConexao: '',
    correios: '',
    status: '',
    modulo: '',
    campo: ''
  }
  lista: any = [];
  constructor(public alertController: AlertController, private barcodeScanner: BarcodeScanner, 
    public modalController: ModalController, private router: Router, public loader: LoaderService,
    public auth: AuthServiceService, public preVenda: VendasLojasService) { }

  ngOnInit() {
    
  }

  ionViewDidEnter() {
    this.buscarVendas();
  }

  buscarVendas(){
    this.lista = [];
    this.loader.showLoader('Consultando vendas...');
    let parametro = {"idConexao" : this.auth.Id};
    this.preVenda.consutarCorreios(parametro)
    .then((result: any) => {
      this.loader.hideLoader();
      this.lista = result;
    })
    .catch((error: any) => {
      this.loader.hideLoader();
      console.log('error: '+error);
    });
  }

  async lerBarras() {
    const modal = await this.modalController.create({
      component: LerBarrasComponent,
      componentProps: {        
      },
      backdropDismiss: false,      
    });

    modal.onDidDismiss().then((res) => {            
      if(res.data != ''){
        this.codigoProcurar = res.data;        
      }
    });

    return await modal.present();
  }

  back(){        
    this.router.navigateByUrl('/vendas');    
  }

  lerEtiqueta(){
    this.selectedProduct = {};
    this.barcodeScanner.scan().then((barcodeData) => {
      this.codigoProcurar = barcodeData.text;
      this.Parametro.codigo = this.codigoProcurar;
    }, (err) => {
      this.lerBarras();
    });
  }

  async addCorreios(ped) {
    const alert = await this.alertController.create({
      cssClass: 'my-custom-class',
      header: 'Código de rastreio para',
      subHeader: ped.CIDADE+'/'+ped.UF,
      inputs: [
        {
          name: 'correios',
          type: 'text',
          placeholder: 'Código de rastreio'
        }
      ],
      buttons: [
        {
          text: 'Cancelar',
          role: 'cancel',
          cssClass: 'secondary',
          handler: () => {
            console.log('Confirm Cancel');
          }
        }, {
          text: 'Confirmar',
          handler: (c) => {
            this.codigoProcurar = c.correios;
            ped.VALOR = c.correios;
            this.Parametro.idConexao = this.auth.Id;
            this.Parametro.correios = c.correios;
            this.Parametro.pedido = ped.PEDIDO;
            this.Parametro.idPedido = ped.PEDIDOORIGEM;
            this.Parametro.idPedi01CPL = ped.ID;
            this.Parametro.modulo = 'CORREIOS';
            this.Parametro.campo = 'RASTREIO';
            this.inserirRastreio(this.Parametro);
          }
        }
      ]
    });

    await alert.present();
  }

  inserirRastreio(parametro){
    this.lista = [];
    this.loader.showLoader('Inserindo código de rastreio...');    
    this.preVenda.inserirCorreios(parametro).then((result: any) => {
      this.loader.hideLoader();
      console.log(result);
      this.buscarVendas();
    })
    .catch((error: any) => {
      this.loader.hideLoader();
      console.log('error: '+error);
    });
  }


  

}
