import { Component, OnInit } from '@angular/core';
import { ActivatedRoute } from '@angular/router';
import { ModalController } from '@ionic/angular';
import { ParametrosComponent } from '../../modal/parametros/parametros.component';
import { EstoqueLojasService } from '../../providers/estoque-lojas.service';
import { LoaderService } from '../../providers/loader.service';

@Component({
  selector: 'app-estoque-consultar-detalhe',
  templateUrl: './estoque-consultar-detalhe.page.html',
  styleUrls: ['./estoque-consultar-detalhe.page.scss'],
})
export class EstoqueConsultarDetalhePage implements OnInit {
  codprod: any = "";
  detalheItem: any = [];

  Ent_compra = 0;
  Ent_Transf = 0;
  Ent_troca = 0;
  Ent_Balanco = 0;

  Sai_Venda = 0;
  Sai_Transf = 0;
  Sai_Delv_Fab = 0;
  fraseLojas: any = "";  
  loja: any = "";
  
  

  constructor(private route: ActivatedRoute, public loader: LoaderService, public estoque: EstoqueLojasService, public modalController: ModalController) { }

  ngOnInit() {
    const data = this.route.snapshot.paramMap.get('codigo');
    this.codprod = data;
    if(data != ''){
      this.consultarMovimentacaoEstoque(data, '');
    }    
  }
  
  async openModal() {
    const modal = await this.modalController.create({
      component: ParametrosComponent,
      componentProps: {
        "lojas": true,
        "artigo": false,
        "grupo": false,
        "marca": false,
        "fornecedor": false,
        "dataInicial": false,
        "dataFinal": false,
        "colecao": false,
        "data": false,
        "genero": false
      },
      backdropDismiss: false,      
    });

    modal.onDidDismiss().then((res) => {
      if (res !== null) {      
        this.fraseLojas = res.data.lj;
        this.loja = res.data.lj;
        this.fraseLojas = "";
        this.consultarMovimentacaoEstoque(this.codprod, res.data.lj);
      }
    });
    return await modal.present();
  }

  consultarMovimentacaoEstoque(codprod, loja){
    this.detalheItem = [];
    this.loader.showLoader("Buscando detalhe do produto...");
    this.estoque.movimentacaoEstoque(codprod, loja)
    .then((result: any) => {
      this.loader.hideLoader();
      
        this.detalheItem = (result);
        this.Ent_compra = 0;
        this.Ent_Transf = 0;
        this.Ent_troca = 0;
        this.Ent_Balanco = 0;
  
        this.Sai_Venda = 0;
        this.Sai_Transf = 0;
        this.Sai_Delv_Fab = 0;
        for (let i = 0; i < result.length; i++) {
          const element = result[i];
          if(element.ENT_COMPRA > 0){
            this.Ent_compra = this.Ent_compra + element.ENT_COMPRA;
          }
          if(element.ENT_TRANSF > 0){
            this.Ent_Transf = this.Ent_Transf + element.ENT_TRANSF;
          }
          if(element.ENT_TROCA > 0){
            this.Ent_troca = this.Ent_troca + element.ENT_TROCA;
          }
          if(element.ENT_BALANCO > 0){
            this.Ent_Balanco = this.Ent_Balanco + element.ENT_BALANCO;
          }
          if(element.SAI_VENDA > 0){
            this.Sai_Venda = this.Sai_Venda + element.SAI_VENDA;
          }      
          if(element.SAI_TRANSF > 0){
            this.Sai_Transf = this.Sai_Transf + element.SAI_TRANSF;
          }
          if(element.SAI_DELV_FAB > 0){
            this.Sai_Delv_Fab = this.Sai_Delv_Fab + element.SAI_DELV_FAB;
          }
        }
    })
    .catch((error: any) => {
      /*
      this.loading.dismiss();
      this.loading.onDidDismiss(() => {        
        alert(error);
      });
      */
    });
  }

}
