import { Component, OnInit } from '@angular/core';
import { ModalController } from '@ionic/angular';
import { ParametrosComponent } from '../../modal/parametros/parametros.component';
import { EstoqueLojasService } from '../../providers/estoque-lojas.service';
import { LoaderService } from '../../providers/loader.service';

@Component({
  selector: 'app-estoque-curva-abc',
  templateUrl: './estoque-curva-abc.page.html',
  styleUrls: ['./estoque-curva-abc.page.scss'],
})
export class EstoqueCurvaAbcPage implements OnInit {
  data :any = {
    dataInicial: '',
    dataFinal: '',
    loja: '',
    parametro: '',
    QUANTIDADE: 10
  }
  artigos: any = [];
  marcas: any = [];
  grupos: any = [];
  tamanhos: any = [];
  constructor(public estoque: EstoqueLojasService, public loader: LoaderService, public modalController: ModalController) { }

  ngOnInit() {
    let diaAtual = new Date();
    let mes : any = diaAtual.getMonth()+1;
    var ultimoDia = new Date(diaAtual.getFullYear(), diaAtual.getMonth() + 1, 0);
    
    this.data.dataInicial = diaAtual.getFullYear()+'-'+this.padLeft(mes, '0', 2)+'-01';
    this.data.dataFinal = diaAtual.getFullYear()+'-'+this.padLeft(mes, '0', 2)+'-'+ ultimoDia.getDate();
    this.detalheVendasPorArtigos(this.data);
    this.detalheVendasPorGrupos(this.data);
    this.detalheVendasPorMarcas(this.data);
  }

  padLeft(text:string, padChar:string, size:number): string {
    return (String(padChar).repeat(size) + text).substr( (size * -1), size) ;
  }

  detalheVendasPorArtigos(data){    
    this.estoque.detalheVendasPorArtigos(data)
    .then((result: any) => {      
      if(result.length != 0){     
        var sum = result.reduce( function( prevVal, elem ) {
          return prevVal + elem.VL;
        }, 0 );     
        var acum = 0;
        var arr = result.map(function(num) { 
          var CURVA = 'A';
          var COLOR = '#d4fbca';
          acum = acum + (num.VL/sum)*100;          
          if(acum > 80 && acum < 95){
            CURVA = 'B'
            COLOR = '#dfecf3'
          } else if(acum >= 95){
            CURVA = 'C'
            COLOR = '#ffcda2'
          }
          return { ARTIGO: num.ARTIGO, QT: num.QT, VL: num.VL, PORCENTEGEM: (num.VL/sum)*100, ACUMULADO: acum,
          CURVA: CURVA, COLOR: COLOR };
        });
        this.artigos = [];   
        this.artigos = arr;        
      } else {        
        this.loader.presentToast("Não encontrei nada!")
      }
    })
    .catch((error: any) => {
      console.log('error: '+error);
    });
  }
  
  detalheVendasPorGrupos(data){
    this.estoque.detalheVendasPorGrupos(this.data).then((result: any) => {      
      if(result.length != 0){        
        var sum = result.reduce( function( prevVal, elem ) {
          return prevVal + elem.VL;
        }, 0 );     
        var acum = 0;
        var arr = result.map(function(num) { 
          var CURVA = 'A';
          var COLOR = '#d4fbca';
          acum = acum + (num.VL/sum)*100;          
          if(acum > 80 && acum < 95){
            CURVA = 'B'
            COLOR = '#dfecf3'
          } else if(acum >= 95){
            CURVA = 'C'
            COLOR = '#ffcda2'
          }
          return { GRUPO: num.GRUPO, QT: num.QT, VL: num.VL, PORCENTEGEM: (num.VL/sum)*100, ACUMULADO: acum,
          CURVA: CURVA, COLOR: COLOR };
        });
        this.grupos = [];   
        this.grupos = arr;   
      } else {        
        this.loader.presentToast("Não encontrei nada!")
      }
    })
    .catch((error: any) => {
      console.log('error: '+error);
    });
  }
  
  detalheVendasPorMarcas(data){
    this.estoque.detalheVendasPorMarcas(this.data).then((result: any) => { 
      if(result.length != 0){     
        var sum = result.reduce( function( prevVal, elem ) {
          return prevVal + elem.VL;
        }, 0 );     
        var acum = 0;
        var arr = result.map(function(num) { 
          var CURVA = 'A';
          var COLOR = 'danger';
          acum = acum + (num.VL/sum)*100;          
          if(acum > 80 && acum < 95){
            CURVA = 'B'
            COLOR = 'primary'
          } else if(acum >= 95){
            CURVA = 'C'
            COLOR = 'secondary'
          }
          return { MARCA: num.MARCA, QT: num.QT, VL: num.VL, PORCENTEGEM: (num.VL/sum)*100, ACUMULADO: acum,
          CURVA: CURVA, COLOR: COLOR };
        });
        this.marcas = [];   
        this.marcas = arr;        
      } else {        
        this.loader.presentToast("Não encontrei nada!")
      }
    })
    .catch((error: any) => {
      console.log('error: '+error);
    });
  }
  detalheVendasPorTamanhos(data){
    this.estoque.detalheVendasPorTamanhos(this.data).then((result: any) => {      
      if(result.length != 0){     
        this.tamanhos = [];   
        var tamanho = result.length < this.data.QUANTIDADE ? result.length : this.data.QUANTIDADE;        
        for (let i = 0; i < tamanho; i++) {
          const element = result[i];            
          this.tamanhos.push(element);          
        }            
      } else {        
        this.loader.presentToast("Não encontrei nada!")
      }
    })
    .catch((error: any) => {
      console.log('error: '+error);
    });
  }

  async openModal() {
    const modal = await this.modalController.create({
      component: ParametrosComponent,
      componentProps: {
        "lojas": false,
        "artigo": false,
        "grupo": false,
        "marca": false,
        "fornecedor": false,
        "dataInicial": true,
        "dataFinal": true,
        "colecao": false,
        "data": false,
        "genero": false
      },
      backdropDismiss: false,      
    });

    modal.onDidDismiss().then((res) => {      
      // console.log(res);
      if (res !== null) {
        this.data.dataInicial = res.data['dataInicial'];
        this.data.dataFinal = res.data['dataFinal'];        
        this.detalheVendasPorArtigos(this.data);
        this.detalheVendasPorGrupos(this.data);
        this.detalheVendasPorMarcas(this.data);
        this.detalheVendasPorTamanhos(this.data);   
      }
    });

    return await modal.present();
  }

}
