import { Component, OnInit } from '@angular/core';
import { NavigationExtras, Router } from '@angular/router';
import { ModalController, Platform } from '@ionic/angular';
import { ParametrosComponent } from '../../modal/parametros/parametros.component';
import { EstoqueLojasService } from '../../providers/estoque-lojas.service';
import { LoaderService } from '../../providers/loader.service';
import { ActionSheetController } from '@ionic/angular';
import { FileOpener } from '@ionic-native/file-opener/ngx';
import { File } from '@ionic-native/file/ngx';
import { saveAs } from 'file-saver';
import { FileSaverOptions } from "file-saver";

@Component({
  selector: 'app-estoque-entradas',
  templateUrl: './estoque-entradas.page.html',
  styleUrls: ['./estoque-entradas.page.scss'],
})
export class EstoqueEntradasPage implements OnInit {

  parametro = {
    id : '',
    data_inicial : '',
    data_final : '',
    referencia: '',
    nf: '',
    chave: ''
  }
  quantidadeEstoque: number = 0;
  valorEstoque: number = 0;

  estoque: any;
  mes: any;
  plataforma: any = '';
  constructor(public estoqueP: EstoqueLojasService, public loader: LoaderService, 
    public modalController: ModalController, private router: Router, 
    public actionSheetController: ActionSheetController,
    private opener: FileOpener,
    private file: File,
    public platform: Platform) { 
      
    }

  ngOnInit() {
    var date = new Date();
    var primeiroDia = new Date(date.getFullYear(), date.getMonth(), 1);
    var ultimoDia = new Date(date.getFullYear(), date.getMonth() + 1, 0);
    var a = date.getMonth() + 1;
    this.mes = ultimoDia.getMonth() + 1;
    
    this.parametro.data_inicial = date.getFullYear()+'-'+this.padLeft(this.mes, '0', 2)+'-'+'01';
    this.parametro.data_final = date.getFullYear()+'-'+this.padLeft(this.mes, '0', 2)+'-'+ultimoDia.getDate();
    
    this.buscarEntradas(this.parametro);
  }

  padLeft(text:string, padChar:string, size:number): string {
    return (String(padChar).repeat(size) + text).substr( (size * -1), size) ;
  }

  async openModal() {
    const modal = await this.modalController.create({
      component: ParametrosComponent,
      componentProps: {
        "lojas": false,
        "artigo": false,
        "grupo": false,
        "marca": false,
        "fornecedor": false,
        "dataInicial": true,
        "dataFinal": true,
        "colecao": false,
        "data": false,
        "genero": false
      },
      backdropDismiss: false,      
    });

    modal.onDidDismiss().then((res) => {            
      if (res !== null) {
        this.parametro.data_inicial = res.data.dataInicial;
        this.parametro.data_final = res.data.dataFinal;
        this.parametro.referencia = res.data.referencia;
        this.parametro.nf = res.data.nf;
        if(res.data.dataInicial == '' || res.data.dataFinal == ''){
          this.loader.showError("Ops!", "Preencha os campos de data corretamente");
        } else {
        this.buscarEntradas(this.parametro);
        } 
      }
    });

    return await modal.present();
  }

  itemSelected(item){    
    // this.navCtrl.push('DetalheEntradasEstoquePage', {item});    
    let navigationExtras: NavigationExtras = {
      queryParams: {
        special: JSON.stringify({"PEDIDO": item.PEDIDO, "NOME": item.NOME, "NUMERO_NOTA": item.NUMERO_NOTA})
      }
    };
    
    this.router.navigate(['/app/tabs/map/estoque-entradas-detalhe'], navigationExtras);
  }

  async presentActionSheet(pedido) {    
    const actionSheet = await this.actionSheetController.create({
      header: 'O que fazer?',      
      buttons: [{
        text: 'Baixar o PDF',
        icon: 'document-outline',
        handler: () => {
          console.log('Play clicked');
          this.parametro.chave = pedido.NFE_CHAVE;
          this.downloadPDF(this.parametro);
        }
      }, {
        text: 'Detalhar',
        icon: 'pricetags-outline',
        handler: () => {
          this.itemSelected(pedido);
          console.log('Favorite clicked');
        }
      }, {
        text: 'Cancelar',
        icon: 'close',
        role: 'cancel',
        handler: () => {
          console.log('Cancel clicked');
        }
      }]
    });
    await actionSheet.present();

    const { role } = await actionSheet.onDidDismiss();
    console.log('onDidDismiss resolved with role', role);
  }

  downloadPDF(parametro){    
    this.loader.showLoader("Download do PDF...");    
    this.estoqueP.downloadNF(parametro)
    .then((result: any) => {
      this.loader.hideLoader();      
        if(result.length == 0 || result == 'false' || result == false){
          this.loader.presentToast("Não encontrei o XML de entrada para fazer o download!");
        } else {
          this.saveAndOpenPdf(result.caminho, this.parametro.chave+'-NF.pdf');
        }
      })
      .catch((error: any) => {
        this.loader.hideLoader();       
        console.log(error);    
        this.loader.showError("Ops", error);        
      });
  }

  saveAndOpenPdf(pdf: string, filename: string) {    
    for (let i = 0; i < this.platform.platforms().length; i++) {
      const element = this.platform.platforms()[i];
      // console.log(element);
      if(element == 'desktop' || element == 'mobileweb' || element == 'pwa'){
        this.plataforma = 'desktop';
      } 
      if(element == 'android'){
        this.plataforma = 'celular';
      }
    }
    if(this.plataforma == 'desktop'){
      let blob = this.convertBase64ToBlob(pdf, 'data:application/pdf;base64');
      const options: FileSaverOptions = {
        autoBom: false
      };
      saveAs(blob, filename, options);      
    } else {
      const writeDirectory = this.platform.is('ios') ? this.file.dataDirectory : this.file.externalDataDirectory;
      // alert(writeDirectory);
      this.file.writeFile(writeDirectory, filename, this.convertBase64ToBlob(pdf, 'data:application/pdf;base64'), {replace: true})
        .then((e) => {
        this.opener.open(writeDirectory + filename, 'application/pdf').catch(() => {
          console.log('Error opening pdf file');
        });
      }).catch(() => {
        console.error('Error writing pdf file');
      });
    }        
  }
    
  convertBase64ToBlob(b64Data, contentType): Blob {
    contentType = contentType || '';
    const sliceSize = 512;
    b64Data = b64Data.replace(/^[^,]+,/, '');
    b64Data = b64Data.replace(/\s/g, '');
    const byteCharacters = window.atob(b64Data);
    const byteArrays = [];
    for (let offset = 0; offset < byteCharacters.length; offset += sliceSize) {
         const slice = byteCharacters.slice(offset, offset + sliceSize);
         const byteNumbers = new Array(slice.length);
         for (let i = 0; i < slice.length; i++) {
             byteNumbers[i] = slice.charCodeAt(i);
         }
         const byteArray = new Uint8Array(byteNumbers);
         byteArrays.push(byteArray);
    }
    return new Blob(byteArrays, {type: contentType});
  }

  buscarEntradas(parametro){
    this.estoque = [];
    this.loader.showLoader("Buscando entradas...");    
    this.estoqueP.buscarEntradas(parametro)
    .then((result: any) => {
      this.estoque = result;
      for (let i = 0; i < result.length; i++) {
        const element = result[i];
        this.quantidadeEstoque += element.QUANTIDADE;
        this.valorEstoque += element.VALOR_NOTA;
      }
      this.loader.hideLoader();      
        if(result.length == 0){
          this.loader.presentToast("Não encontrei nada!");          
        }      
      })
      .catch((error: any) => {
        this.loader.hideLoader();       
        console.log(error);    
        this.loader.showError("Ops", error);        
      });
  }

}
