import { Component, ElementRef, OnInit, ViewChild } from '@angular/core';
import { BarcodeScanner } from '@ionic-native/barcode-scanner/ngx';
import { Camera, CameraOptions } from '@ionic-native/camera/ngx';
import { ActionSheetController, ModalController } from '@ionic/angular';
import { LerBarrasComponent } from '../../modal/ler-barras/ler-barras.component';
import { AuthServiceService } from '../../providers/auth-service.service';
import { EstoqueLojasService } from '../../providers/estoque-lojas.service';
import { LoaderService } from '../../providers/loader.service';

@Component({
  selector: 'app-estoque-minimo',
  templateUrl: './estoque-minimo.page.html',
  styleUrls: ['./estoque-minimo.page.scss'],
})
export class EstoqueMinimoPage implements OnInit {
  public obj: any;
  @ViewChild('pwaphoto', { static: true }) pwaphoto: ElementRef;

  public Parametro = {
    id: '',
    codigo: '',
    parametro: '',
    foto: '',
    codprod: ''
  }

  cameraEAN: boolean = true;
  
  filtroPesquisa: any = 'referencia';
  codigoProcurar: any = '';

  semFoto: any = "assets/imgs/semImagem.jpg";
  
  clickedImagePath:any;
  products: any[] = [];
  selectedProduct: any;
  productFound:boolean = false;
  codprod = "";

  options: CameraOptions = {
    quality: 100,
    destinationType: this.camera.DestinationType.DATA_URL,
    encodingType: this.camera.EncodingType.JPEG,
    mediaType: this.camera.MediaType.PICTURE,
    cameraDirection:0,  
    allowEdit: false,
    correctOrientation: true,
    saveToPhotoAlbum: false,
    targetWidth: 1000,
    targetHeight: 1000
  }

  gelleryOptions: CameraOptions = {
    quality: 100,
    sourceType: this.camera.PictureSourceType.PHOTOLIBRARY,
    destinationType: this.camera.DestinationType.DATA_URL,
    encodingType: this.camera.EncodingType.JPEG,
    allowEdit: false,
    correctOrientation: true,
    saveToPhotoAlbum: false,
    targetWidth: 1000,
    targetHeight: 1000
  }
  constructor(public auth: AuthServiceService, public actionSheetCtrl: ActionSheetController,
    private barcodeScanner: BarcodeScanner, public loader: LoaderService, 
    public rel_estoque: EstoqueLojasService, public camera: Camera, public modalController: ModalController) { }

  ngOnInit() {
  }

  async lerBarras() {
    const modal = await this.modalController.create({
      component: LerBarrasComponent,
      componentProps: {        
      },
      backdropDismiss: false,      
    });

    modal.onDidDismiss().then((res) => {            
      if(res.data != ''){
        if(res.data.length == 8){
          this.filtroPesquisa = 'codigo_winsae';
        } else {
          this.filtroPesquisa = 'ean';
        }
        this.codigoProcurar = res.data;
        this.pesquisarProduto();
      }
    });

    return await modal.present();
  }

  lerEtiqueta(){
    this.selectedProduct = {};
    this.barcodeScanner.scan().then((barcodeData) => {
      this.codigoProcurar = barcodeData.text;
      this.Parametro.codigo = this.codigoProcurar; 
      this.Parametro.parametro = this.filtroPesquisa;  
      if(barcodeData.text.length == 8){
        this.filtroPesquisa = 'codigo_winsae';
      } else {
        this.filtroPesquisa = 'ean';
      }      
      this.pesquisarProduto();
    }, (err) => {
      this.lerBarras();
    });
  }

  valuechange(newValue) {
    if(newValue.key == 'Enter' || newValue.keyCode == 13 || newValue.keyIdentifier == 'Enter'){
      this.pesquisarProduto();
    }    
  }

  

 /*
  movimentacaoItem(item){    
    let profileModal = this.modalCtrl.create('HistoricoProdutosPage', {"codprod": item});
    profileModal.onDidDismiss(data => {      
      console.log(data);
    });    
    profileModal.present(); 
  }  */

  uploadPWA() {

    if (this.pwaphoto == null) {
      return;
    }

    const fileList: FileList = this.pwaphoto.nativeElement.files;

    if (fileList && fileList.length > 0) {
      this.resizeImage(fileList[0], 1000, 1000).then((resultado) => {        
        this.Parametro.foto = resultado;
        this.Parametro.id = this.auth.Id;
        this.Parametro.codprod = this.codprod;
        this.enviarImgServer();        
      });
    }
  }

  resizeImage(file:File, maxWidth:number, maxHeight:number):Promise<any> {
    return new Promise((resolve, reject) => {
        let image = new Image();
        image.src = URL.createObjectURL(file);
        image.onload = () => {
            let width = image.width;
            let height = image.height;

            let newWidth;
            let newHeight;
						let canvas = document.createElement('canvas');
            
            if (width <= maxWidth && height <= maxHeight) {
            		canvas.width = width;
            		canvas.height = height;
                let context2 = canvas.getContext('2d');
            		context2.drawImage(image, 0, 0, width, height);						       		                
                resolve((""+canvas.toDataURL('image/jpeg')));
            } else {
              if (width > height) {
                  newHeight = height * (maxWidth / width);
                  newWidth = maxWidth;
              } else {
                  newWidth = width * (maxHeight / height);
                  newHeight = maxHeight;
              }
              
              canvas.width = newWidth;
              canvas.height = newHeight;
  
              let context = canvas.getContext('2d');
  
              context.drawImage(image, 0, 0, newWidth, newHeight);
  
              // canvas.toBlob(resolve, file.type);
              resolve(""+canvas.toDataURL('image/jpeg'));
            }                       
        };
        image.onerror = reject;
    });
  }

  async presentActionSheet(item) {
    this.codprod = item.CODPROD;
    if(this.auth.modeloCelular == "ios" || this.auth.modeloCelular == ""){
      this.pwaphoto.nativeElement.click();
    } else {
      const actionSheet = await this.actionSheetCtrl.create({        
        header: 'Escolher foto',
        buttons: [
          {
            text: 'Arquivo',
            role: 'destructive',
            handler: () => {            
              this.abrirGeleria(item);
            }
          },{
            text: 'Tirar foto',
            handler: () => {            
              this.addFoto(item);
            }
          },{
            text: 'Cancelar',
            role: 'cancel',
            handler: () => {
              console.log('Cancel clicked');
            }
          }
        ]
      });
      await actionSheet.present();
    }
  }
  
  padLeft(text:string, padChar:string, size:number): string {
    return (String(padChar).repeat(size) + text).substr( (size * -1), size) ;
  }
  
  ionViewDidLoad() {
    console.log('ionViewDidLoad ProdutosEstoquePage');    
  }

  scan() {
    this.selectedProduct = {};
    this.barcodeScanner.scan().then((barcodeData) => {
      this.codigoProcurar = barcodeData.text;
      if(barcodeData.text.length == 8){
        this.filtroPesquisa = 'codigo_winsae';
      } else {
        this.filtroPesquisa = 'ean';
      }      
      this.pesquisarProduto();
    }, (err) => {
      alert(err);
    });
  }

  public pesquisarProduto(){
    this.Parametro.id = this.auth.Id;
    this.Parametro.codigo = this.codigoProcurar; 
    this.Parametro.parametro = this.filtroPesquisa;
    if(this.codigoProcurar == ''){
      this.loader.showError('Ops', 'Deve preencher com algum valor.');
    } else {
      if(this.filtroPesquisa == 'codigo_winsae' && this.codigoProcurar.length < 5){
        //this.loading.dismiss();
        //this.showAlertCodigoWinSAE('Esse campo deve ter no mínimo 5 até 8 caracteres.');
        this.Parametro.codigo = this.padLeft(this.Parametro.codigo,"0",5);
      }  
      this.loader.showLoader("Consultando produto...");
      this.rel_estoque.buscarEstoquep(this.Parametro).then((result: any) => {
        this.loader.hideLoader();
        const grouped = this.groupBy(result, codigo => codigo.CODPROD);
        let array = Array.from(grouped, ([name, value]) => ({ name, value }));
        this.obj = array;
        if(this.obj == ''){
          this.loader.showError('Ops', 'Não encontrei nada.');
        }
      }).catch((error: any) => {
        this.loader.hideLoader();
        this.loader.showError('Ops', 'O seu servidor pode esta sem internet no momento, tente novamente mais tarde.');
      });      
    }
  }

  itemSelected(item){    
  }

  groupBy(list, keyGetter) {
    const map = new Map();
    list.forEach((item) => {
         const CODPROD = keyGetter(item);
         const collection = map.get(CODPROD);
         if (!collection) {
             map.set(CODPROD, [item]);
         } else {
             collection.push(item);
         }
    });
    return map;
}

  abrirGeleria(item) {
    this.camera.getPicture(this.gelleryOptions).then((imgData) => {      
      let base64Image = 'data:image/jpeg;base64,' + imgData;
      this.Parametro.foto = base64Image;
      this.Parametro.id = this.auth.Id;
      this.Parametro.codprod = item.CODPROD;      
      this.enviarImgServer();
    }, (err) => {
      console.log(err);
    })
  }

  addFoto(item){
    this.camera.getPicture(this.options).then((imageData) => {      
    let base64Image = 'data:image/jpeg;base64,' + imageData;
    this.Parametro.foto = base64Image;
    this.Parametro.id = this.auth.Id;
    this.Parametro.codprod = item.CODPROD;
    // alert(base64Image)
    this.enviarImgServer();
    }, (err) => {
      alert("Erro: "+ err);
    });     
  }

  
  enviarImgServer(){
    this.loader.showLoader("Enviando foto para o servidor...");
    this.rel_estoque.inserirFotoAleatoria(this.Parametro).then((result: any) => {
      this.loader.hideLoader();
      this.loader.presentToast('Foto inserida com sucesso!');      
      this.pesquisarProduto();
    }).catch((error: any) => {
      this.loader.hideLoader();
        //console.log('error: '+error);
      this.loader.showError('Ops', 'O seu servidor pode esta sem internet no momento, tente novamente mais tarde.');
    });
  }

}
