import { Component, OnInit, ViewChild } from '@angular/core';
import { ModalController } from '@ionic/angular';
import * as HighCharts from 'highcharts';
import { ParametrosComponent } from '../../modal/parametros/parametros.component';
import { EstoqueLojasService } from '../../providers/estoque-lojas.service';
import { LoaderService } from '../../providers/loader.service';

@Component({
  selector: 'app-estoque-resumo',
  templateUrl: './estoque-resumo.page.html',
  styleUrls: ['./estoque-resumo.page.scss'],
})
export class EstoqueResumoPage implements OnInit {
  estoque : any;  
  data = { 
    filtroArtigos : [],
    filtroGrupos : [],
    filtroMarcas : [],
    idConexao: '',
    loja: ''
  }
  // chart = new Chart({});
  grafico: any = [];
  @ViewChild('barCanvas', { static: true }) barCanvas; 
  constructor(public loader: LoaderService, public estoqueLojas: EstoqueLojasService,
    public modalController: ModalController) { }

  ngOnInit() {
    this.resumoDeEstoque();
  }

  async openModal() {
    const modal = await this.modalController.create({
      component: ParametrosComponent,
      componentProps: {
        "lojas": false,
        "artigo": true,
        "grupo": true,
        "marca": true,
        "fornecedor": false,
        "dataInicial": false,
        "dataFinal": false,
        "colecao": false,
        "data": false,
        "genero": false
      },
      backdropDismiss: false,      
    });

    modal.onDidDismiss().then((res) => {            
      if (res !== null) {
        this.data.filtroArtigos = res.data['filtroArtigos'];
        this.data.filtroGrupos = res.data['filtroGrupos'];
        this.data.filtroMarcas = res.data['filtroMarcas'];
        this.detalheFiltro(this.data);
      }
    });

    return await modal.present();
  }

  graf(){
    // console.log(this.grafico)
    HighCharts.chart('chart', {
      chart: {
        type: 'column'
      },
      title: {
        text: 'Gráfico de quantidades'
      },
      xAxis: {
        categories: ['Lojas'],
        crosshair: true
      },
      yAxis: {
        // min: 0,
        title: {
            text: 'Quantidade'
        }
      },
      tooltip: {
        headerFormat: '<span style="font-size:10px">{point.key}</span><table>',
        pointFormat: '<tr><td style="color:{series.color};padding:0">{series.name}: </td>' +
            '<td style="padding:0"><b> {point.y:.2f} </b></td></tr>',
        footerFormat: '</table>',
        shared: true,
        useHTML: true
      },
      plotOptions: {
        column: {
            pointPadding: 0.2,
            borderWidth: 0
        }
      },
      series: this.grafico
    });
    // this.chart = chart;    
  }

  detalhe(loja){
    this.data.loja = loja;    
  }

  resumoDeEstoque(){
    this.estoque = [];
    this.loader.showLoader("Buscando informação de estoque...");
    // this.grafico = [];
    this.estoqueLojas.buscarEstoqueResumido()
    .then((result: any) => {      
      this.loader.hideLoader();
      this.estoque = result;
      // console.log(result);
      for (let i = 0; i < result.length; i++) {
        const element = result[i];        
        if(element.length > 0){
          this.grafico.push({
            "name": element[0].CODLOJA.trim(), "data": [element[0].ESTOQUE] 
          })
        }
        // console.log(element);        
      }      
      this.graf();      
    })
    .catch((error: any) => {
      this.loader.hideLoader();      
    });
  }

  detalheFiltro(data){
    this.loader.showLoader("Buscando informação de estoque...");
    this.estoque = [];
    this.grafico = [];
    this.estoqueLojas.buscarEstoqueResumidoFiltro(data)
    .then((result: any) => {            
      this.estoque = result;
      for (let i = 0; i < result.length; i++) {
        const element = result[i];        
        if(element.length > 0){
          this.grafico.push({
            "name": element[0].CODLOJA.trim(), "data": [element[0].ESTOQUE] 
          })
        }
        // console.log(element);        
      }
      
      this.loader.hideLoader();
      this.graf();      
      })
      .catch((error: any) => {
        console.log('error: '+error);
      });
  }

}
