import { Component, OnInit } from '@angular/core';
import { ModalController } from '@ionic/angular';
import { from } from 'rxjs';
import { groupBy, mergeMap, toArray } from 'rxjs/operators';
import { ParametrosComponent } from '../../modal/parametros/parametros.component';
import { EstoqueLojasService } from '../../providers/estoque-lojas.service';
import { LoaderService } from '../../providers/loader.service';

@Component({
  selector: 'app-estoque-tamanho',
  templateUrl: './estoque-tamanho.page.html',
  styleUrls: ['./estoque-tamanho.page.scss'],
})
export class EstoqueTamanhoPage implements OnInit {
  ar: any;  
  filtroLojas: any;
  total: any = [];
  loading: any;
  constructor(public modalController: ModalController, public estoque: EstoqueLojasService, public loader: LoaderService) { }

  ngOnInit() {
    this.loader.presentToast("Faça os filtros primeiro para obter os resultados. Botão ao lado direito no canto superior!")
  }

  async openModal() {
    const modal = await this.modalController.create({
      component: ParametrosComponent,
      componentProps: {
        "lojas": true,
        "artigo": true,
        "grupo": true,
        "marca": true,
        "fornecedor": false,
        "dataInicial": false,
        "dataFinal": false,
        "colecao": false,
        "data": false,
        "genero": false
      },
      backdropDismiss: false,      
    });

    modal.onDidDismiss().then((res) => {
      let data = res.data;      
      
      if(data != null){
        let lojas = [];
        
        lojas.push({CODIGO: data['lj']});
        let artigos = [];
        for (let i = 0; i < data['filtroArtigos'].length; i++) {
          const element = data['filtroArtigos'][i];
          artigos.push(element)
        }
        let marcas = [];
        for (let i = 0; i < data['filtroMarcas'].length; i++) {
          const element = data['filtroMarcas'][i];
          marcas.push(element)
        }
        let grupos = [];
        for (let i = 0; i < data['filtroGrupos'].length; i++) {
          const element = data['filtroGrupos'][i];
          grupos.push(element)
        }
        let ar = {
          "loja" : data['lj'] == "" ? "" : lojas,
          "filtroArtigos" : artigos,
          "filtroMarcas" : marcas,
          "filtroGrupos" : grupos
        }                                       
        this.filtroLojas = "Loja escolhida: "+data['lj'];
        
        data = ar;
        this.estoquePorGrupo(data);             
      }
    });

    return await modal.present();
  }

  public estoquePorGrupo(data) {
    console.log(data);
    this.loading = false;
    this.estoque.estoquePorGrupo(data)
      .then((result: any) => {        
          
          if(result.length == 0){
            this.loader.presentToast("Não encontrei nenhum resultado!");
          }
          this.ar = [];
          const source = from(result);
          
          const example = source.pipe(
            groupBy(person => person['TITULO']),
            mergeMap(group => group.pipe(toArray()))
          );
          const subscribe = example.subscribe(val => this.ar.push(val));
          
          this.total = [];
          for (let i = 0; i < this.ar.length; i++) {
            const element = this.ar[i];
            let grupo = element[0].TITULO;
            var sum = element.reduce( function( prevVal, elem ) {
              return prevVal + elem.ESTOQUE;
            }, 0 );
            this.total.push({
              "GRUPO" : grupo,
              "TOTAL" : sum
            });
          }
          this.loading = true;
      })
      .catch((error: any) => {  
        this.loading = true;      
        this.loader.showError('Ops', error);        
      });
  }

}
