import { Component, OnInit } from '@angular/core';
import { ModalController } from '@ionic/angular';
import { ParametrosComponent } from '../../modal/parametros/parametros.component';
import { EstoqueLojasService } from '../../providers/estoque-lojas.service';
import { LoaderService } from '../../providers/loader.service';

@Component({
  selector: 'app-estoque-vendido-fornecedor',
  templateUrl: './estoque-vendido-fornecedor.page.html',
  styleUrls: ['./estoque-vendido-fornecedor.page.scss'],
})
export class EstoqueVendidoFornecedorPage implements OnInit {
  dados: any;
  filtroLojas: any;
  param: any =[];
  primeiroMes: any;
  mes: any;
  loading: any;
  constructor(public loader: LoaderService, public modalController: ModalController, public estoque: EstoqueLojasService) { }

  ngOnInit() {
    this.loader.presentToast('Faça o filtro para obter os valors.');
  }

  padLeft(text:string, padChar:string, size:number): string {
    return (String(padChar).repeat(size) + text).substr( (size * -1), size) ;
  }

  async openModal() {
    const modal = await this.modalController.create({
      component: ParametrosComponent,
      componentProps: {
        "lojas": true,
        "artigo": false,
        "grupo": false,
        "marca": false,
        "fornecedor": false,
        "dataInicial": true,
        "dataFinal": true,
        "colecao": false,
        "data": false,
        "genero": false
      },
      backdropDismiss: false,      
    });

    modal.onDidDismiss().then((res) => {            
      if (res !== null) {
        let data= res.data;
        console.log(data);
            if(data != null){
              let lojas = [];
              lojas.push(data['lj'])
              
              let artigos = [];
              for (let i = 0; i < data['filtroArtigos'].length; i++) {
                const element = data['filtroArtigos'][i];
                artigos.push(element.CODIGO)
              }
              let fornecedores = [];
              /*for (let i = 0; i < data['fornecedores'].length; i++) {
                const element = data['fornecedores'][i];
                fornecedores.push(element.CODFORN);
              }*/
              let marcas = [];
              for (let i = 0; i < data['filtroMarcas'].length; i++) {
                const element = data['filtroMarcas'][i];
                marcas.push(element.CODIGO)
              }
              let grupos = [];
              for (let i = 0; i < data['filtroGrupos'].length; i++) {
                const element = data['filtroGrupos'][i];
                grupos.push(element.CODIGO)
              }
              let ar = {
                "loja" : lojas,
                "filtroArtigos" : artigos,
                "filtroMarcas" : marcas,
                "filtroGrupos" : grupos,
                "filtroFornecedores": fornecedores,
                "data_inicial" : data['dataInicial'],
                "data_final" : data['dataFinal']
              }                                       
              if(lojas.length == 0 || lojas.length > 1){
                this.filtroLojas = "Loja escolhida: Várias";
              } else {                
                this.filtroLojas = "Loja escolhida: "+data['lj'];
              }
              
              this.param = ar;
              this.consultarVendas(this.param);
            }
      }
    });

    return await modal.present();
  }

  consultarVendas(obj){    
    this.loading = false;
    this.estoque.vendasGruposPorFornecedor(obj)
    .then((result: any) => {        
        this.loading = true;
        this.dados = result;
      })
      .catch((error: any) => {        
        this.loading = true;
        this.loader.showError("Ops", "Possível erro no servidor que não esta ativo.");
      });
  }


}
