import { Component, OnInit } from '@angular/core';
import { ModalController } from '@ionic/angular';
import { ParametrosComponent } from '../../modal/parametros/parametros.component';
import { LoaderService } from '../../providers/loader.service';
import { VendasLojasService } from '../../providers/vendas-lojas.service';
import * as HighCharts from 'highcharts';


@Component({
  selector: 'app-financeiro-fluxo-caixa',
  templateUrl: './financeiro-fluxo-caixa.page.html',
  styleUrls: ['./financeiro-fluxo-caixa.page.scss'],
})
export class FinanceiroFluxoCaixaPage implements OnInit {
  
  data: any = false;
  pagar: number = 0;
  receber: number = 0;
  vendas: any = [];
  valorDetalhado: any = [];
  saldoAcumulado: number = 0;
  categorias: any = [];
  arre: any = [];
  mes: any;
  fraseLojas: any = "Todas";
  primeiroMes: any;
  parametro = {
    id : '',
    data_inicial : '',
    data_final : '',
    loja: []
  }
  constructor(public modalController: ModalController, public loader: LoaderService, public vendasLojas: VendasLojasService) { }

  ngOnInit() {
    this.buscarFluxo();
  }

  padLeft(text:string, padChar:string, size:number): string {
    return (String(padChar).repeat(size) + text).substr( (size * -1), size) ;
  }

  async openModal() {
    const modal = await this.modalController.create({
      component: ParametrosComponent,
      componentProps: {
        "lojas": true,
        "artigo": false,
        "grupo": false,
        "marca": false,
        "fornecedor": false,
        "dataInicial": false,
        "dataFinal": false,
        "colecao": false,
        "data": false,
        "genero": false
      },
      backdropDismiss: false,      
    });

    modal.onDidDismiss().then((res) => {
      console.log(res);
      if (res !== null) {      
        this.fraseLojas = res.data.lj;
        this.parametro.loja.push({"CODIGO" : res.data.lj});
        this.fraseLojas = res.data.lj;
        
        this.buscarFluxo();
      }
    });
    return await modal.present();
  }

  buscarFluxo(){
    var date = new Date();
    var primeiroDia = new Date(date.getFullYear(), date.getMonth(), 1);
    this.primeiroMes = date.getMonth() + 1;
    var ultimoDia = new Date(date.getFullYear(), date.getMonth() + 6, 0);
    var a = date.getMonth() + 1;
    this.mes = ultimoDia.getMonth() + 1;
    this.parametro.data_inicial = date.getFullYear()+'-'+this.padLeft(this.primeiroMes, '0', 2)+'-'+'01';
    this.parametro.data_final = ultimoDia.getFullYear()+'-'+this.padLeft(this.mes, '0', 2)+'-'+ultimoDia.getDate();    
    this.fluxoDeCaixa(this.parametro);    
  }

  fluxoDeCaixa(parametro){
    this.loader.showLoader("Estou consultando as informações...");
    this.vendasLojas.fluxoDeCaixa(parametro).then((result: any) => {    
    this.vendas = []; 
    this.valorDetalhado = [];
    this.pagar = 0;
    this.receber = 0;
    this.saldoAcumulado = 0;
    let saldo = 0;
    this.data = true;
    this.parametro.loja = [];
    for (let i = 0; i < result.length; i++) {
        const element = result[i]; 
        this.pagar = this.pagar + element.VALOR_PAGAR; 
        this.receber = this.receber + element.VALOR_RECEBER;      
        this.saldoAcumulado =  this.saldoAcumulado + (element.VALOR_RECEBER - element.VALOR_PAGAR);
        this.valorDetalhado.push({
            "MES": element.MES + "/" + element.ANO,
            "PAGAR": element.VALOR_PAGAR,
            "RECEBER": element.VALOR_RECEBER,
            "ACUMULADO": this.saldoAcumulado
        });
    }        
    saldo = this.receber - this.pagar;
    let color = "#990000";
    
    if(saldo > 0){
        color = "#009900";
    }
    this.vendas.push({
        "name": "Pagar",
        "data": [+this.pagar.toFixed(2)],
        "color": "#ff8080"
        }, {
        "name": "Receber",
        "data": [+this.receber.toFixed(2)],
        "color": "#80b3ff"
        }, {
        "name": "Saldo",
        "data": [+saldo.toFixed(2)],
        "color": color
    });             
    //this.loader.hideLoader();    
    this.graf(this.vendas);
    })
    .catch((error: any) => {
      //this.loader.hideLoader();
      this.loader.showError('Ops', error);      
    });
}

  graf(data){    
    HighCharts.chart('column', {
        chart: {
            type: 'column',
        },
        title: {
            text: 'Fluxo acumulado'
        },
        xAxis: {
            categories: ['Fluxo']
        },
        credits: {
            enabled: false
        },
        
        series: data,        
      });      
  }

}
