import { Component, OnInit } from '@angular/core';
import { ModalController } from '@ionic/angular';
import { from } from 'rxjs';
import { groupBy, mergeMap, toArray } from 'rxjs/operators';
import { ParametrosComponent } from '../../modal/parametros/parametros.component';
import { TelaGenericaComponent } from '../../modal/tela-generica/tela-generica.component';
import { FinanceiroLojasService } from '../../providers/financeiro-lojas.service';

@Component({
  selector: 'app-financeiro-recebimento-parcelas',
  templateUrl: './financeiro-recebimento-parcelas.page.html',
  styleUrls: ['./financeiro-recebimento-parcelas.page.scss'],
})
export class FinanceiroRecebimentoParcelasPage implements OnInit {
  dinheiroT = 0;
  chequeT = 0;
  cartaoT = 0;
  linkT = 0;
  pixT = 0;
  valesT = 0;
  boletosT = 0;
  consignadoT = 0;
  permutaT = 0;
  ecommerceT = 0;
  crediarioT = 0;
  outrosT = 0;
  TotalGeral = 0;
  QtTotalPedidos = 0;
  parametro: any = {
    dataInicial: "",
    dataFinal: "",
    percentual: 0,
    loja: [],
    documento: [],
    parametro: "inclusao"
  };
  primeiroMes: any;
  mes: any;
  valores: any = [];
  vendas: any = [];
  constructor(public financeiro: FinanceiroLojasService, public modalController: ModalController) { }

  ngOnInit() {
    var date = new Date();
    var primeiroDia = new Date(date.getFullYear(), date.getMonth(), 1);
    this.primeiroMes = date.getMonth() + 1;
    var ultimoDia = new Date(date.getFullYear(), date.getMonth() + 1, 0);
    var a = date.getMonth() + 1;
    this.mes = ultimoDia.getMonth() + 1;    
    // let ab = date.setMonth(date.getMonth() + 2); 
    
    this.parametro.DATA_INICIAL = date.getFullYear()+'-'+this.padLeft(this.primeiroMes, '0', 2)+'-'+'01';
    this.parametro.DATA_FINAL = ultimoDia.getFullYear()+'-'+this.padLeft(this.primeiroMes, '0', 2)+'-'+ultimoDia.getDate();    
    
    this.consultarPagamentos(this.parametro); 
  }

  padLeft(text:string, padChar:string, size:number): string {
    return (String(padChar).repeat(size) + text).substr( (size * -1), size) ;
  }

  async openModal() {
    const modal = await this.modalController.create({
      component: ParametrosComponent,
      componentProps: {
        "lojas": true,
        "artigo": false,
        "grupo": false,
        "marca": false,
        "fornecedor": false,
        "dataInicial": true,
        "dataFinal": true,
        "colecao": false,
        "data": false,
        "genero": false,
        "documento": false,
        "valoresVencimento": true
      },
      backdropDismiss: false,      
    });

    modal.onDidDismiss().then((res) => {
      if (res !== null) {              
        res.data.DATA_INICIAL = res.data.dataInicial;
        res.data.DATA_FINAL = res.data.dataFinal;        
        this.parametro.loja.push({"CODIGO" : res.data.lj});
        this.parametro.parametro = (res.data.valoresVencimento == true) ? "vencimento" : "inclusao";
        if(res.data.DATA_INICIAL != "" || res.data.DATA_FINAL != ""){
          // console.log(res.data.valoresVencimento);
          this.consultarPagamentos(this.parametro);
        }
        // this.parametro = res.data;
      }
    });
    return await modal.present();
  }
  
  consultarPagamentos(parametro){    
    this.vendas = [];
    this.financeiro.consultarRecebimentosPorDocumento(parametro)
    .then((result: any) => {
      this.dinheiroT = 0;
      this.chequeT = 0;
      this.cartaoT = 0;
      this.linkT = 0;
      this.pixT = 0;
      this.valesT = 0;
      this.boletosT = 0;
      this.consignadoT = 0;
      this.permutaT = 0;
      this.ecommerceT = 0;
      this.crediarioT = 0;
      this.outrosT = 0;
      this.TotalGeral = 0;
      this.QtTotalPedidos = 0;
      for (let i = 0; i < result.length; i++) {
        const element = result[i];
        this.TotalGeral = this.TotalGeral + element['TOTAL_VALORES'];
        this.QtTotalPedidos = this.QtTotalPedidos + element['QT'];         
        this.dinheiroT = this.dinheiroT + (element['TP_DOC'] == 1 ? element['TOTAL_VALORES'] : 0);
        this.chequeT = this.chequeT + (element['TP_DOC'] == 2 ? element['TOTAL_VALORES'] : 0);
        this.cartaoT = this.cartaoT + (element['TP_DOC'] == 3 || element['TP_DOC'] == 4 ? element['TOTAL_VALORES'] : 0);
        this.valesT = this.valesT + (element['TP_DOC'] == 5 ? element['TOTAL_VALORES'] : 0);

        this.pixT = this.pixT + (element['TP_DOC'] == 110 || element['TP_DOC'] == 111 ? element['TOTAL_VALORES'] : 0);
        this.boletosT = this.boletosT + (element['TP_DOC'] == 15 || element['TP_DOC'] == 6 ? element['TOTAL_VALORES'] : 0);
        
        this.consignadoT = this.consignadoT + (element['TP_DOC'] == 8 ? element['TOTAL_VALORES'] : 0);
        this.permutaT = this.permutaT + (element['TP_DOC'] == 11 ? element['TOTAL_VALORES'] : 0);

        this.crediarioT = this.crediarioT + (element['TP_DOC'] == 13 ? element['TOTAL_VALORES'] : 0);

        this.linkT = this.linkT + (element['TP_DOC'] == 101 || element['TP_DOC'] == 102 || element['TP_DOC'] == 103 || element['TP_DOC'] == 104 ? element['TOTAL_VALORES'] : 0);
        
        this.outrosT = this.outrosT + (element['TP_DOC'] == 0 ? element['TOTAL_VALORES'] : 0);
        /*         
        ecommerceT = 0;         
        */
      }
      // this.vendas = result;          
      const source = from(result);
        const example = source.pipe(
          groupBy(person => person['LOJA']),
          mergeMap(group => group.pipe(toArray()))
        );    
        const subscribe = example.subscribe(val => {this.vendas.push(val)});        
      })
      .catch((error: any) => {
        console.log('error: '+error);
      });
  }

}
