import { Component, Input, OnInit } from '@angular/core';
import { NavigationExtras, Router } from '@angular/router';
import { ModalController } from '@ionic/angular';
import { ParametrosComponent } from '../../modal/parametros/parametros.component';
import { FinanceiroLojasService } from '../../providers/financeiro-lojas.service';
import { LoaderService } from '../../providers/loader.service';

@Component({
  selector: 'app-financeiro-relatorio',
  templateUrl: './financeiro-relatorio.page.html',
  styleUrls: ['./financeiro-relatorio.page.scss'],
})
export class FinanceiroRelatorioPage implements OnInit {
  @Input('progress') progress;
  financeiro : any;
  data :any = {
    data_inicial: '',
    data_final: '',
    loja: '',
    parametro: ''
  } 
  constructor(public modalController: ModalController, public loader: LoaderService, 
    public finances: FinanceiroLojasService, private router: Router) { }

  padLeft(text:string, padChar:string, size:number): string {
    return (String(padChar).repeat(size) + text).substr( (size * -1), size) ;
  }
  ngOnInit() {
    this.loader.presentToast('Clique no saldo a pagar e faça a baixa automática das contas pelo celular');
    let diaAtual = new Date();
    let mes : any = diaAtual.getMonth()+1;
    var ultimoDia = new Date(diaAtual.getFullYear(), diaAtual.getMonth() + 1, 0);
    
    this.data.dataInicial = diaAtual.getFullYear()+'-'+this.padLeft(mes, '0', 2)+'-01';
    this.data.dataFinal = diaAtual.getFullYear()+'-'+this.padLeft(mes, '0', 2)+'-'+ ultimoDia.getDate();
    this.resumoFinanceiro(this.data);
  }

  async openModal() {
    const modal = await this.modalController.create({
      component: ParametrosComponent,
      componentProps: {
        "lojas": false,
        "artigo": false,
        "grupo": false,
        "marca": false,
        "fornecedor": false,
        "dataInicial": true,
        "dataFinal": true,
        "colecao": false,
        "data": false,
        "genero": false
      },
      backdropDismiss: false,      
    });

    modal.onDidDismiss().then((res) => {      
      console.log(res);
      if (res !== null) {
      
        this.data.dataInicial = res.data.dataInicial;
        this.data.dataFinal = res.data.dataFinal;
        if(res.data.dataFinal == '' || res.data.dataInicial == ''){
          this.loader.showError("Atenção", "As datas preenchidas não podem ficar em branco.")
        } else {
          console.log(this.data);
          this.resumoFinanceiro(this.data);
        }
      }
    });

    return await modal.present();
  }
  detalheDevido(item){
    var ultimoDia = new Date(item.ANO, item.MES, 0);  
    this.data.dataInicial = item.ANO+'-'+this.padLeft(item.MES, '0', 2)+'-01';
    this.data.dataFinal = item.ANO+'-'+this.padLeft(item.MES, '0', 2)+'-'+ ultimoDia.getDate();
    this.data.loja = item.LOJA;
    this.data.parametro = 'todos';
    this.abrirDetalhePaginas(this.data)
  }

  detalhePago(item){
    var ultimoDia = new Date(item.ANO, item.MES, 0);  
    this.data.dataInicial = item.ANO+'-'+this.padLeft(item.MES, '0', 2)+'-01';
    this.data.dataFinal = item.ANO+'-'+this.padLeft(item.MES, '0', 2)+'-'+ ultimoDia.getDate();
    this.data.loja = item.LOJA;
    this.data.parametro = 'pago';
    this.abrirDetalhePaginas(this.data)
  }

  detalhePagar(item){
    var ultimoDia = new Date(item.ANO, item.MES, 0);  
    this.data.dataInicial = item.ANO+'-'+this.padLeft(item.MES, '0', 2)+'-01';
    this.data.dataFinal = item.ANO+'-'+this.padLeft(item.MES, '0', 2)+'-'+ ultimoDia.getDate();
    this.data.loja = item.LOJA;
    this.data.parametro = 'aberto';
    this.abrirDetalhePaginas(this.data)
  }

  

  resumoFinanceiro(data){
    this.financeiro = [];

    this.loader.showLoader("Buscando contas a pagar...");
    this.finances.financeiroLojas(data)
    .then((result: any) => {
      this.loader.hideLoader();      
      this.financeiro = result;      
    })
    .catch((error: any) => {      
      this.loader.hideLoader();
      this.loader.showError("Ops", error);
      
    });
  }

  abrirDetalhePaginas(item){
    // this.navCtrl.push('DetalheFinanceiroLojasPage', item);
    let navigationExtras: NavigationExtras = {
      queryParams: {
        special: JSON.stringify(item)
      }
    };
    this.router.navigate(['/app/tabs/about/financeiro-baixa-contas'], navigationExtras);
  }

}
