import { Component, OnInit } from '@angular/core';
import { ActionSheetController, AlertController } from '@ionic/angular';
import { AuthServiceService } from '../../../providers/auth-service.service';
import { LoaderService } from '../../../providers/loader.service';
import { VendasLojasService } from '../../../providers/vendas-lojas.service';

@Component({
  selector: 'app-ml',
  templateUrl: './ml.page.html',
  styleUrls: ['./ml.page.scss'],
})
export class MlPage implements OnInit {

  result: any = [];
  empresaEnvio: any = "Correios";
  tipoEnvio: any = "Sedex10";
  constructor(public loader: LoaderService, public vendasLojas: VendasLojasService, 
    public auth: AuthServiceService, public actionSheetController: ActionSheetController,
    private alertController: AlertController) { }

  ngOnInit() {
    this.vendasPluggTO();
  }

  async presentAlert(item) {
    const alert = await this.alertController.create({
      header: 'Dados de entrega',      
      backdropDismiss: false,
      inputs: [
        {
          value: this.empresaEnvio,
          placeholder: 'Transportadora',
          name: 'transportadora',
          id: 'Transportadora'
        },
        {
          value: this.tipoEnvio,
          placeholder: 'Tipo: PAC/SEDEX',
          name: 'tipo',
          id: 'tipo',
          attributes: {
            maxlength: 20,
          },
        },
        {          
          placeholder: 'Cód. Rastreio',
          name: 'rastreio',
          id: 'rastreio',
          attributes: {
            maxlength: 30,
          },
        }        
      ],
      buttons: [
        {
          text: 'Cancelar',
          role: 'cancel',
          handler: (e) => {
            console.log(e);
          },
        },
        {
          text: 'Confirmar',
          role: 'confirm',
          handler: (e) => {
            let ar = {
              "id" : this.auth.Id,
              "idPedido" : item.VALOR,
              "pedido" : item.PEDIDO,
              "transportadora" : e.transportadora,
              "tipo" : e.tipo,
              "rastreio" : e.rastreio
            }
            if(e.transportadora == "" || e.tipo == "" || e.rastreio == ""){
              this.loader.showError("Atenção", "Todos os campos deverão ser preenchidos.");
            } else {
              this.informarRastreio(ar);
            }
          },
        },
      ],
    });

    await alert.present();
  }

  informarRastreio(item){
    this.loader.showLoader('Aguarde... Inserindo o código do rastreio!')
    this.vendasLojas.inserirRastreio(item)
    .then((result: any) => {    
      // console.log(result);
      if(result.hasOwnProperty('error')){
        this.loader.showError('Atenção', result.details);
      } else {
        this.loader.presentToast('Rastreio informado com sucesso!');
      }
      this.loader.hideLoader();
    }).catch((error: any) => {
      this.loader.hideLoader();
    });    
  }

  vendasPluggTO(){
    this.result = [];
    this.loader.showLoader('Consultando vendas...');
    this.vendasLojas.vendasPluggTO('').then((result: any) => {
      // console.log(result);
      this.result = result;
      this.loader.hideLoader();
    }).catch((error: any) => {
      this.loader.hideLoader();
    });
  }

  informarNFe(item){
    if(item.CHAVE == "" || item.CHAVE == null){
      this.loader.showError('Atenção', 'Ainda não emitiram NF-e para esse pedido.');
    } else {
      this.loader.showLoader('Inserindo dados da NFe...');
      this.vendasLojas.inserirNF(item).then((result: any) => {
        console.log(result);
        if(result.hasOwnProperty('error')){
          this.loader.showError('Atenção', result.details);
        } else {
          this.loader.presentToast('NFe inserida com sucesso.');
        }
        this.loader.hideLoader();
      }).catch((error: any) => {
        this.loader.hideLoader();
      });
    }
  }

  abrirEtiqueta(etiqueta){
    window.open(etiqueta, "_blank");
  }

  consultarUnicoPedidoPluggto(item){
    this.loader.showLoader('Consultando entregas...');
    this.vendasLojas.consultarUnicoPedidoPluggto(item).then((result: any) => {
      let entrega = result['Order']['shipments'];
      for (let i = 0; i < entrega.length; i++) {
        const element = entrega[i];
        this.empresaEnvio = element['shipping_company'];
        this.tipoEnvio = element['shipping_method'];
      }
      if(result.hasOwnProperty('error')){
        this.loader.showError('Atenção', result.details);
      } else {
        this.presentAlert(item);
      }
      this.loader.hideLoader();
    }).catch((error: any) => {
      this.loader.hideLoader();
    });    
  }

  etiqueta(item){
    this.loader.showLoader('Procurando etiquetas...');
    this.vendasLojas.imprimirEtiquetas(item).then((result: any) => {
      if(result.hasOwnProperty('error')){
        this.loader.showError('Atenção', result.details);
      } else {
        for (let i = 0; i < result['urls'].length; i++) {
          const element = result['urls'][i];
          this.abrirEtiqueta(element);
        }
      }
      this.loader.hideLoader();
    }).catch((error: any) => {
      this.loader.hideLoader();
    });    
  }

  async presentActionSheet(item) {    
    // console.log((item.TIPO.trim()));
    if(item.TIPO.trim() != "Aprovado"){
      this.loader.showError("Atenção!", "Pedidos com o status "+item.TIPO+", não poderá enviar NFe ou código de rastreio para transporte.")
    } else {
      const actionSheet = await this.actionSheetController.create({
        header: 'Escolhas',
        cssClass: 'my-custom-class',
        buttons: [{
          text: 'Informar NFe',
          role: 'destructive',
          icon: 'document-attach',
          handler: () => {
            this.informarNFe(item);
          }
        }, {
          text: 'Informar entrega',
          icon: 'bicycle',
          handler: () => {
            this.consultarUnicoPedidoPluggto(item);
          }
        }, {
          text: 'Etiqueta de envio',
          icon: 'clipboard',
          handler: () => {
            this.etiqueta(item);
          }
        }, {
          text: 'Cancelar',
          icon: 'close',
          role: 'cancel',
          handler: () => {
            console.log('Cancel clicked');
          }
        }]
      });
      await actionSheet.present();
  
      const { role, data } = await actionSheet.onDidDismiss();
      console.log('onDidDismiss resolved with role and data', role, data);

    }
  }

}
