import { Component, ViewChild, OnInit } from '@angular/core';
import { Router } from '@angular/router';
import { AlertController,  IonRouterOutlet, LoadingController, ModalController, ToastController, Config, Platform } from '@ionic/angular';

import { ConferenceData } from '../../providers/conference-data';
import { UserData } from '../../providers/user-data';
import { Storage } from '@ionic/storage';
import { AuthServiceService } from '../../providers/auth-service.service';
import { LoaderService } from '../../providers/loader.service';

@Component({
  selector: 'page-schedule',
  templateUrl: 'schedule.html',
  styleUrls: ['./schedule.scss'],
})
export class SchedulePage implements OnInit {
  // Gets a reference to the list element
  registerCredentials = { id: '' };
  vendas: any;
  mes: any;
  hoje: any;
  dia: any;
  usuario: any;
  relResumoDiario: boolean = true;
  relResumoMensal: boolean = true;
  frmDescontoEmPedidos: boolean = true;
  frmConciliador: boolean = true;
  frmCondicaoPagto: boolean = true;
  entrarShopee: any = 'hidden';
  entrarWoocommerce: any = 'hidden';
  frmManutencaoVendas: boolean = true;
 

  constructor(
    public alertCtrl: AlertController,
    public confData: ConferenceData,
    public loadingCtrl: LoadingController,
    public modalCtrl: ModalController,
    public router: Router,
    public routerOutlet: IonRouterOutlet,
    public toastCtrl: ToastController,
    public user: UserData,
    public config: Config,
    private storage: Storage,
    public auth: AuthServiceService,
    public load: LoaderService,
    public plat: Platform
  ) { 
      
  }

  verificarPermissoes(){
    // this.load.presentToast("Operador: "+this.auth.Usuario.codigo);
    this.auth.consultarPermissoesUsuarios({
      "id" : this.auth.Id,
      "usuario": this.auth.Usuario.codigo
      }).then((result: any) => {        
        for (let a = 0; a < result.length; a++) {
          const elemento = result[a];          
          if((elemento.MODULO == "RelatResumoDoDia" || elemento.MODULO == "FechaCaixa") && elemento.ENTRAR == "true"){
            this.relResumoDiario = false;
          }
          if(elemento.MODULO == "RelatResumoDeVendasPorTipoDoc" && elemento.ENTRAR == "true"){
            this.relResumoMensal = false;
          }
          if(elemento.MODULO == "frmPedidosDeVenda_ConfirmarPedidoPendente" && elemento.ENTRAR == "true"){
            this.frmDescontoEmPedidos = false;
          }
          if(elemento.MODULO == "frmBaixaDeContasAreceber" && elemento.ENTRAR == "true"){
            this.frmConciliador = false;
          }
          if(elemento.MODULO == "frmCadastroDeCondicoes" && elemento.ENTRAR == "true"){
            this.frmCondicaoPagto = false;
          }
          if(elemento.MODULO == "ManutecaoVendas" && elemento.ENTRAR == "true"){
            this.frmManutencaoVendas = false;
          }          
        }
      }).catch((error: any) => {        
        //this.toast.create({ message: 'Erro ao efetuar login. Erro: ' + error.error, position: 'botton', duration: 3000 }).present();        
      });
      let texto = '';
      for (let i = 0; i < this.plat.platforms().length; i++) {
        const element = this.plat.platforms()[i];
        // console.log(element);
        texto += element+'<br>'
      }
      // alert(texto);
  }

  ngOnInit() {
    this.verificarPermissoes();
    let diaAtual = new Date();
    this.mes = diaAtual.getMonth()+1;
    this.hoje = diaAtual.getDate();
    let dia = diaAtual.getFullYear()+'-'+this.padLeft(this.mes, '0', 2)+'-'+this.padLeft(this.hoje, '0', 2);
    // this.navCtrl.push('DetalheVendasVendedoresPage', { "DATA": dia, "LOJA": "" });
    // this.router.navigateByUrl('/app/tabs/schedule/resumo-diario');
    this.dia = dia;
    /*
    this.storage.get('mudancas').then((val) => {
      if(val != null){
        if(this.auth.modeloCelular == 'ios'){
          this.load.showError('Informação', val);
          // this.showAlert('Informação', );
        }        
      } 
    }); 
    */
    this.entrarShopee = this.auth.shopee;
    this.entrarWoocommerce = this.auth.woocomerce;
    /*  this.storage.get('ID').then((val) => {
        if(val != null){
          for (let i = 0; i < val.length; i++) {
            const element = val[i];
            this.registerCredentials.id = element.ID;
            this.usuario = element.NOME;            
            for (let a = 0; a < element.PERMISSOES.length; a++) {
              const elemento = element.PERMISSOES[a];
              if((elemento.MODULO == "RelatResumoDoDia" || elemento.MODULO == "FechaCaixa") && elemento.ENTRAR == "true"){
                this.relResumoDiario = false;
              }
              if(elemento.MODULO == "RelatResumoDeVendasPorTipoDoc" && elemento.ENTRAR == "true"){
                this.relResumoMensal = false;
              }
              if(elemento.MODULO == "frmPedidosDeVenda_ConfirmarPedidoPendente" && elemento.ENTRAR == "true"){
                this.frmDescontoEmPedidos = false;
              }
              if(elemento.MODULO == "frmBaixaDeContasAreceber" && elemento.ENTRAR == "true"){
                this.frmConciliador = false;
              }
              if(elemento.MODULO == "frmCadastroDeCondicoes" && elemento.ENTRAR == "true"){
                this.frmCondicaoPagto = false;
              }
            }
          }
        } else {
          this.usuario = this.auth.Usuario.nome;
        }
      });   
    */
    this.mes = diaAtual.getFullYear()+'-'+this.padLeft(this.mes, '0', 2);
  }

  padLeft(text:string, padChar:string, size:number): string {
    return (String(padChar).repeat(size) + text).substr( (size * -1), size) ;
  }
  
  graficoMensal(){
    // this.navCtrl.push('VendasMesPage', {});
  }

  ionViewWillEnter(){
    this.user.getPermissoes().then(val => {
      if(val != null){
        for (let i = 0; i < val.length; i++) {
          const element: any = val[i];
          this.registerCredentials.id = element.ID;
          this.usuario = element.NOME;            
          for (let a = 0; a < element.PERMISSOES.length; a++) {
            const elemento = element.PERMISSOES[a];
            if((elemento.MODULO == "RelatResumoDoDia" || elemento.MODULO == "FechaCaixa") && elemento.ENTRAR == "true"){
              this.relResumoDiario = false;
            }
            if(elemento.MODULO == "RelatResumoDeVendasPorTipoDoc" && elemento.ENTRAR == "true"){
              this.relResumoMensal = false;
            }
            if(elemento.MODULO == "frmPedidosDeVenda_ConfirmarPedidoPendente" && elemento.ENTRAR == "true"){
              this.frmDescontoEmPedidos = false;
            }
            if(elemento.MODULO == "frmBaixaDeContasAreceber" && elemento.ENTRAR == "true"){
              this.frmConciliador = false;
            }
            if(elemento.MODULO == "frmCadastroDeCondicoes" && elemento.ENTRAR == "true"){
              this.frmCondicaoPagto = false;
            }
          }
        }
      } else {
        this.usuario = this.auth.Usuario.nome;
      }
      return val;
    });
  }
  ionViewDidEnter(){
    // console.log("ionViewDidEnter");
  }
  ionViewWillLeave(){
    // console.log("ionViewWillLeave");
  }
  ionViewDidLeave(){
    // console.log("ionViewDidLeave");
  }	

  resumoMensal(){
    // this.navCtrl.push('VendasMesPage', {});
    this.router.navigateByUrl('/app/tabs/schedule/vendas-mensal');
  }

  comparativoIndiceLojasPage(){
    // this.navCtrl.push('ComparativoIndiceLojasPage', {});    
  }

  campanhasPage(){
    // this.navCtrl.push('ResultadoCampanhaPage', {});    
  }

  condicaoPagtos(){
    // this.navCtrl.push('CondicaoPagtoPage', {});    
  }

  resumoDiario(){
    // let diaAtual = new Date();
    // this.mes = diaAtual.getMonth()+1;
    // this.hoje = diaAtual.getDate();
    // let dia = diaAtual.getFullYear()+'-'+this.padLeft(this.mes, '0', 2)+'-'+this.padLeft(this.hoje, '0', 2);
    // this.navCtrl.push('DetalheVendasVendedoresPage', { "DATA": dia, "LOJA": "" });
    // this.router.navigateByUrl('/app/tabs/schedule/resumo-diario');
    
  }

  vendasPerdidas(){
    // this.navCtrl.push('VendasPerdidasLojasPage');
  }

  grafico(){
    // this.navCtrl.push('GraficoLojasPage');
  }

  lucratividade(){
    // this.navCtrl.push('LucratividadePage');
  }

  sair(){
    // this.navCtrl.push('SairPage', {});
  }

  manutencaoDeVendas(){
    // this.navCtrl.push('ManutencaoDeVendasPage', {});
  }

  liberacaoDescontoEmPedidos(){
    // this.navCtrl.push('LiberacaoDescontoPedidosPage', {});
  }

  conciliador(){
    // this.navCtrl.push('ConciliacaoCartoesPage', {});    
  }

  chavePIX(){
    // this.navCtrl.push('ChavePixPage', {});
  }

  shopee(){
    // this.navCtrl.push('ShopeePage', {});
  }
  
  
}
