import { Component, OnInit } from '@angular/core';
import { LoaderService } from '../../providers/loader.service';
import { VendasLojasService } from '../../providers/vendas-lojas.service';

@Component({
  selector: 'app-shopee',
  templateUrl: './shopee.page.html',
  styleUrls: ['./shopee.page.scss'],
})
export class ShopeePage implements OnInit {
  listaPedidos: any = []
  constructor(public loader: LoaderService, public vendas: VendasLojasService) { }

  ngOnInit() {
    this.buscarVendas();
  }

  buscarVendas(){
    this.loader.showLoader("Consultando vendas Shopee...");
    this.vendas.buscarVendasShopee()
    .then((result: any) => {      
      this.listaPedidos = [];
      // console.log(result);
      this.loader.hideLoader();      
      if(result.length == 0){
        this.loader.showError("Ops", "Não encontrei vendas no Shopee");
      }
      for (let i = 0; i < result.length; i++) {
        const element = result[i];
        this.listaPedidos.push({
          "ordersn" : element.ordersn,
          "recipient_address" : {
            "name": element.recipient_address.name
          },
          "create_time": element.create_time,
          "order_status": element.order_status,
          "shipping_carrier": element.shipping_carrier,
          "total_amount": element.total_amount,
          "NF_numero": element.invoice_data.number,
          "NF_chave": element.invoice_data.access_key,
          "pedido_winsae": ""
        })
      }      
    })
    .catch((error: any) => {
      console.log(error);
    });
  }

  addPedido(pedido){
    this.loader.showLoader("Adicionando venda no WinSAE");
    this.vendas.addVendasShopee(pedido)
    .then((result: any) => {
      this.loader.hideLoader();
      for (let i = 0; i < this.listaPedidos.length; i++) {
        const element = this.listaPedidos[i];
        if(element.ordersn == result.PedidoShopee){
          element.pedido_winsae = result.PedidoWinSAE;
        }
      }
    })
    .catch((error: any) => {
      console.log('error: '+error);
    });
  }

}
