import { Component, OnInit } from '@angular/core';
import { NgForm } from '@angular/forms';

import { ActionSheetController, AlertController, ToastController } from '@ionic/angular';
import { AuthServiceService } from '../../providers/auth-service.service';
import { DbService } from '../../providers/db.service';
import { LoaderService } from '../../providers/loader.service';


@Component({
  selector: 'page-support',
  templateUrl: 'support.html',
  styleUrls: ['./support.scss'],
})
export class SupportPage implements OnInit {
  public cnpj: any;
  public tela: any = [];

  constructor(
    public alertCtrl: AlertController,
    public toastCtrl: ToastController,
    public actionSheetCtrl: ActionSheetController,
    public auth: AuthServiceService,
    public db: DbService,
    public loader: LoaderService
  ) { }
  voltar(){
    
  }
  async presentActionSheet(data) {
    const actionSheet = await this.actionSheetCtrl.create({
      header: 'Deseja apagar a linha?',
      buttons: [
        {
          text: 'Apagar',
          handler: () => {
            this.apagarServidorBanco(data);            
          }
        },{
          text: 'Cancelar',
          role: 'cancelar',
          handler: () => {
            console.log('Cancel clicked');
          }
        }
      ]
    });
    await actionSheet.present();
  }

  apagarServidorBanco(data){
    this.db.remove(data.idservidor);
    for (let i = 0; i < this.tela.length; i++) {
      const element = this.tela[i];
      if(this.tela[i]['idservidor'] == data.idservidor){
        this.tela.splice(i, 1);
      }    
    }
  }

  ngOnInit() {    
    this.db.consultarServidores().then((result: any) => {
      this.tela = result;            
    });
  }

  valuechange(newValue) {    
    if(newValue.key == 'Enter' || newValue.keyCode == 13 || newValue.keyIdentifier == 'Enter'){
    }
    if(this.cnpj.length == 14 && this.cnpj != ""){
      if(this.is_cnpj(this.cnpj) == true){
        this.consultarCnpjServidor(this.cnpj);
      } else {        
        this.loader.showError('Ops!', "CNPJ inválido");
      }
    }
  }

  apagarServidor(a){
    this.presentActionSheet(a);
  } 

  consultarCnpjServidor(cnpj){
    this.loader.showLoader("Aguarde, consultando CNPJ no nosso servidor!");
    this.auth.consultarServidor(cnpj)
    .then((result: any) => {
      this.loader.hideLoader();
      this.tela.push(result);
      if(result != []){
        for (let i = 0; i < this.tela.length; i++) {
          const element = this.tela[i];
          if(this.tela[i]['idservidor'] == result.CHAVEDEACESSO){
            this.tela.splice(i, 1);
          }    
        }
        this.db.insertServidor(result.CHAVEDEACESSO, result.IPSERVER, '', result.PASTASERVER, '',  result.SENHABANCO, result.EMPRESA);          
      }      
    })
    .catch((error: any) => {
      console.log(error.message);        
    });;
  }

  is_cnpj(c) {
    var b = [6,5,4,3,2,9,8,7,6,5,4,3,2];
    if((c = c.replace(/[^\d]/g,"")).length != 14)
        return false;
    if(/0{14}/.test(c))
        return false;
    for (var i = 0, n = 0; i < 12; n += c[i] * b[++i]);
    if(c[12] != (((n %= 11) < 2) ? 0 : 11 - n))
        return false;
    for (var i = 0, n = 0; i <= 12; n += c[i] * b[i++]);
    if(c[13] != (((n %= 11) < 2) ? 0 : 11 - n))
        return false;
    return true;
  };
}
