import { NgModule } from '@angular/core';
import { RouterModule, Routes } from '@angular/router';
import { TabsPage } from './tabs-page';
import { SchedulePage } from '../schedule/schedule';
import { CheckTutorial } from '../../providers/check-tutorial.service';


const routes: Routes = [
  {
    path: 'tabs',
    component: TabsPage,
    
    children: [
      {
        path: 'schedule',
        canLoad: [CheckTutorial],
        canActivate: [CheckTutorial],
        children: [
          {
            path: '',
            component: SchedulePage,
          },
          {
            path: 'session/:sessionId',
            loadChildren: () => import('../session-detail/session-detail.module').then(m => m.SessionDetailModule)
          },
          {
            path: 'resumo-diario/:dia',
            loadChildren: () => import('../resumo-diario/resumo-diario.module').then(m => m.ResumoDiarioPageModule),
            canLoad: [CheckTutorial],    
             
          },          
          {
            path: 'resumo-diario-detalhe/:dia',
            loadChildren: () => import('../resumo-diario-detalhe/resumo-diario-detalhe.module').then(m => m.ResumoDiarioDetalhePageModule),
            canLoad: [CheckTutorial],    
             
          },          
          {
            path: 'pixstatus',
            loadChildren: () => import('../pixstatus/pixstatus.module').then(m => m.PixstatusPageModule),
            canLoad: [CheckTutorial],    
             
          },
          {
            path: 'vendas-mensal/:mes',
            loadChildren: () => import('../vendas-mensal/vendas-mensal.module').then(m => m.VendasMensalPageModule),
            canLoad: [CheckTutorial],          
          },          
          {
            path: 'correios',
            loadChildren: () => import('../correios/correios.module').then(m => m.CorreiosPageModule),
            canLoad: [CheckTutorial],          
          },
          {
            path: 'vendas-mensal-detalhe',
            loadChildren: () => import('../vendas-mensal-detalhe/vendas-mensal-detalhe.module').then(m => m.VendasMensalDetalhePageModule),
            canLoad: [CheckTutorial],          
          },          
          {
            path: 'vendas-grafico-comparativo',
            loadChildren: () => import('../vendas-grafico-comparativo/vendas-grafico-comparativo.module').then(m => m.VendasGraficoComparativoPageModule),
            canLoad: [CheckTutorial],          
          },
          {
            path: 'vendas-lucratividade',
            loadChildren: () => import('../vendas-lucratividade/vendas-lucratividade.module').then(m => m.VendasLucratividadePageModule),
            canLoad: [CheckTutorial],          
          },
          {
            path: 'vendas-comparativo-indice',
            loadChildren: () => import('../vendas-comparativo-indice/vendas-comparativo-indice.module').then(m => m.VendasComparativoIndicePageModule),
            canLoad: [CheckTutorial],          
          },
          {
            path: 'vendas-liberar-desconto',
            loadChildren: () => import('../vendas-liberar-desconto/vendas-liberar-desconto.module').then(m => m.VendasLiberarDescontoPageModule),
            canLoad: [CheckTutorial],          
          },
          {
            path: 'cadastro-condicao-pagamento',
            loadChildren: () => import('../cadastro-condicao-pagamento/cadastro-condicao-pagamento.module').then(m => m.CadastroCondicaoPagamentoPageModule),
            canLoad: [CheckTutorial],          
          },
          {
            path: 'shopee',
            loadChildren: () => import('../shopee/shopee.module').then(m => m.ShopeePageModule),
            canLoad: [CheckTutorial],          
          },
          {
            path: 'vendas-grafico-semanas',
            loadChildren: () => import('../vendas-grafico-semanas/vendas-grafico-semanas.module').then(m => m.VendasGraficoSemanasPageModule),
            canLoad: [CheckTutorial],          
          },
          {
            path: 'mercadoLivre',
            loadChildren: () => import('../mercadoLivre/ml/ml.module').then(m => m.MlPageModule),
            canLoad: [CheckTutorial],          
          },
          {
            path: 'cadastrar-item-mercado-livre',
            loadChildren: () => import('../mercadoLivre/cadastrar-item-ml/cadastrar-item-ml.module').then(m => m.CadastrarItemMlPageModule),
            canLoad: [CheckTutorial],          
          },         
          {
            path: 'marketplace',
            loadChildren: () => import('../marketplace-produtos/marketplace-produtos.module').then(m => m.MarketplaceProdutosPageModule),
            canLoad: [CheckTutorial],          
          },         
          {
            path: 'marketplace-add',
            loadChildren: () => import('../marketplace-add/marketplace-add.module').then(m => m.MarketplaceAddPageModule),
            canLoad: [CheckTutorial],          
          },   
          {
            path: 'marketplace-editar',
            loadChildren: () => import('../marketplace-editar/marketplace-editar.module').then(m => m.MarketplaceEditarPageModule),
            canLoad: [CheckTutorial],          
          },      
          {
            path: 'vendas-campanha',
            loadChildren: () => import('../vendas-campanhas/vendas-campanhas.module').then(m => m.VendasCampanhasPageModule),
            canLoad: [CheckTutorial],          
          },      
          {
            path: 'manutencao-de-vendas',
            loadChildren: () => import('../cadastro-manutencao-vendas/cadastro-manutencao-vendas.module').then(m => m.CadastroManutencaoVendasPageModule),
            canLoad: [CheckTutorial],          
          },
          {
            path: 'comparativo-hora',
            loadChildren: () => import('../comparativo-hora/comparativo-hora.module').then(m => m.ComparativoHoraPageModule),
            canLoad: [CheckTutorial],          
          }
        ]
      },
      {
        path: 'speakers',
        canLoad: [CheckTutorial],
        canActivate: [CheckTutorial],     
        children: [
          {
            path: '',
            loadChildren: () => import('../speaker-list/speaker-list.module').then(m => m.SpeakerListModule)
          },
          {
            path: 'vendedores-desempenho',
            loadChildren: () => import('../vendedores-desempenho/vendedores-desempenho.module').then(m => m.VendedoresDesempenhoPageModule)
          },          
          {
            path: 'vendedores-desempenho-detalhe',
            loadChildren: () => import('../vendedores-desempenho-detalhe/vendedores-desempenho-detalhe.module').then(m => m.VendedoresDesempenhoDetalhePageModule)
          },
          {
            path: 'cadastro-vendedores',
            loadChildren: () => import('../cadastro-vendedores/cadastro-vendedores.module').then(m => m.CadastroVendedoresPageModule)
          },
          {
            path: 'avaliacao-vendedores',
            loadChildren: () => import('../avaliacao-vendedores/avaliacao-vendedores.module').then(m => m.AvaliacaoVendedoresPageModule)
          }
        ]
      },
      {
        path: 'map',
        canLoad: [CheckTutorial],
        canActivate: [CheckTutorial],     
        children: [
          {
            path: '',
            loadChildren: () => import('../map/map.module').then(m => m.MapModule)
          },
          {
            path: 'estoque-resumo',
            loadChildren: () => import('../estoque-resumo/estoque-resumo.module').then(m => m.EstoqueResumoPageModule)
          },
          {
            path: 'estoque-curva-abc',
            loadChildren: () => import('../estoque-curva-abc/estoque-curva-abc.module').then(m => m.EstoqueCurvaAbcPageModule)
          },
          {
            path: 'estoque-entradas',
            loadChildren: () => import('../estoque-entradas/estoque-entradas.module').then(m => m.EstoqueEntradasPageModule)
          },
          {
            path: 'estoque-entradas-detalhe',
            loadChildren: () => import('../estoque-entradas-detalhe/estoque-entradas-detalhe.module').then(m => m.EstoqueEntradasDetalhePageModule)
          },
          {
            path: 'estoque-minimo',
            loadChildren: () => import('../estoque-minimo/estoque-minimo.module').then(m => m.EstoqueMinimoPageModule)
          },
          {
            path: 'estoque-tamanho',
            loadChildren: () => import('../estoque-tamanho/estoque-tamanho.module').then(m => m.EstoqueTamanhoPageModule)
          },
          {
            path: 'estoque-vendido-fornecedor',
            loadChildren: () => import('../estoque-vendido-fornecedor/estoque-vendido-fornecedor.module').then(m => m.EstoqueVendidoFornecedorPageModule)
          },
          {
            path: 'cadastro-alteracao-promocao',
            loadChildren: () => import('../cadastro-alteracao-promocao/cadastro-alteracao-promocao.module').then(m => m.CadastroAlteracaoPromocaoPageModule)
          },
          {
            path: 'cadastro-alteracao-promocao-planilha',
            loadChildren: () => import('../cadastro-alteracao-promocao-planilha/cadastro-alteracao-promocao-planilha.module').then(m => m.CadastroAlteracaoPromocaoPlanilhaPageModule)
          },
          {
            path: 'cadastro-produtos',
            loadChildren: () => import('../cadastro-produtos/cadastro-produtos.module').then(m => m.CadastroProdutosPageModule)
          },
          {
            path: 'estoque-consultar',
            loadChildren: () => import('../estoque-consultar/estoque-consultar.module').then(m => m.EstoqueConsultarPageModule)
          },          
          {
            path: 'estoque-consulta-detalhe/:codigo',
            loadChildren: () => import('../estoque-consultar-detalhe/estoque-consultar-detalhe.module').then(m => m.EstoqueConsultarDetalhePageModule),
            canLoad: [CheckTutorial],          
          },          
          {
            path: 'cadastrar-produtos-amc',
            loadChildren: () => import('../cadastrar-produtos-amc/cadastrar-produtos-amc.module').then(m => m.CadastrarProdutosAmcPageModule),
            canLoad: [CheckTutorial],          
          },
          {
            path: 'grupo-produtos',
            loadChildren: () => import('../cadastro-grupos/cadastro-grupos.module').then(m => m.CadastroGruposPageModule),
            canLoad: [CheckTutorial],          
          }
        ]

      },
      {
        path: 'about',
        canLoad: [CheckTutorial],
        canActivate: [CheckTutorial],     
        children: [
          {
            path: '',
            loadChildren: () => import('../about/about.module').then(m => m.AboutModule)
          },
          {
            path: 'financeiro-relatorio',
            loadChildren: () => import('../financeiro-relatorio/financeiro-relatorio.module').then(m => m.FinanceiroRelatorioPageModule)
          },
          {
            path: 'financeiro-baixa-contas',
            loadChildren: () => import('../financeiro-baixa-contas/financeiro-baixa-contas.module').then(m => m.FinanceiroBaixaContasPageModule)
          },
          {
            path: 'financeiro-fluxo-caixa',
            loadChildren: () => import('../financeiro-fluxo-caixa/financeiro-fluxo-caixa.module').then(m => m.FinanceiroFluxoCaixaPageModule)
          },
          {
            path: 'financeiro-recebimento-parcelas',
            loadChildren: () => import('../financeiro-recebimento-parcelas/financeiro-recebimento-parcelas.module').then(m => m.FinanceiroRecebimentoParcelasPageModule)
          },
          {
            path: 'cadastro-contas-pagar',
            loadChildren: () => import('../cadastro-contas-pagar/cadastro-contas-pagar.module').then(m => m.CadastroContasPagarPageModule)
          },
          {
            path: 'retorno-remessa',
            loadChildren: () => import('../retorno-remessa/retorno-remessa.module').then(m => m.RetornoRemessasPageModule)
          },
          {
            path: 'conferencia-cartao',
            loadChildren: () => import('../conferencia-cartao/conferencia-cartao.module').then(m => m.ConferenciaCartaoPageModule)
          }
        ]
      },
      {
        path: 'clientes',
        canLoad: [CheckTutorial],
        canActivate: [CheckTutorial],     
        children: [
          {
            path: '',
            loadChildren: () => import('../clientes/clientes.module').then(m => m.ClientesModule),
          },
          {
            path: 'clientes-melhores',
            loadChildren: () => import('../clientes-melhores/clientes-melhores.module').then(m => m.ClientesMelhoresPageModule)
          },
          {
            path: 'clientes-fluxo',
            loadChildren: () => import('../clientes-fluxo/clientes-fluxo.module').then(m => m.ClientesFluxoPageModule)
          },
          {
            path: 'clientes-qualidade',
            loadChildren: () => import('../clientes-qualidade/clientes-qualidade.module').then(m => m.ClientesQualidadePageModule)
          }
        ]
      },
      {
        path: '',
        redirectTo: '/app/tabs/schedule',
        pathMatch: 'full'
      }
    ]
  }
];

@NgModule({
  imports: [RouterModule.forChild(routes)],
  exports: [RouterModule]
})
export class TabsPageRoutingModule { }

