import { Component, OnInit } from '@angular/core';
import { ModalController } from '@ionic/angular';
import { ParametrosComponent } from '../../modal/parametros/parametros.component';
import { LoaderService } from '../../providers/loader.service';
import { VendasLojasService } from '../../providers/vendas-lojas.service';

@Component({
  selector: 'app-vendas-campanhas',
  templateUrl: './vendas-campanhas.page.html',
  styleUrls: ['./vendas-campanhas.page.scss'],
})
export class VendasCampanhasPage implements OnInit {
  parametro = {
    idConexao : '',
    data_inicial : '',
    data_final : ''
  }
  vendas: any;
  mes: any;
  constructor(public loader: LoaderService, public vendasLojas: VendasLojasService, public modalController: ModalController) { }

  ngOnInit() {
    var date = new Date();
    var primeiroDia = new Date(date.getFullYear(), date.getMonth(), 1);
    var ultimoDia = new Date(date.getFullYear(), date.getMonth() + 1, 0);
    var a = date.getMonth() + 1;
    this.mes = ultimoDia.getMonth() + 1;
    
    this.parametro.data_inicial = date.getFullYear()+'-'+this.padLeft(this.mes, '0', 2)+'-'+'01';
    this.parametro.data_final = date.getFullYear()+'-'+this.padLeft(this.mes, '0', 2)+'-'+ultimoDia.getDate();
    this.buscarCampanhas(this.parametro);
  }

  padLeft(text:string, padChar:string, size:number): string {
    return (String(padChar).repeat(size) + text).substr( (size * -1), size) ;
  }

  async openModal() {
    const modal = await this.modalController.create({
      component: ParametrosComponent,
      componentProps: {
        "lojas": false,
        "artigo": false,
        "grupo": false,
        "marca": false,
        "fornecedor": false,
        "dataInicial": true,
        "dataFinal": true,
        "colecao": false,
        "data": false,
        "genero": false
      },
      backdropDismiss: false,      
    });

    modal.onDidDismiss().then((res) => {            
      if (res !== null) {
        this.parametro.data_inicial = res.data.dataInicial;
        this.parametro.data_final = res.data.dataFinal;
        if(res.data.dataFinal == '' || res.data.dataInicial == ''){
          this.loader.showError("Atenção", "As datas preenchidas não podem ficar em branco.")
        } else {
          this.buscarCampanhas(this.parametro)
        }
      }
    });

    return await modal.present();
  }

  color(item){
    let color: any;
    if(item.BRUTO-(item.DESPESA_LIQUIDA+item.CUSTO) >= 0){
      color = "green";
    } else {
      color = "#f53d3d";
    }
    return color; 
  }

  ionViewDidLoad() {    
    
  }

  buscarCampanhas(parametro){
    this.vendas = [];   
    this.loader.showLoader("Buscando informações no servidor..."); 
    this.vendasLojas.vendasPorCampanhas(parametro)
    .then((result: any) => {
      // console.log(result);
      this.vendas = [];
      this.vendas = result;
      this.loader.hideLoader();      
      if(result.length == 0){        
        this.loader.presentToast("Não encontrei nada!");        
      }      
      })
      .catch((error: any) => {
        this.loader.hideLoader();      
        this.loader.showError("Ops!", error);          
      });
  }

}
