import { Component, OnInit } from '@angular/core';
import { ModalController } from '@ionic/angular';
import { ParametrosComponent } from '../../modal/parametros/parametros.component';
import { LoaderService } from '../../providers/loader.service';
import { VendasLojasService } from '../../providers/vendas-lojas.service';

@Component({
  selector: 'app-vendas-comparativo-indice',
  templateUrl: './vendas-comparativo-indice.page.html',
  styleUrls: ['./vendas-comparativo-indice.page.scss'],
})
export class VendasComparativoIndicePage implements OnInit {
  parametro = {
    id : '',
    data_inicial : '',
    data_final : '',
    parametro: "",
    somenteValor: false,
  }
  
  totalAnterior: number = 0;
  totalAtual: number = 0;

  vendas: any;
  mes: any;
  constructor(public modalController: ModalController, public loader: LoaderService,
    public vendasLojas: VendasLojasService) { }

  ngOnInit() {
    var date = new Date();
    var primeiroDia = new Date(date.getFullYear(), date.getMonth(), 1);
    var ultimoDia = new Date(date.getFullYear(), date.getMonth() + 1, 0);
    var a = date.getMonth() + 1;
    this.mes = ultimoDia.getMonth() + 1;
    var diaFinal: any = date.getDate();
    this.parametro.data_inicial = date.getFullYear()+'-'+this.padLeft(this.mes, '0', 2)+'-'+'01';
    this.parametro.data_final = date.getFullYear()+'-'+this.padLeft(this.mes, '0', 2)+'-'+this.padLeft(diaFinal, '0', 2);
    
    this.parametro.parametro = 'anual';
    this.parametro.somenteValor = false;
    this.buscarComparativo(this.parametro);
  }

  padLeft(text:string, padChar:string, size:number): string {
    return (String(padChar).repeat(size) + text).substr( (size * -1), size) ;
  }

  async openModal() {
    const modal = await this.modalController.create({
      component: ParametrosComponent,
      componentProps: {
        "lojas": false,
        "artigo": false,
        "grupo": false,
        "marca": false,
        "fornecedor": false,
        "dataInicial": true,
        "dataFinal": true,
        "colecao": false,
        "data": false,
        "genero": false,
        "parametro_retroativo": true,
        "somenteValores": true
      },
      backdropDismiss: false,      
    });

    modal.onDidDismiss().then((d :any) => {
      let data = d.data;
      console.log(data);
      if(data != undefined){        
        this.parametro.data_inicial = (data.dataInicial == '') ? this.parametro.data_inicial : data.dataInicial;
        this.parametro.data_final = (data.dataFinal == '') ? this.parametro.data_final : data.dataFinal;
        this.parametro.somenteValor = data.somenteValores;
        if(data.parametro != null){
          this.parametro.parametro = data.parametro;
        } else {
          this.parametro.parametro = 'anual';
        }            
        if(this.parametro.data_inicial != undefined && this.parametro.data_final != undefined ){
          this.buscarComparativo(this.parametro);
        } else {
          var date = new Date();
          var primeiroDia = new Date(date.getFullYear(), date.getMonth(), 1);
          var ultimoDia = new Date(date.getFullYear(), date.getMonth() + 1, 0);
          var a = date.getMonth() + 1;
          this.mes = ultimoDia.getMonth() + 1;
          var diaFinal: any = date.getDate();
          this.parametro.data_inicial = date.getFullYear()+'-'+this.padLeft(this.mes, '0', 2)+'-'+'01';
          this.parametro.data_final = date.getFullYear()+'-'+this.padLeft(this.mes, '0', 2)+'-'+this.padLeft(diaFinal, '0', 2);
          this.buscarComparativo(this.parametro);
        }
      }
      
    });

    return await modal.present();
  }

  buscarComparativo(param){        
    this.vendas = [];    
    this.totalAnterior = 0;
    this.totalAtual = 0;
    this.loader.showLoader("Buscando informações comparativas...");    
    this.vendasLojas.comparativoDeVendas(param)
    .then((result: any) => {          
      this.loader.hideLoader();
      this.vendas = result;
      for (let i = 0; i < result.length; i++) {
        const element = result[i];
        this.totalAnterior = this.totalAnterior + element.VL_TOTAL_ANO_PASSADO;
        this.totalAtual = this.totalAtual + element.VL_TOTAL_ANO_ATUAL;        
      }
      if(result.length == 0){
        this.loader.presentToast("Não encontrei nada!")
      }
      }).catch((error: any) => {
        this.loader.hideLoader();
        console.log(error);
        this.loader.showError("Ops!", error);        
      });
  }

}
