import { Component, OnInit } from '@angular/core';
import { ActivatedRoute } from '@angular/router';
import { ModalController } from '@ionic/angular';
import * as HighCharts from 'highcharts';
import { ParametrosComponent } from '../../modal/parametros/parametros.component';
import { AuthServiceService } from '../../providers/auth-service.service';
import { LoaderService } from '../../providers/loader.service';
import { VendasLojasService } from '../../providers/vendas-lojas.service';

@Component({
  selector: 'app-vendas-grafico-comparativo',
  templateUrl: './vendas-grafico-comparativo.page.html',
  styleUrls: ['./vendas-grafico-comparativo.page.scss'],
})
export class VendasGraficoComparativoPage implements OnInit {
  public data = {
    id : ""
  }  
  dataReturned: any;
  meses = ["Jan","Fev","Mar","Abr","Mai","Jun","Jul","Ago","Set","Out","Nov","Dez"];  
  valorDinheiro = [0,0,0,0,0,0,0,0,0,0,0,0];  
  Valores = [];  
  mes = 0;
  stringMes = "";
  vendas: any;
  venda = [];  
  constructor(public loader: LoaderService, public vendasLojas: VendasLojasService, 
    public auth: AuthServiceService, private route: ActivatedRoute, public modalController: ModalController) { }

  ngOnInit() {
    this.buscarGrafico("");  
  }

  async openModal() {
    const modal = await this.modalController.create({
      component: ParametrosComponent,
      componentProps: {
        "lojas": true,
        "artigo": false,
        "grupo": false,
        "marca": false,
        "fornecedor": false,
        "dataInicial": false,
        "dataFinal": false,
        "colecao": false,
        "data": false,
        "genero": false
      }
    });

    modal.onDidDismiss().then((res) => {      
      if (res !== null) {
        this.dataReturned = res.data;
        this.buscarGrafico(res.data.lj);        
      }
    });

    return await modal.present();
  }

  alimetaValorAdd(indice, valor){
    this.valorDinheiro[indice] = valor;
  };

  graf(){
    HighCharts.chart('lineChart',{
      chart: {
        type: 'column'
      },
      title: {
        text: 'Gráfico anual de vendas (R$)'
      },
      subtitle: {
          text: 'Comparação entre 3 anos'
      },
      xAxis: {
        categories: this.meses,
        crosshair: true
      },
      yAxis: {
        min: 0,
        title: {
            text: 'Valor (R$)'
        }
      },
      tooltip: {
        headerFormat: '<span style="font-size:10px">{point.key}</span><table>',
        pointFormat: '<tr><td style="color:{series.color};padding:0">{series.name}: </td>' +
            '<td style="padding:0"><b> R$ {point.y:.2f} </b></td></tr>',
        footerFormat: '</table>',
        shared: true,
        useHTML: true
      },
      plotOptions: {
        column: {
            pointPadding: 0.2,
            borderWidth: 0
        }
      },      
      series: this.Valores
    });    
  }

  buscarGrafico(a){
    this.loader.showLoader("Buscando informações para o gráfico...");    
    this.vendas = [];
    this.Valores = [];
    this.valorDinheiro = [0,0,0,0,0,0,0,0,0,0,0,0];    
    this.vendasLojas.graficoDeVendas(a)
    .then((result: any) => {
      this.loader.hideLoader();      
      if(result.length != 0){
        let ano = result[0].ANO;
        for (let i = 0; i < result.length; i++) {
          const vendas = result[i];       
          let anoTemp = vendas.ANO; 
          let mes = vendas.MES;
          if (anoTemp != ano || i == result.length-1) {
            if(i == result.length-1 && anoTemp == ano){
              this.alimetaValorAdd(parseInt(mes)-1, vendas.VALOR);
            }
            let a = ano.toString().substring(2,4);
            if(ano == 2018){
              a = 10;
            } 
            if(ano == 2017){
              a = 200;
            } 
            if(ano == 2016){
              a = 300;
            }
            if(ano == 2019){
              a = 400;
            }
            let venda = {
              name: ano,
              data: this.valorDinheiro              
            };
            this.Valores.push(venda);
            ano = vendas.ANO;
            this.valorDinheiro = [0,0,0,0,0,0,0,0,0,0,0,0];            
            this.alimetaValorAdd(parseInt(mes)-1, vendas.VALOR);
            if(i == result.length-1 && anoTemp == ano && vendas.MES == "01"){              
              venda = {
                  name: ano,
                  data: this.valorDinheiro
              };
              this.Valores.push(venda);
            }
          }else{
            this.alimetaValorAdd(parseInt(mes)-1, vendas.VALOR);            
          }          
        }        
      } else {        
        // this.presentToast("Não encontrei nada!")
      }
      this.graf();
      
    })
    .catch((error: any) => {
      this.loader.hideLoader();
      this.loader.showError('Ops', error);      
    });
  }

  

}
