import { Component, OnInit } from '@angular/core';
import { ModalController } from '@ionic/angular';
import { ParametrosComponent } from '../../modal/parametros/parametros.component';
import { AuthServiceService } from '../../providers/auth-service.service';
import { LoaderService } from '../../providers/loader.service';
import { VendasLojasService } from '../../providers/vendas-lojas.service';
import * as HighCharts from 'highcharts';


@Component({
  selector: 'app-vendas-grafico-semanas',
  templateUrl: './vendas-grafico-semanas.page.html',
  styleUrls: ['./vendas-grafico-semanas.page.scss'],
})
export class VendasGraficoSemanasPage implements OnInit {

  parametro = {
    idConexao : '',
    data_inicial : '',
    data_final : '',
    loja: ''
  }  
  resultado = [];
  vendas: any;
  mes: any;
  arPizza = [];
  constructor(public modalController: ModalController, public vendasLojas: VendasLojasService, 
    public loader: LoaderService, public auth: AuthServiceService) { }

  ngOnInit() {
    var date = new Date();
    var primeiroDia = new Date(date.getFullYear(), date.getMonth(), 1);
    var ultimoDia = new Date(date.getFullYear(), date.getMonth() + 1, 0);    
    var a = date.getMonth() + 1;
    this.mes = ultimoDia.getMonth() + 1;
    var diaFinal: any = date.getDate();
    this.parametro.data_inicial = '01'+'.'+this.padLeft(this.mes, '0', 2)+'.'+date.getFullYear();
    this.parametro.data_final =  this.padLeft(diaFinal, '0', 2)+'.'+this.padLeft(this.mes, '0', 2)+'.'+date.getFullYear();
    this.parametro.idConexao = this.auth.Id;
    if(this.auth.Usuario.somenteLojaLocal == true){
      this.parametro.loja = this.auth.Usuario.loja;
    }
    this.buscarVendasPorSemana(this.parametro);
  }

  padLeft(text:string, padChar:string, size:number): string {
    return (String(padChar).repeat(size) + text).substr( (size * -1), size) ;
  }

  async openModal() {
    const modal = await this.modalController.create({
      component: ParametrosComponent,
      componentProps: {
        "lojas": true,
        "artigo": false,
        "grupo": false,
        "marca": false,
        "fornecedor": false,
        "dataInicial": false,
        "dataFinal": false,
        "dataMes": true,
        "colecao": false,
        "data": false,
        "genero": false
      }
    });

    modal.onDidDismiss().then((res) => {      
      if (res !== null) {                
        let mes = (res.data.dataMes.substring(5,8));
        let ano = parseInt(res.data.dataMes.substring(0,4));
        var primeiroDia = new Date(ano, parseInt(mes)-1, 1);
        var ultimoDia:any = new Date(ano, parseInt(mes), 0);
        this.parametro.loja = res.data.lj;
        if(res.data.dataMes == ''){

        } else {
          this.parametro.data_inicial = '01'+'.'+this.padLeft(mes, '0', 2)+'.'+ano;
          this.parametro.data_final = this.padLeft(ultimoDia.getDate(), '0', 2)+'.'+this.padLeft(mes, '0', 2)+'.'+ano;
        }
        this.parametro.idConexao = this.auth.Id;        
        this.buscarVendasPorSemana(this.parametro)
      }
    });

    return await modal.present();
  }

  buscarVendasPorSemana(param){        
    this.vendas = [];
    this.loader.showLoader("Buscando informações comparativas...");    
    this.vendasLojas.vendasComparativoSemana(param)
    .then((result: any) => {          
      this.loader.hideLoader();      
      this.resultado = [];
      this.arPizza = [];
      for (let i = 0; i < result.length; i++) {
        const element = result[i];              
        this.resultado.push({
            name: element.SEMANA+' sem',
            data: [element.SEG, element.TER, element.QUA, element.QUI, element.SEX, element.SAB, element.DOM],          
        });
        
        this.arPizza.push({
          name: element.SEMANA+' sem',
          y: element.SEG+element.TER+element.QUA+element.QUI+element.SEX+element.SAB+element.DOM
        });
      }
      if(result.length == 0){
        this.loader.presentToast("Não encontrei nada!")
      } else {
        let pizza = [{
          name: 'Brands',
          colorByPoint: true,
          data: this.arPizza
        }];
        this.buscarGrafico(this.resultado);        
        this.buscarGraficoPizza(pizza);
      }
      }).catch((error: any) => {
        this.loader.hideLoader();
        console.log(error);
        this.loader.showError("Ops!", error);        
      });
  }

  buscarGrafico(series){
    let loja = this.parametro.loja == '' ? 'TODAS' : this.parametro.loja;
    HighCharts.chart('barChartSemana',{
      chart: {
        type: 'bar'
      },
      title: {
        text: 'Clientes por semana'
      },
      subtitle: {
          text: 'Loja selecionada '+loja+ '<br>Período de '+this.parametro.data_inicial+' até '+this.parametro.data_final
      },
      xAxis: {
        categories: ['Segunda', 'Terça', 'Quarta', 'Quinta', 'Sexta', 'Sabado', 'Domingo'],
        title: {
            text: null
        }
      },
      yAxis: {
        min: 0,
        title: {
            text: 'Quantidade de clientes',
            align: 'high'
        },
        labels: {
            overflow: 'justify'
        }
      },
      tooltip: {
        valueSuffix: ' QT'
      },
      plotOptions: {
        bar: {
            dataLabels: {
                enabled: true
            }
        }
      },      
      legend: {
        layout: 'vertical',
        align: 'right',
        verticalAlign: 'top',
        x: 10,
        y: -10,
        floating: true,
        borderWidth: 1,
        backgroundColor:
          HighCharts.defaultOptions.legend.backgroundColor || '#FFFFFF',
        shadow: true
      },
      series: series
    }); 
  }


  buscarGraficoPizza(series){    
    let loja = this.parametro.loja == '' ? 'TODAS' : this.parametro.loja;
    HighCharts.chart('pizzaChartSemana', {
      chart: {
          plotBackgroundColor: null,
          plotBorderWidth: null,
          plotShadow: false,
          type: 'pie'
      },
      title: {
          text: 'Percentual acumulado por semana'
      },
      tooltip: {
          pointFormat: '{series.name}: <b>{point.percentage:.1f}%</b>'
      },
      accessibility: {
          point: {
              valueSuffix: '%'
          }
      },
      plotOptions: {
          pie: {
              allowPointSelect: true,
              cursor: 'pointer',
              dataLabels: {
                  enabled: true,
                  format: '<b>{point.name}</b>: {point.percentage:.1f} %'
              }
          }
      },
      series: series      
    });
  }

}
