import { Component, OnInit } from '@angular/core';
import { ActivatedRoute, NavigationExtras, Router } from '@angular/router';
import { AuthServiceService } from '../../providers/auth-service.service';
import { LoaderService } from '../../providers/loader.service';
import { UserData } from '../../providers/user-data';
import { VendasLojasService } from '../../providers/vendas-lojas.service';

@Component({
  selector: 'app-vendas-mensal',
  templateUrl: './vendas-mensal.page.html',
  styleUrls: ['./vendas-mensal.page.scss'],
})
export class VendasMensalPage implements OnInit {

  registerCredentials = { id: '' };
  vendas: any;
  mes: any;
  data: any;
  totalVendas= 0;
  totalClientes= 0;
  totalNF=0;
  verNF: boolean = false;
  constructor(public loader: LoaderService, public vendasLojas: VendasLojasService, 
    public auth: AuthServiceService, private route: ActivatedRoute, private router: Router,
    public user: UserData) { }

  ngOnInit() {
    const data = this.route.snapshot.paramMap.get('mes');    
    this.buscarDesempenhoLojas(data);
  }

  ionViewWillEnter(){
    this.user.getPermissoes().then(val => {
      if(val != null){
        for (let i = 0; i < val.length; i++) {
          const element: any = val[i];
          this.registerCredentials.id = element.ID;
          for (let a = 0; a < element.PERMISSOES.length; a++) {
            const elemento = element.PERMISSOES[a];
            if((elemento.MODULO == "frmDigitaBalanco") && (elemento.ENTRAR == "true" && elemento.INCLUIR == "true")){
              this.verNF = true;
            }            
          }
        }
      } 
      return val;
    });
  }

  buscar(e){
    /*
    console.log(this.data);
    console.log(e);
    */
    this.data = e;
    this.buscarDesempenhoLojas(this.data.substring(0,7));
  }

  detalhe(e){    
    let navigationExtras: NavigationExtras = {
      queryParams: {
        special: JSON.stringify(e)
      }
    };
    this.router.navigate(['/app/tabs/schedule/vendas-mensal-detalhe'], navigationExtras);
  }

  cancelar(e){
    console.log(e)
  }

  buscarDesempenhoLojas(data) {
    this.vendas = [];
    this.loader.showLoader("Buscando vendas...");
    this.vendasLojas.desempenhoLojas(data)
    .then((result: any) => {      
      this.totalVendas= 0;
      this.totalClientes= 0;  
      this.totalNF= 0;  
      this.loader.hideLoader();      
        if(result.length == 0){
          this.loader.presentToast("Ops! Não encontrei nada!");
        }
        for (let i = 0; i < result.length; i++) {
          const element = result[i];
          // console.log(element);
          this.totalVendas = this.totalVendas + element.VL_LIQUIDO;
          this.totalClientes = this.totalClientes + element.QTPEDIDOS;
          this.totalNF = this.totalNF + element.NF;
        }
        this.vendas = result;              
    }).catch((error: any) => {
      this.loader.hideLoader();
    });
  }

}
