import { Component, OnInit } from '@angular/core';
import { ModalController } from '@ionic/angular';
import { ParametrosComponent } from '../../modal/parametros/parametros.component';
import { LoaderService } from '../../providers/loader.service';
import { VendasLojasService } from '../../providers/vendas-lojas.service';
import { groupBy, mergeMap, toArray } from 'rxjs/operators';
import { from } from 'rxjs';
import { NavigationExtras, Router } from '@angular/router';


@Component({
  selector: 'app-vendedores-desempenho',
  templateUrl: './vendedores-desempenho.page.html',
  styleUrls: ['./vendedores-desempenho.page.scss'],
})
export class VendedoresDesempenhoPage implements OnInit {
  ar: any;
  parametro = {
    id : '',
    data_inicial : '',
    data_final : '',
    vendedor: '',
    nomeVend: ''
  }
  vendas: any;
  mes: any;  
  loading: any;
  
  constructor(public modalController: ModalController, public loader: LoaderService, 
    public vendasLojas: VendasLojasService, private router: Router) { 
      
    }

  ngOnInit() {
    var date = new Date();
    var primeiroDia = new Date(date.getFullYear(), date.getMonth(), 1);
    var ultimoDia = new Date(date.getFullYear(), date.getMonth() + 1, 0);
    var a = date.getMonth() + 1;
    this.mes = ultimoDia.getMonth() + 1;
    this.parametro.data_inicial = date.getFullYear()+'-'+this.padLeft(this.mes, '0', 2)+'-'+'01';
    this.parametro.data_final = date.getFullYear()+'-'+this.padLeft(this.mes, '0', 2)+'-'+ultimoDia.getDate();
    this.buscarDesempenhoVendedores(this.parametro);
  }

  padLeft(text:string, padChar:string, size:number): string {
    return (String(padChar).repeat(size) + text).substr( (size * -1), size) ;
  }

  async openModal() {
    const modal = await this.modalController.create({
      component: ParametrosComponent,
      componentProps: {
        "lojas": false,
        "artigo": false,
        "grupo": false,
        "marca": false,
        "fornecedor": false,
        "dataInicial": true,
        "dataFinal": true,
        "colecao": false,
        "data": false,
        "genero": false,
        "parametro_retroativo": false,
        "somenteValores": false
      },
      backdropDismiss: false,      
    });

    modal.onDidDismiss().then((d :any) => {
      let data = d.data;
      if(data != undefined){        
        this.parametro.data_inicial = data.dataInicial;
        this.parametro.data_final = data.dataFinal;      
        if(this.parametro.data_inicial != undefined && this.parametro.data_final != undefined ){
          this.buscarDesempenhoVendedores(this.parametro);
        } else {
          var date = new Date();
          var primeiroDia = new Date(date.getFullYear(), date.getMonth(), 1);
          var ultimoDia = new Date(date.getFullYear(), date.getMonth() + 1, 0);
          var a = date.getMonth() + 1;
          this.mes = ultimoDia.getMonth() + 1;
          var diaFinal: any = date.getDate();
          this.parametro.data_inicial = date.getFullYear()+'-'+this.padLeft(this.mes, '0', 2)+'-'+'01';
          this.parametro.data_final = date.getFullYear()+'-'+this.padLeft(this.mes, '0', 2)+'-'+this.padLeft(diaFinal, '0', 2);
          this.buscarDesempenhoVendedores(this.parametro);
        }
      }
      
    });

    return await modal.present();
  }

  buscarDesempenhoVendedores(parametro){
    this.vendas = [];  
    this.loading = false;
    // this.loader.showLoader("Buscando desempenho...");  
    this.vendasLojas.desempenhoVendedoresPDV(parametro)
    .then((result: any) => {
      // console.log(result);
      this.loading = true;
      this.loader.hideLoader();      
        this.vendas = result;
        this.ar = [];
        if(result.length == 0){          
          this.loader.presentToast("Não encontrei nada!");
        } else {
          const source = from(result);
          const example = source.pipe(
            groupBy(person => person['LOJA']),
            mergeMap(group => group.pipe(toArray()))
          );    
          const subscribe = example.subscribe(val => this.ar.push(val));
        }      
      })
      .catch((error: any) => {
        this.loader.hideLoader();
        this.loader.showError("Ops!", error);
      });
  }

  detalharVendedor(a){    
    this.parametro.vendedor = a.VENDEDOR;
    this.parametro.nomeVend = a.LKVEND01_NOMEVEND;    
    let navigationExtras: NavigationExtras = {
      queryParams: {
        special: JSON.stringify(this.parametro)
      }
    };
    this.router.navigate(['/app/tabs/speakers/vendedores-desempenho-detalhe'], navigationExtras);
  }

}
